@@ -64,7 +64,7 @@ def run_tool_db_odbc_0(DSN=None, USER=None, PASSWORD=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def Disconnect_from_ODBC_Source(ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, TRANSACT=None, Verbose=2):
+def Disconnect_from_ODBC_Source(CONNECTION=None, TRANSACT=None, Verbose=2):
     '''
     Disconnect from ODBC Source
     ----------
@@ -72,9 +72,7 @@ def Disconnect_from_ODBC_Source(ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, TRA
     Disconnects an ODBC source connection.\n
     Arguments
     ----------
-    - ODBC_DSN [`text`] : Data Source
-    - ODBC_USR [`text`] : User
-    - ODBC_PWD [`text`] : Password
+    - CONNECTION [`choice`] : Connection. Available Choices: Default: 0
     - TRANSACT [`choice`] : Transactions. Available Choices: [0] rollback [1] commit Default: 1
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
@@ -84,14 +82,12 @@ def Disconnect_from_ODBC_Source(ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, TRA
     '''
     Tool = Tool_Wrapper('db_odbc', '1', 'Disconnect from ODBC Source')
     if Tool.is_Okay():
-        Tool.Set_Option('ODBC_DSN', ODBC_DSN)
-        Tool.Set_Option('ODBC_USR', ODBC_USR)
-        Tool.Set_Option('ODBC_PWD', ODBC_PWD)
+        Tool.Set_Option('CONNECTION', CONNECTION)
         Tool.Set_Option('TRANSACT', TRANSACT)
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_db_odbc_1(ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, TRANSACT=None, Verbose=2):
+def run_tool_db_odbc_1(CONNECTION=None, TRANSACT=None, Verbose=2):
     '''
     Disconnect from ODBC Source
     ----------
@@ -99,9 +95,7 @@ def run_tool_db_odbc_1(ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, TRANSACT=Non
     Disconnects an ODBC source connection.\n
     Arguments
     ----------
-    - ODBC_DSN [`text`] : Data Source
-    - ODBC_USR [`text`] : User
-    - ODBC_PWD [`text`] : Password
+    - CONNECTION [`choice`] : Connection. Available Choices: Default: 0
     - TRANSACT [`choice`] : Transactions. Available Choices: [0] rollback [1] commit Default: 1
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
@@ -111,14 +105,12 @@ def run_tool_db_odbc_1(ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, TRANSACT=Non
     '''
     Tool = Tool_Wrapper('db_odbc', '1', 'Disconnect from ODBC Source')
     if Tool.is_Okay():
-        Tool.Set_Option('ODBC_DSN', ODBC_DSN)
-        Tool.Set_Option('ODBC_USR', ODBC_USR)
-        Tool.Set_Option('ODBC_PWD', ODBC_PWD)
+        Tool.Set_Option('CONNECTION', CONNECTION)
         Tool.Set_Option('TRANSACT', TRANSACT)
         return Tool.Execute(Verbose)
     return False
 
-def CommitRollback_Transaction(ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, SOURCE=None, TRANSACT=None, Verbose=2):
+def CommitRollback_Transaction(CONNECTION=None, SOURCE=None, TRANSACT=None, Verbose=2):
     '''
     Commit/Rollback Transaction
     ----------
@@ -126,9 +118,7 @@ def CommitRollback_Transaction(ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, SOUR
     Execute a commit or rollback on open transactions with ODBC source.\n
     Arguments
     ----------
-    - ODBC_DSN [`text`] : Data Source
-    - ODBC_USR [`text`] : User
-    - ODBC_PWD [`text`] : Password
+    - CONNECTION [`choice`] : Connection. Available Choices: Default: 0
     - SOURCE [`choice`] : Source. Available Choices: Default: 0
     - TRANSACT [`choice`] : Transactions. Available Choices: [0] rollback [1] commit Default: 1
 
@@ -139,15 +129,13 @@ def CommitRollback_Transaction(ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, SOUR
     '''
     Tool = Tool_Wrapper('db_odbc', '2', 'Commit/Rollback Transaction')
     if Tool.is_Okay():
-        Tool.Set_Option('ODBC_DSN', ODBC_DSN)
-        Tool.Set_Option('ODBC_USR', ODBC_USR)
-        Tool.Set_Option('ODBC_PWD', ODBC_PWD)
+        Tool.Set_Option('CONNECTION', CONNECTION)
         Tool.Set_Option('SOURCE', SOURCE)
         Tool.Set_Option('TRANSACT', TRANSACT)
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_db_odbc_2(ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, SOURCE=None, TRANSACT=None, Verbose=2):
+def run_tool_db_odbc_2(CONNECTION=None, SOURCE=None, TRANSACT=None, Verbose=2):
     '''
     Commit/Rollback Transaction
     ----------
@@ -155,9 +143,7 @@ def run_tool_db_odbc_2(ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, SOURCE=None,
     Execute a commit or rollback on open transactions with ODBC source.\n
     Arguments
     ----------
-    - ODBC_DSN [`text`] : Data Source
-    - ODBC_USR [`text`] : User
-    - ODBC_PWD [`text`] : Password
+    - CONNECTION [`choice`] : Connection. Available Choices: Default: 0
     - SOURCE [`choice`] : Source. Available Choices: Default: 0
     - TRANSACT [`choice`] : Transactions. Available Choices: [0] rollback [1] commit Default: 1
 
@@ -168,15 +154,13 @@ def run_tool_db_odbc_2(ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, SOURCE=None,
     '''
     Tool = Tool_Wrapper('db_odbc', '2', 'Commit/Rollback Transaction')
     if Tool.is_Okay():
-        Tool.Set_Option('ODBC_DSN', ODBC_DSN)
-        Tool.Set_Option('ODBC_USR', ODBC_USR)
-        Tool.Set_Option('ODBC_PWD', ODBC_PWD)
+        Tool.Set_Option('CONNECTION', CONNECTION)
         Tool.Set_Option('SOURCE', SOURCE)
         Tool.Set_Option('TRANSACT', TRANSACT)
         return Tool.Execute(Verbose)
     return False
 
-def Execute_SQL(ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, SQL=None, COMMIT=None, STOP=None, Verbose=2):
+def Execute_SQL(CONNECTION=None, SQL=None, COMMIT=None, STOP=None, Verbose=2):
     '''
     Execute SQL
     ----------
@@ -184,10 +168,8 @@ def Execute_SQL(ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, SQL=None, COMMIT=No
     Execute SQL commands on a connected ODBC source. Separate different commands with a semicolon (';').\n
     Arguments
     ----------
-    - ODBC_DSN [`text`] : Data Source
-    - ODBC_USR [`text`] : User
-    - ODBC_PWD [`text`] : Password
-    - SQL [`long text`] : SQL Statment. Default: CREATE TABLE myTable1 (Col1 VARCHAR(255) PRIMARY KEY, Col2 INTEGER);
+    - CONNECTION [`choice`] : Connection. Available Choices: Default: 0
+    - SQL [`long text`] : SQL Statement. Default: CREATE TABLE myTable1 (Col1 VARCHAR(255) PRIMARY KEY, Col2 INTEGER);
 INSERT INTO myTable1 (Col1, Col2) VALUES('First Value', 1);
 DROP TABLE myTable1;
 
@@ -201,16 +183,14 @@ DROP TABLE myTable1;
     '''
     Tool = Tool_Wrapper('db_odbc', '3', 'Execute SQL')
     if Tool.is_Okay():
-        Tool.Set_Option('ODBC_DSN', ODBC_DSN)
-        Tool.Set_Option('ODBC_USR', ODBC_USR)
-        Tool.Set_Option('ODBC_PWD', ODBC_PWD)
+        Tool.Set_Option('CONNECTION', CONNECTION)
         Tool.Set_Option('SQL', SQL)
         Tool.Set_Option('COMMIT', COMMIT)
         Tool.Set_Option('STOP', STOP)
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_db_odbc_3(ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, SQL=None, COMMIT=None, STOP=None, Verbose=2):
+def run_tool_db_odbc_3(CONNECTION=None, SQL=None, COMMIT=None, STOP=None, Verbose=2):
     '''
     Execute SQL
     ----------
@@ -218,10 +198,8 @@ def run_tool_db_odbc_3(ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, SQL=None, CO
     Execute SQL commands on a connected ODBC source. Separate different commands with a semicolon (';').\n
     Arguments
     ----------
-    - ODBC_DSN [`text`] : Data Source
-    - ODBC_USR [`text`] : User
-    - ODBC_PWD [`text`] : Password
-    - SQL [`long text`] : SQL Statment. Default: CREATE TABLE myTable1 (Col1 VARCHAR(255) PRIMARY KEY, Col2 INTEGER);
+    - CONNECTION [`choice`] : Connection. Available Choices: Default: 0
+    - SQL [`long text`] : SQL Statement. Default: CREATE TABLE myTable1 (Col1 VARCHAR(255) PRIMARY KEY, Col2 INTEGER);
 INSERT INTO myTable1 (Col1, Col2) VALUES('First Value', 1);
 DROP TABLE myTable1;
 
@@ -235,16 +213,14 @@ DROP TABLE myTable1;
     '''
     Tool = Tool_Wrapper('db_odbc', '3', 'Execute SQL')
     if Tool.is_Okay():
-        Tool.Set_Option('ODBC_DSN', ODBC_DSN)
-        Tool.Set_Option('ODBC_USR', ODBC_USR)
-        Tool.Set_Option('ODBC_PWD', ODBC_PWD)
+        Tool.Set_Option('CONNECTION', CONNECTION)
         Tool.Set_Option('SQL', SQL)
         Tool.Set_Option('COMMIT', COMMIT)
         Tool.Set_Option('STOP', STOP)
         return Tool.Execute(Verbose)
     return False
 
-def List_Table_Fields(FIELDS=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, TABLE=None, Verbose=2):
+def List_Table_Fields(FIELDS=None, CONNECTION=None, TABLE=None, Verbose=2):
     '''
     List Table Fields
     ----------
@@ -253,9 +229,7 @@ def List_Table_Fields(FIELDS=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None,
     Arguments
     ----------
     - FIELDS [`output table`] : Fields
-    - ODBC_DSN [`text`] : Data Source
-    - ODBC_USR [`text`] : User
-    - ODBC_PWD [`text`] : Password
+    - CONNECTION [`choice`] : Connection. Available Choices: Default: 0
     - TABLE [`choice`] : Table Source. Available Choices: Default: 0
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
@@ -266,14 +240,12 @@ def List_Table_Fields(FIELDS=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None,
     Tool = Tool_Wrapper('db_odbc', '4', 'List Table Fields')
     if Tool.is_Okay():
         Tool.Set_Output('FIELDS', FIELDS)
-        Tool.Set_Option('ODBC_DSN', ODBC_DSN)
-        Tool.Set_Option('ODBC_USR', ODBC_USR)
-        Tool.Set_Option('ODBC_PWD', ODBC_PWD)
+        Tool.Set_Option('CONNECTION', CONNECTION)
         Tool.Set_Option('TABLE', TABLE)
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_db_odbc_4(FIELDS=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, TABLE=None, Verbose=2):
+def run_tool_db_odbc_4(FIELDS=None, CONNECTION=None, TABLE=None, Verbose=2):
     '''
     List Table Fields
     ----------
@@ -282,9 +254,7 @@ def run_tool_db_odbc_4(FIELDS=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None,
     Arguments
     ----------
     - FIELDS [`output table`] : Fields
-    - ODBC_DSN [`text`] : Data Source
-    - ODBC_USR [`text`] : User
-    - ODBC_PWD [`text`] : Password
+    - CONNECTION [`choice`] : Connection. Available Choices: Default: 0
     - TABLE [`choice`] : Table Source. Available Choices: Default: 0
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
@@ -295,14 +265,12 @@ def run_tool_db_odbc_4(FIELDS=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None,
     Tool = Tool_Wrapper('db_odbc', '4', 'List Table Fields')
     if Tool.is_Okay():
         Tool.Set_Output('FIELDS', FIELDS)
-        Tool.Set_Option('ODBC_DSN', ODBC_DSN)
-        Tool.Set_Option('ODBC_USR', ODBC_USR)
-        Tool.Set_Option('ODBC_PWD', ODBC_PWD)
+        Tool.Set_Option('CONNECTION', CONNECTION)
         Tool.Set_Option('TABLE', TABLE)
         return Tool.Execute(Verbose)
     return False
 
-def Import_Table(TABLE=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, SOURCE=None, Verbose=2):
+def Import_Table(TABLE=None, CONNECTION=None, SOURCE=None, Verbose=2):
     '''
     Import Table
     ----------
@@ -311,9 +279,7 @@ def Import_Table(TABLE=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, SOURCE
     Arguments
     ----------
     - TABLE [`output table`] : Table
-    - ODBC_DSN [`text`] : Data Source
-    - ODBC_USR [`text`] : User
-    - ODBC_PWD [`text`] : Password
+    - CONNECTION [`choice`] : Connection. Available Choices: Default: 0
     - SOURCE [`choice`] : Table Source. Available Choices: Default: 0
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
@@ -324,14 +290,12 @@ def Import_Table(TABLE=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, SOURCE
     Tool = Tool_Wrapper('db_odbc', '5', 'Import Table')
     if Tool.is_Okay():
         Tool.Set_Output('TABLE', TABLE)
-        Tool.Set_Option('ODBC_DSN', ODBC_DSN)
-        Tool.Set_Option('ODBC_USR', ODBC_USR)
-        Tool.Set_Option('ODBC_PWD', ODBC_PWD)
+        Tool.Set_Option('CONNECTION', CONNECTION)
         Tool.Set_Option('SOURCE', SOURCE)
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_db_odbc_5(TABLE=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, SOURCE=None, Verbose=2):
+def run_tool_db_odbc_5(TABLE=None, CONNECTION=None, SOURCE=None, Verbose=2):
     '''
     Import Table
     ----------
@@ -340,9 +304,7 @@ def run_tool_db_odbc_5(TABLE=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None,
     Arguments
     ----------
     - TABLE [`output table`] : Table
-    - ODBC_DSN [`text`] : Data Source
-    - ODBC_USR [`text`] : User
-    - ODBC_PWD [`text`] : Password
+    - CONNECTION [`choice`] : Connection. Available Choices: Default: 0
     - SOURCE [`choice`] : Table Source. Available Choices: Default: 0
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
@@ -353,14 +315,12 @@ def run_tool_db_odbc_5(TABLE=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None,
     Tool = Tool_Wrapper('db_odbc', '5', 'Import Table')
     if Tool.is_Okay():
         Tool.Set_Output('TABLE', TABLE)
-        Tool.Set_Option('ODBC_DSN', ODBC_DSN)
-        Tool.Set_Option('ODBC_USR', ODBC_USR)
-        Tool.Set_Option('ODBC_PWD', ODBC_PWD)
+        Tool.Set_Option('CONNECTION', CONNECTION)
         Tool.Set_Option('SOURCE', SOURCE)
         return Tool.Execute(Verbose)
     return False
 
-def Export_Table(TABLE=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, TABLE_PK=None, TABLE_NN=None, TABLE_UQ=None, NAME=None, EXISTS=None, Verbose=2):
+def Export_Table(TABLE=None, CONNECTION=None, TABLE_PK=None, TABLE_NN=None, TABLE_UQ=None, NAME=None, EXISTS=None, Verbose=2):
     '''
     Export Table
     ----------
@@ -369,9 +329,7 @@ def Export_Table(TABLE=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, TABLE_
     Arguments
     ----------
     - TABLE [`input table`] : Table
-    - ODBC_DSN [`text`] : Data Source
-    - ODBC_USR [`text`] : User
-    - ODBC_PWD [`text`] : Password
+    - CONNECTION [`choice`] : Connection. Available Choices: Default: 0
     - TABLE_PK [`table fields`] : Primary Key
     - TABLE_NN [`table fields`] : Not Null
     - TABLE_UQ [`table fields`] : Unique
@@ -386,9 +344,7 @@ def Export_Table(TABLE=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, TABLE_
     Tool = Tool_Wrapper('db_odbc', '6', 'Export Table')
     if Tool.is_Okay():
         Tool.Set_Input ('TABLE', TABLE)
-        Tool.Set_Option('ODBC_DSN', ODBC_DSN)
-        Tool.Set_Option('ODBC_USR', ODBC_USR)
-        Tool.Set_Option('ODBC_PWD', ODBC_PWD)
+        Tool.Set_Option('CONNECTION', CONNECTION)
         Tool.Set_Option('TABLE_PK', TABLE_PK)
         Tool.Set_Option('TABLE_NN', TABLE_NN)
         Tool.Set_Option('TABLE_UQ', TABLE_UQ)
@@ -397,7 +353,7 @@ def Export_Table(TABLE=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, TABLE_
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_db_odbc_6(TABLE=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, TABLE_PK=None, TABLE_NN=None, TABLE_UQ=None, NAME=None, EXISTS=None, Verbose=2):
+def run_tool_db_odbc_6(TABLE=None, CONNECTION=None, TABLE_PK=None, TABLE_NN=None, TABLE_UQ=None, NAME=None, EXISTS=None, Verbose=2):
     '''
     Export Table
     ----------
@@ -406,9 +362,7 @@ def run_tool_db_odbc_6(TABLE=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None,
     Arguments
     ----------
     - TABLE [`input table`] : Table
-    - ODBC_DSN [`text`] : Data Source
-    - ODBC_USR [`text`] : User
-    - ODBC_PWD [`text`] : Password
+    - CONNECTION [`choice`] : Connection. Available Choices: Default: 0
     - TABLE_PK [`table fields`] : Primary Key
     - TABLE_NN [`table fields`] : Not Null
     - TABLE_UQ [`table fields`] : Unique
@@ -423,9 +377,7 @@ def run_tool_db_odbc_6(TABLE=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None,
     Tool = Tool_Wrapper('db_odbc', '6', 'Export Table')
     if Tool.is_Okay():
         Tool.Set_Input ('TABLE', TABLE)
-        Tool.Set_Option('ODBC_DSN', ODBC_DSN)
-        Tool.Set_Option('ODBC_USR', ODBC_USR)
-        Tool.Set_Option('ODBC_PWD', ODBC_PWD)
+        Tool.Set_Option('CONNECTION', CONNECTION)
         Tool.Set_Option('TABLE_PK', TABLE_PK)
         Tool.Set_Option('TABLE_NN', TABLE_NN)
         Tool.Set_Option('TABLE_UQ', TABLE_UQ)
@@ -434,7 +386,7 @@ def run_tool_db_odbc_6(TABLE=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None,
         return Tool.Execute(Verbose)
     return False
 
-def Drop_Table(ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, TABLE=None, Verbose=2):
+def Drop_Table(CONNECTION=None, TABLE=None, Verbose=2):
     '''
     Drop Table
     ----------
@@ -442,9 +394,7 @@ def Drop_Table(ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, TABLE=None, Verbose=
     Deletes a table from a database via ODBC.\n
     Arguments
     ----------
-    - ODBC_DSN [`text`] : Data Source
-    - ODBC_USR [`text`] : User
-    - ODBC_PWD [`text`] : Password
+    - CONNECTION [`choice`] : Connection. Available Choices: Default: 0
     - TABLE [`choice`] : Table. Available Choices: Default: 0
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
@@ -454,14 +404,12 @@ def Drop_Table(ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, TABLE=None, Verbose=
     '''
     Tool = Tool_Wrapper('db_odbc', '7', 'Drop Table')
     if Tool.is_Okay():
-        Tool.Set_Option('ODBC_DSN', ODBC_DSN)
-        Tool.Set_Option('ODBC_USR', ODBC_USR)
-        Tool.Set_Option('ODBC_PWD', ODBC_PWD)
+        Tool.Set_Option('CONNECTION', CONNECTION)
         Tool.Set_Option('TABLE', TABLE)
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_db_odbc_7(ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, TABLE=None, Verbose=2):
+def run_tool_db_odbc_7(CONNECTION=None, TABLE=None, Verbose=2):
     '''
     Drop Table
     ----------
@@ -469,9 +417,7 @@ def run_tool_db_odbc_7(ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, TABLE=None,
     Deletes a table from a database via ODBC.\n
     Arguments
     ----------
-    - ODBC_DSN [`text`] : Data Source
-    - ODBC_USR [`text`] : User
-    - ODBC_PWD [`text`] : Password
+    - CONNECTION [`choice`] : Connection. Available Choices: Default: 0
     - TABLE [`choice`] : Table. Available Choices: Default: 0
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
@@ -481,14 +427,12 @@ def run_tool_db_odbc_7(ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, TABLE=None,
     '''
     Tool = Tool_Wrapper('db_odbc', '7', 'Drop Table')
     if Tool.is_Okay():
-        Tool.Set_Option('ODBC_DSN', ODBC_DSN)
-        Tool.Set_Option('ODBC_USR', ODBC_USR)
-        Tool.Set_Option('ODBC_PWD', ODBC_PWD)
+        Tool.Set_Option('CONNECTION', CONNECTION)
         Tool.Set_Option('TABLE', TABLE)
         return Tool.Execute(Verbose)
     return False
 
-def Import_Table_from_Query(TABLE=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, TABLES=None, FIELDS=None, WHERE=None, GROUP=None, HAVING=None, ORDER=None, DISTINCT=None, Verbose=2):
+def Import_Table_from_Query(TABLE=None, CONNECTION=None, TABLES=None, FIELDS=None, WHERE=None, GROUP=None, HAVING=None, ORDER=None, DISTINCT=None, Verbose=2):
     '''
     Import Table from Query
     ----------
@@ -498,9 +442,7 @@ def Import_Table_from_Query(TABLE=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=N
     Arguments
     ----------
     - TABLE [`output table`] : Table
-    - ODBC_DSN [`text`] : Data Source
-    - ODBC_USR [`text`] : User
-    - ODBC_PWD [`text`] : Password
+    - CONNECTION [`choice`] : Connection. Available Choices: Default: 0
     - TABLES [`text`] : Tables
     - FIELDS [`text`] : Fields. Default: *
     - WHERE [`text`] : Where
@@ -517,9 +459,7 @@ def Import_Table_from_Query(TABLE=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=N
     Tool = Tool_Wrapper('db_odbc', '8', 'Import Table from Query')
     if Tool.is_Okay():
         Tool.Set_Output('TABLE', TABLE)
-        Tool.Set_Option('ODBC_DSN', ODBC_DSN)
-        Tool.Set_Option('ODBC_USR', ODBC_USR)
-        Tool.Set_Option('ODBC_PWD', ODBC_PWD)
+        Tool.Set_Option('CONNECTION', CONNECTION)
         Tool.Set_Option('TABLES', TABLES)
         Tool.Set_Option('FIELDS', FIELDS)
         Tool.Set_Option('WHERE', WHERE)
@@ -530,7 +470,7 @@ def Import_Table_from_Query(TABLE=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=N
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_db_odbc_8(TABLE=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, TABLES=None, FIELDS=None, WHERE=None, GROUP=None, HAVING=None, ORDER=None, DISTINCT=None, Verbose=2):
+def run_tool_db_odbc_8(TABLE=None, CONNECTION=None, TABLES=None, FIELDS=None, WHERE=None, GROUP=None, HAVING=None, ORDER=None, DISTINCT=None, Verbose=2):
     '''
     Import Table from Query
     ----------
@@ -540,9 +480,7 @@ def run_tool_db_odbc_8(TABLE=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None,
     Arguments
     ----------
     - TABLE [`output table`] : Table
-    - ODBC_DSN [`text`] : Data Source
-    - ODBC_USR [`text`] : User
-    - ODBC_PWD [`text`] : Password
+    - CONNECTION [`choice`] : Connection. Available Choices: Default: 0
     - TABLES [`text`] : Tables
     - FIELDS [`text`] : Fields. Default: *
     - WHERE [`text`] : Where
@@ -559,9 +497,7 @@ def run_tool_db_odbc_8(TABLE=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None,
     Tool = Tool_Wrapper('db_odbc', '8', 'Import Table from Query')
     if Tool.is_Okay():
         Tool.Set_Output('TABLE', TABLE)
-        Tool.Set_Option('ODBC_DSN', ODBC_DSN)
-        Tool.Set_Option('ODBC_USR', ODBC_USR)
-        Tool.Set_Option('ODBC_PWD', ODBC_PWD)
+        Tool.Set_Option('CONNECTION', CONNECTION)
         Tool.Set_Option('TABLES', TABLES)
         Tool.Set_Option('FIELDS', FIELDS)
         Tool.Set_Option('WHERE', WHERE)
@@ -618,7 +554,7 @@ def run_tool_db_odbc_9(SOURCES=None, CONNECTED=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def List_Tables(TABLES=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, Verbose=2):
+def List_Tables(TABLES=None, CONNECTION=None, Verbose=2):
     '''
     List Tables
     ----------
@@ -627,9 +563,7 @@ def List_Tables(TABLES=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, Verbos
     Arguments
     ----------
     - TABLES [`output table`] : Tables
-    - ODBC_DSN [`text`] : Data Source
-    - ODBC_USR [`text`] : User
-    - ODBC_PWD [`text`] : Password
+    - CONNECTION [`choice`] : Connection. Available Choices: Default: 0
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
     Returns
@@ -639,13 +573,11 @@ def List_Tables(TABLES=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, Verbos
     Tool = Tool_Wrapper('db_odbc', '10', 'List Tables')
     if Tool.is_Okay():
         Tool.Set_Output('TABLES', TABLES)
-        Tool.Set_Option('ODBC_DSN', ODBC_DSN)
-        Tool.Set_Option('ODBC_USR', ODBC_USR)
-        Tool.Set_Option('ODBC_PWD', ODBC_PWD)
+        Tool.Set_Option('CONNECTION', CONNECTION)
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_db_odbc_10(TABLES=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None, Verbose=2):
+def run_tool_db_odbc_10(TABLES=None, CONNECTION=None, Verbose=2):
     '''
     List Tables
     ----------
@@ -654,9 +586,7 @@ def run_tool_db_odbc_10(TABLES=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None
     Arguments
     ----------
     - TABLES [`output table`] : Tables
-    - ODBC_DSN [`text`] : Data Source
-    - ODBC_USR [`text`] : User
-    - ODBC_PWD [`text`] : Password
+    - CONNECTION [`choice`] : Connection. Available Choices: Default: 0
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
     Returns
@@ -666,9 +596,7 @@ def run_tool_db_odbc_10(TABLES=None, ODBC_DSN=None, ODBC_USR=None, ODBC_PWD=None
     Tool = Tool_Wrapper('db_odbc', '10', 'List Tables')
     if Tool.is_Okay():
         Tool.Set_Output('TABLES', TABLES)
-        Tool.Set_Option('ODBC_DSN', ODBC_DSN)
-        Tool.Set_Option('ODBC_USR', ODBC_USR)
-        Tool.Set_Option('ODBC_PWD', ODBC_PWD)
+        Tool.Set_Option('CONNECTION', CONNECTION)
         return Tool.Execute(Verbose)
     return False
 
