@@ -308,7 +308,7 @@ def User_Defined_Filter(INPUT=None, FILTER=None, RESULT=None, FILTER_3X3=None, A
     - FILTER [`optional input table`] : Kernel
     - RESULT [`output grid`] : Filtered Grid
     - FILTER_3X3 [`static table`] : 3x3 Kernel. 3 Fields: - 1. [8 byte floating point number] 1 - 2. [8 byte floating point number] 2 - 3. [8 byte floating point number] 3 
-    - ABSOLUTE [`boolean`] : Absolute Weighting. Default: 1 If not checked to be absolute resulting sum will become devided by the sum of filter kernel's weights.
+    - ABSOLUTE [`boolean`] : Absolute Weighting. Default: 1 If not checked to be absolute resulting sum will become divided by the sum of filter kernel's weights.
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
     Returns
@@ -337,7 +337,7 @@ def run_tool_grid_filter_4(INPUT=None, FILTER=None, RESULT=None, FILTER_3X3=None
     - FILTER [`optional input table`] : Kernel
     - RESULT [`output grid`] : Filtered Grid
     - FILTER_3X3 [`static table`] : 3x3 Kernel. 3 Fields: - 1. [8 byte floating point number] 1 - 2. [8 byte floating point number] 2 - 3. [8 byte floating point number] 3 
-    - ABSOLUTE [`boolean`] : Absolute Weighting. Default: 1 If not checked to be absolute resulting sum will become devided by the sum of filter kernel's weights.
+    - ABSOLUTE [`boolean`] : Absolute Weighting. Default: 1 If not checked to be absolute resulting sum will become divided by the sum of filter kernel's weights.
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
     Returns
