@@ -704,7 +704,7 @@ def run_tool_grid_spline_6(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=No
         return Tool.Execute(Verbose)
     return False
 
-def Multilevel_BSpline_for_Categories(POINTS=None, TARGET_TEMPLATE=None, CATEGORIES=None, PROPABILITY=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
+def Multilevel_BSpline_for_Categories(POINTS=None, TARGET_TEMPLATE=None, CATEGORIES=None, PROBABILITY=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
     '''
     Multilevel B-Spline for Categories
     ----------
@@ -715,7 +715,7 @@ def Multilevel_BSpline_for_Categories(POINTS=None, TARGET_TEMPLATE=None, CATEGOR
     - POINTS [`input shapes`] : Points
     - TARGET_TEMPLATE [`optional input grid`] : Target System. use this grid's system for output grids
     - CATEGORIES [`output grid`] : Categories
-    - PROPABILITY [`output grid`] : Propability
+    - PROBABILITY [`output grid`] : Probability
     - FIELD [`table field`] : Attribute
     - TARGET_DEFINITION [`choice`] : Target Grid System. Available Choices: [0] user defined [1] grid or grid system Default: 0
     - TARGET_USER_SIZE [`floating point number`] : Cellsize. Minimum: 0.000000 Default: 1.000000
@@ -739,7 +739,7 @@ def Multilevel_BSpline_for_Categories(POINTS=None, TARGET_TEMPLATE=None, CATEGOR
         Tool.Set_Input ('POINTS', POINTS)
         Tool.Set_Input ('TARGET_TEMPLATE', TARGET_TEMPLATE)
         Tool.Set_Output('CATEGORIES', CATEGORIES)
-        Tool.Set_Output('PROPABILITY', PROPABILITY)
+        Tool.Set_Output('PROBABILITY', PROBABILITY)
         Tool.Set_Option('FIELD', FIELD)
         Tool.Set_Option('TARGET_DEFINITION', TARGET_DEFINITION)
         Tool.Set_Option('TARGET_USER_SIZE', TARGET_USER_SIZE)
@@ -755,7 +755,7 @@ def Multilevel_BSpline_for_Categories(POINTS=None, TARGET_TEMPLATE=None, CATEGOR
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_grid_spline_7(POINTS=None, TARGET_TEMPLATE=None, CATEGORIES=None, PROPABILITY=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
+def run_tool_grid_spline_7(POINTS=None, TARGET_TEMPLATE=None, CATEGORIES=None, PROBABILITY=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
     '''
     Multilevel B-Spline for Categories
     ----------
@@ -766,7 +766,7 @@ def run_tool_grid_spline_7(POINTS=None, TARGET_TEMPLATE=None, CATEGORIES=None, P
     - POINTS [`input shapes`] : Points
     - TARGET_TEMPLATE [`optional input grid`] : Target System. use this grid's system for output grids
     - CATEGORIES [`output grid`] : Categories
-    - PROPABILITY [`output grid`] : Propability
+    - PROBABILITY [`output grid`] : Probability
     - FIELD [`table field`] : Attribute
     - TARGET_DEFINITION [`choice`] : Target Grid System. Available Choices: [0] user defined [1] grid or grid system Default: 0
     - TARGET_USER_SIZE [`floating point number`] : Cellsize. Minimum: 0.000000 Default: 1.000000
@@ -790,7 +790,7 @@ def run_tool_grid_spline_7(POINTS=None, TARGET_TEMPLATE=None, CATEGORIES=None, P
         Tool.Set_Input ('POINTS', POINTS)
         Tool.Set_Input ('TARGET_TEMPLATE', TARGET_TEMPLATE)
         Tool.Set_Output('CATEGORIES', CATEGORIES)
-        Tool.Set_Output('PROPABILITY', PROPABILITY)
+        Tool.Set_Output('PROBABILITY', PROBABILITY)
         Tool.Set_Option('FIELD', FIELD)
         Tool.Set_Option('TARGET_DEFINITION', TARGET_DEFINITION)
         Tool.Set_Option('TARGET_USER_SIZE', TARGET_USER_SIZE)
