@@ -220,7 +220,7 @@ def Extract_a_Grid_from_a_Grid_Collection(GRIDS=None, Z_LEVEL=None, GRID=None, Z
     - Z_LEVEL [`optional input grid`] : Z
     - GRID [`output grid`] : Grid
     - Z_LEVEL_DEFAULT [`floating point number`] : Default. Default: 0.000000 default value if no grid has been selected
-    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neigbhour [1] Linear Interpolation [2] Spline Interpolation Default: 1
+    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neighbour [1] Linear Interpolation [2] Spline Interpolation Default: 1
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
     Returns
@@ -249,7 +249,7 @@ def run_tool_grids_tools_3(GRIDS=None, Z_LEVEL=None, GRID=None, Z_LEVEL_DEFAULT=
     - Z_LEVEL [`optional input grid`] : Z
     - GRID [`output grid`] : Grid
     - Z_LEVEL_DEFAULT [`floating point number`] : Default. Default: 0.000000 default value if no grid has been selected
-    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neigbhour [1] Linear Interpolation [2] Spline Interpolation Default: 1
+    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neighbour [1] Linear Interpolation [2] Spline Interpolation Default: 1
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
     Returns
@@ -320,7 +320,7 @@ def run_tool_grids_tools_4(GRID=None, GRIDS=None, Z_LEVEL=None, DELETE=None, Ver
         return Tool.Execute(Verbose)
     return False
 
-def Nearest_Neighbour_3D(POINTS=None, TARGET_TEMPLATE=None, GRIDS=None, Z_FIELD=None, Z_SCALE=None, V_FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TARGET_USER_ZSIZE=None, TARGET_USER_ZMIN=None, TARGET_USER_ZMAX=None, TARGET_USER_ZNUM=None, Verbose=2):
+def Nearest_Neighbour_3D(POINTS=None, TARGET_TEMPLATE=None, GRIDS=None, Z_FIELD=None, Z_SCALE=None, V_FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TARGET_USER_ZSIZE=None, TARGET_USER_ZMIN=None, TARGET_USER_ZMAX=None, TARGET_USER_ZNUM=None, Verbose=2):
     '''
     Nearest Neighbour (3D)
     ----------
@@ -342,6 +342,7 @@ def Nearest_Neighbour_3D(POINTS=None, TARGET_TEMPLATE=None, GRIDS=None, Z_FIELD=
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - TARGET_USER_ZSIZE [`floating point number`] : Cellsize. Minimum: 0.000000 Default: 1.000000
@@ -370,6 +371,7 @@ def Nearest_Neighbour_3D(POINTS=None, TARGET_TEMPLATE=None, GRIDS=None, Z_FIELD=
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('TARGET_USER_ZSIZE', TARGET_USER_ZSIZE)
@@ -379,7 +381,7 @@ def Nearest_Neighbour_3D(POINTS=None, TARGET_TEMPLATE=None, GRIDS=None, Z_FIELD=
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_grids_tools_5(POINTS=None, TARGET_TEMPLATE=None, GRIDS=None, Z_FIELD=None, Z_SCALE=None, V_FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TARGET_USER_ZSIZE=None, TARGET_USER_ZMIN=None, TARGET_USER_ZMAX=None, TARGET_USER_ZNUM=None, Verbose=2):
+def run_tool_grids_tools_5(POINTS=None, TARGET_TEMPLATE=None, GRIDS=None, Z_FIELD=None, Z_SCALE=None, V_FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TARGET_USER_ZSIZE=None, TARGET_USER_ZMIN=None, TARGET_USER_ZMAX=None, TARGET_USER_ZNUM=None, Verbose=2):
     '''
     Nearest Neighbour (3D)
     ----------
@@ -401,6 +403,7 @@ def run_tool_grids_tools_5(POINTS=None, TARGET_TEMPLATE=None, GRIDS=None, Z_FIEL
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - TARGET_USER_ZSIZE [`floating point number`] : Cellsize. Minimum: 0.000000 Default: 1.000000
@@ -429,6 +432,7 @@ def run_tool_grids_tools_5(POINTS=None, TARGET_TEMPLATE=None, GRIDS=None, Z_FIEL
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('TARGET_USER_ZSIZE', TARGET_USER_ZSIZE)
@@ -438,7 +442,7 @@ def run_tool_grids_tools_5(POINTS=None, TARGET_TEMPLATE=None, GRIDS=None, Z_FIEL
         return Tool.Execute(Verbose)
     return False
 
-def Inverse_Distance_Weighted_3D(POINTS=None, TARGET_TEMPLATE=None, GRIDS=None, Z_FIELD=None, Z_SCALE=None, V_FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TARGET_USER_ZSIZE=None, TARGET_USER_ZMIN=None, TARGET_USER_ZMAX=None, TARGET_USER_ZNUM=None, SEARCH_RANGE=None, SEARCH_RADIUS=None, SEARCH_POINTS_ALL=None, SEARCH_POINTS_MIN=None, SEARCH_POINTS_MAX=None, DW_WEIGHTING=None, DW_IDW_POWER=None, DW_BANDWIDTH=None, Verbose=2):
+def Inverse_Distance_Weighted_3D(POINTS=None, TARGET_TEMPLATE=None, GRIDS=None, Z_FIELD=None, Z_SCALE=None, V_FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TARGET_USER_ZSIZE=None, TARGET_USER_ZMIN=None, TARGET_USER_ZMAX=None, TARGET_USER_ZNUM=None, SEARCH_RANGE=None, SEARCH_RADIUS=None, SEARCH_POINTS_ALL=None, SEARCH_POINTS_MIN=None, SEARCH_POINTS_MAX=None, DW_WEIGHTING=None, DW_IDW_POWER=None, DW_BANDWIDTH=None, Verbose=2):
     '''
     Inverse Distance Weighted (3D)
     ----------
@@ -460,6 +464,7 @@ def Inverse_Distance_Weighted_3D(POINTS=None, TARGET_TEMPLATE=None, GRIDS=None,
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - TARGET_USER_ZSIZE [`floating point number`] : Cellsize. Minimum: 0.000000 Default: 1.000000
@@ -496,6 +501,7 @@ def Inverse_Distance_Weighted_3D(POINTS=None, TARGET_TEMPLATE=None, GRIDS=None,
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('TARGET_USER_ZSIZE', TARGET_USER_ZSIZE)
@@ -513,7 +519,7 @@ def Inverse_Distance_Weighted_3D(POINTS=None, TARGET_TEMPLATE=None, GRIDS=None,
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_grids_tools_6(POINTS=None, TARGET_TEMPLATE=None, GRIDS=None, Z_FIELD=None, Z_SCALE=None, V_FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TARGET_USER_ZSIZE=None, TARGET_USER_ZMIN=None, TARGET_USER_ZMAX=None, TARGET_USER_ZNUM=None, SEARCH_RANGE=None, SEARCH_RADIUS=None, SEARCH_POINTS_ALL=None, SEARCH_POINTS_MIN=None, SEARCH_POINTS_MAX=None, DW_WEIGHTING=None, DW_IDW_POWER=None, DW_BANDWIDTH=None, Verbose=2):
+def run_tool_grids_tools_6(POINTS=None, TARGET_TEMPLATE=None, GRIDS=None, Z_FIELD=None, Z_SCALE=None, V_FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TARGET_USER_ZSIZE=None, TARGET_USER_ZMIN=None, TARGET_USER_ZMAX=None, TARGET_USER_ZNUM=None, SEARCH_RANGE=None, SEARCH_RADIUS=None, SEARCH_POINTS_ALL=None, SEARCH_POINTS_MIN=None, SEARCH_POINTS_MAX=None, DW_WEIGHTING=None, DW_IDW_POWER=None, DW_BANDWIDTH=None, Verbose=2):
     '''
     Inverse Distance Weighted (3D)
     ----------
@@ -535,6 +541,7 @@ def run_tool_grids_tools_6(POINTS=None, TARGET_TEMPLATE=None, GRIDS=None, Z_FIEL
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - TARGET_USER_ZSIZE [`floating point number`] : Cellsize. Minimum: 0.000000 Default: 1.000000
@@ -571,6 +578,7 @@ def run_tool_grids_tools_6(POINTS=None, TARGET_TEMPLATE=None, GRIDS=None, Z_FIEL
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('TARGET_USER_ZSIZE', TARGET_USER_ZSIZE)
