@@ -30,7 +30,7 @@ def Maximum_Entropy_Classification(TRAINING=None, FEATURES_NUM=None, FEATURES_CA
     - PROB [`output grid`] : Probability
     - PROBS [`output grid list`] : Probabilities
     - FIELD [`table field`] : Class Name
-    - PROBS_CREATE [`boolean`] : Create Propabilities. Default: 0
+    - PROBS_CREATE [`boolean`] : Create Probabilities. Default: 0
     - METHOD [`choice`] : Method. Available Choices: [0] Yoshimasa Tsuruoka [1] Dekang Lin Default: 0
     - YT_FILE_LOAD [`file path`] : Load from File...
     - YT_FILE_SAVE [`file path`] : Save to File...
@@ -89,7 +89,7 @@ def run_tool_imagery_maxent_0(TRAINING=None, FEATURES_NUM=None, FEATURES_CAT=Non
     - PROB [`output grid`] : Probability
     - PROBS [`output grid list`] : Probabilities
     - FIELD [`table field`] : Class Name
-    - PROBS_CREATE [`boolean`] : Create Propabilities. Default: 0
+    - PROBS_CREATE [`boolean`] : Create Probabilities. Default: 0
     - METHOD [`choice`] : Method. Available Choices: [0] Yoshimasa Tsuruoka [1] Dekang Lin Default: 0
     - YT_FILE_LOAD [`file path`] : Load from File...
     - YT_FILE_SAVE [`file path`] : Save to File...
