@@ -425,7 +425,7 @@ def Connected_Component_Labeling(INPUT=None, OUTPUT=None, NEIGHBOUR=None, Verbos
     Connected Component Labeling
     ----------
     [imagery_segmentation.5]\n
-    The tool allows one to label subsets of connected components with a unique identifier. Connected component labeling (CCL) is an operator which turns a binary image into a symbolic image in which the label assigned to each pixel is an integer uniquely identifiying the connected component to which that pixel belongs (Shapiro 1996).\n
+    The tool allows one to label subsets of connected components with a unique identifier. Connected component labeling (CCL) is an operator which turns a binary image into a symbolic image in which the label assigned to each pixel is an integer uniquely identifying the connected component to which that pixel belongs (Shapiro 1996).\n
     The tool takes a grid as input and treats it as a binary image. The foreground is defined by all cell values greater than zero, the background by NoData cells and all cell values less than one. Connectivity can be determined by analysing either a 4-connected or a 8-connected neighborhood.\n
     Arguments
     ----------
@@ -451,7 +451,7 @@ def run_tool_imagery_segmentation_5(INPUT=None, OUTPUT=None, NEIGHBOUR=None, Ver
     Connected Component Labeling
     ----------
     [imagery_segmentation.5]\n
-    The tool allows one to label subsets of connected components with a unique identifier. Connected component labeling (CCL) is an operator which turns a binary image into a symbolic image in which the label assigned to each pixel is an integer uniquely identifiying the connected component to which that pixel belongs (Shapiro 1996).\n
+    The tool allows one to label subsets of connected components with a unique identifier. Connected component labeling (CCL) is an operator which turns a binary image into a symbolic image in which the label assigned to each pixel is an integer uniquely identifying the connected component to which that pixel belongs (Shapiro 1996).\n
     The tool takes a grid as input and treats it as a binary image. The foreground is defined by all cell values greater than zero, the background by NoData cells and all cell values less than one. Connectivity can be determined by analysing either a 4-connected or a 8-connected neighborhood.\n
     Arguments
     ----------
