@@ -903,7 +903,7 @@ def Import_WRF_Geogrid_Binary_Format(GRIDS=None, FILE=None, Verbose=2):
     Import WRF Geogrid Binary Format
     ----------
     [io_grid.13]\n
-    Imports grid(s) from Weather Research and Forcasting Model (WRF) geogrid binary format.\n
+    Imports grid(s) from Weather Research and Forecasting Model (WRF) geogrid binary format.\n
     Arguments
     ----------
     - GRIDS [`output grid list`] : Grids
@@ -926,7 +926,7 @@ def run_tool_io_grid_13(GRIDS=None, FILE=None, Verbose=2):
     Import WRF Geogrid Binary Format
     ----------
     [io_grid.13]\n
-    Imports grid(s) from Weather Research and Forcasting Model (WRF) geogrid binary format.\n
+    Imports grid(s) from Weather Research and Forecasting Model (WRF) geogrid binary format.\n
     Arguments
     ----------
     - GRIDS [`output grid list`] : Grids
@@ -949,7 +949,7 @@ def Export_WRF_Geogrid_Binary_Format(GRIDS=None, FILE=None, DATATYPE=None, TYPE=
     Export WRF Geogrid Binary Format
     ----------
     [io_grid.14]\n
-    Exports grid(s) to Weather Research and Forcasting Model (WRF) geogrid binary format.\n
+    Exports grid(s) to Weather Research and Forecasting Model (WRF) geogrid binary format.\n
     Arguments
     ----------
     - GRIDS [`input grid list`] : Grids
@@ -1008,7 +1008,7 @@ def run_tool_io_grid_14(GRIDS=None, FILE=None, DATATYPE=None, TYPE=None, NAME_DI
     Export WRF Geogrid Binary Format
     ----------
     [io_grid.14]\n
-    Exports grid(s) to Weather Research and Forcasting Model (WRF) geogrid binary format.\n
+    Exports grid(s) to Weather Research and Forecasting Model (WRF) geogrid binary format.\n
     Arguments
     ----------
     - GRIDS [`input grid list`] : Grids
