@@ -1271,7 +1271,7 @@ def Export_Polygons_to_HTML_Image_Map(POLYGONS=None, LINK=None, TITLE=None, IMAG
     [io_shapes.22]\n
     Tool to create an HTML ImageMap with polygon dataset and image. The tool requires a polygon dataset and an georeferenced image file. It outputs an html file for possible further editing. The image name in the mapfile html is hard coded to be map.png.\n
     [How to build the link:]\n
-    (-) [Link] Select link identfier from the attribute table of the polygon data layer.\n
+    (-) [Link] Select link identifier from the attribute table of the polygon data layer.\n
     (-) [Prefix] Adds a prefix to the link identifier. If just for icon with alternative text and, add ''#'').\n
     (-) [Suffix] Adds a suffix of the link identifier. Likewise ''.txt, .html, .doc, .png''.\n
     The link will be built with the pattern ''Prefix + Identifier + Suffix''.\n
@@ -1313,7 +1313,7 @@ def run_tool_io_shapes_22(POLYGONS=None, LINK=None, TITLE=None, IMAGE=None, FILE
     [io_shapes.22]\n
     Tool to create an HTML ImageMap with polygon dataset and image. The tool requires a polygon dataset and an georeferenced image file. It outputs an html file for possible further editing. The image name in the mapfile html is hard coded to be map.png.\n
     [How to build the link:]\n
-    (-) [Link] Select link identfier from the attribute table of the polygon data layer.\n
+    (-) [Link] Select link identifier from the attribute table of the polygon data layer.\n
     (-) [Prefix] Adds a prefix to the link identifier. If just for icon with alternative text and, add ''#'').\n
     (-) [Suffix] Adds a suffix of the link identifier. Likewise ''.txt, .html, .doc, .png''.\n
     The link will be built with the pattern ''Prefix + Identifier + Suffix''.\n
