@@ -269,7 +269,7 @@ def Get_Grid_from_Virtual_Point_Cloud(AOI_SHP=None, AOI_GRID=None, GRID_OUT=None
     - FILEPATH [`file path`] : Optional Output Filepath. The full path to which the output(s) should be written. Leave empty to output the datasets as grid list.
     - ATTR_FIELD_GRID [`integer number`] : Attribute Field to Grid. Minimum: 3 Default: 1 The attribute field to grid. Field numbers start with 1, so elevation is attribute field 3.
     - CELL_SIZE [`floating point number`] : Cellsize. Minimum: 0.001000 Default: 1.000000 Cellsize of the output grid [map units]
-    - GRID_SYSTEM_FIT [`choice`] : Grid System Fit. Available Choices: [0] nodes [1] cells Default: 1 Choose how to align the ouput grid system to the AOI
+    - GRID_SYSTEM_FIT [`choice`] : Grid System Fit. Available Choices: [0] nodes [1] cells Default: 1 Choose how to align the output grid system to the AOI
     - METHOD [`choice`] : Aggregation. Available Choices: [0] lowest [1] highest Default: 1 Choose how to aggregate the values
     - CONSTRAIN_QUERY [`boolean`] : Constrain Query. Default: 0 Check this parameter to constrain the query by an attribute range.
     - ATTR_FIELD [`integer number`] : Attribute Field. Minimum: 1 Default: 1 The attribute field to use as constraint. Field numbers start with 1.
@@ -330,7 +330,7 @@ def run_tool_io_virtual_4(AOI_SHP=None, AOI_GRID=None, GRID_OUT=None, FILENAME=N
     - FILEPATH [`file path`] : Optional Output Filepath. The full path to which the output(s) should be written. Leave empty to output the datasets as grid list.
     - ATTR_FIELD_GRID [`integer number`] : Attribute Field to Grid. Minimum: 3 Default: 1 The attribute field to grid. Field numbers start with 1, so elevation is attribute field 3.
     - CELL_SIZE [`floating point number`] : Cellsize. Minimum: 0.001000 Default: 1.000000 Cellsize of the output grid [map units]
-    - GRID_SYSTEM_FIT [`choice`] : Grid System Fit. Available Choices: [0] nodes [1] cells Default: 1 Choose how to align the ouput grid system to the AOI
+    - GRID_SYSTEM_FIT [`choice`] : Grid System Fit. Available Choices: [0] nodes [1] cells Default: 1 Choose how to align the output grid system to the AOI
     - METHOD [`choice`] : Aggregation. Available Choices: [0] lowest [1] highest Default: 1 Choose how to aggregate the values
     - CONSTRAIN_QUERY [`boolean`] : Constrain Query. Default: 0 Check this parameter to constrain the query by an attribute range.
     - ATTR_FIELD [`integer number`] : Attribute Field. Minimum: 1 Default: 1 The attribute field to use as constraint. Field numbers start with 1.
