@@ -19,7 +19,7 @@ def Rectify_Grid(REF_SOURCE=None, GRID=None, REF_TARGET=None, TARGET_TEMPLATE=No
     Rectify Grid
     ----------
     [pj_georeference.1]\n
-    Georeferencing and rectification for grids. Either choose the attribute fields (x/y) with the projected coordinates for the reference points (origin) or supply an additional points layer with correspondend points in the target projection.\n
+    Georeferencing and rectification for grids. Either choose the attribute fields (x/y) with the projected coordinates for the reference points (origin) or supply an additional points layer with correspondent points in the target projection.\n
     Arguments
     ----------
     - REF_SOURCE [`input shapes`] : Reference Points (Origin)
@@ -86,7 +86,7 @@ def run_tool_pj_georeference_1(REF_SOURCE=None, GRID=None, REF_TARGET=None, TARG
     Rectify Grid
     ----------
     [pj_georeference.1]\n
-    Georeferencing and rectification for grids. Either choose the attribute fields (x/y) with the projected coordinates for the reference points (origin) or supply an additional points layer with correspondend points in the target projection.\n
+    Georeferencing and rectification for grids. Either choose the attribute fields (x/y) with the projected coordinates for the reference points (origin) or supply an additional points layer with correspondent points in the target projection.\n
     Arguments
     ----------
     - REF_SOURCE [`input shapes`] : Reference Points (Origin)
@@ -153,7 +153,7 @@ def Warping_Shapes(REF_SOURCE=None, INPUT=None, REF_TARGET=None, OUTPUT=None, XF
     Warping Shapes
     ----------
     [pj_georeference.2]\n
-    Georeferencing of shapes layers. Either choose the attribute fields (x/y) with the projected coordinates for the reference points (origin) or supply a additional points layer with correspondend points in the target projection.\n
+    Georeferencing of shapes layers. Either choose the attribute fields (x/y) with the projected coordinates for the reference points (origin) or supply a additional points layer with correspondent points in the target projection.\n
     Arguments
     ----------
     - REF_SOURCE [`input shapes`] : Reference Points (Origin)
@@ -188,7 +188,7 @@ def run_tool_pj_georeference_2(REF_SOURCE=None, INPUT=None, REF_TARGET=None, OUT
     Warping Shapes
     ----------
     [pj_georeference.2]\n
-    Georeferencing of shapes layers. Either choose the attribute fields (x/y) with the projected coordinates for the reference points (origin) or supply a additional points layer with correspondend points in the target projection.\n
+    Georeferencing of shapes layers. Either choose the attribute fields (x/y) with the projected coordinates for the reference points (origin) or supply a additional points layer with correspondent points in the target projection.\n
     Arguments
     ----------
     - REF_SOURCE [`input shapes`] : Reference Points (Origin)
@@ -671,7 +671,7 @@ def Rectify_Grid_List(REF_SOURCE=None, GRIDS=None, REF_TARGET=None, TARGET_TEMPL
     Rectify Grid List
     ----------
     [pj_georeference.10]\n
-    Georeferencing and rectification for grids. Either choose the attribute fields (x/y) with the projected coordinates for the reference points (origin) or supply an additional points layer with correspondend points in the target projection.\n
+    Georeferencing and rectification for grids. Either choose the attribute fields (x/y) with the projected coordinates for the reference points (origin) or supply an additional points layer with correspondent points in the target projection.\n
     Arguments
     ----------
     - REF_SOURCE [`input shapes`] : Reference Points (Origin)
@@ -738,7 +738,7 @@ def run_tool_pj_georeference_10(REF_SOURCE=None, GRIDS=None, REF_TARGET=None, TA
     Rectify Grid List
     ----------
     [pj_georeference.10]\n
-    Georeferencing and rectification for grids. Either choose the attribute fields (x/y) with the projected coordinates for the reference points (origin) or supply an additional points layer with correspondend points in the target projection.\n
+    Georeferencing and rectification for grids. Either choose the attribute fields (x/y) with the projected coordinates for the reference points (origin) or supply an additional points layer with correspondent points in the target projection.\n
     Arguments
     ----------
     - REF_SOURCE [`input shapes`] : Reference Points (Origin)
