@@ -26,7 +26,7 @@ def Point_Cloud_Cutter(POINTS=None, EXTENT=None, POLYGONS=None, CUT=None, AREA=N
     - POINTS [`input point cloud list`] : Points. One or several input point cloud datasets to cut.
     - EXTENT [`input shapes`] : Shapes Extent
     - POLYGONS [`input shapes`] : Polygons
-    - CUT [`output point cloud list`] : Cut. The cutted output point cloud dataset(s).
+    - CUT [`output point cloud list`] : Cut. The cut output point cloud dataset(s).
     - AREA [`choice`] : Choose Cut from .... Available Choices: [0] User Defined Extent [1] Grid System Extent [2] Shapes Extent [3] Polygons Default: 0
     - INVERSE [`boolean`] : Inverse. Default: 0 Invert selection.
     - XMIN [`floating point number`] : Left. Default: 0.000000
@@ -68,7 +68,7 @@ def run_tool_pointcloud_tools_0(POINTS=None, EXTENT=None, POLYGONS=None, CUT=Non
     - POINTS [`input point cloud list`] : Points. One or several input point cloud datasets to cut.
     - EXTENT [`input shapes`] : Shapes Extent
     - POLYGONS [`input shapes`] : Polygons
-    - CUT [`output point cloud list`] : Cut. The cutted output point cloud dataset(s).
+    - CUT [`output point cloud list`] : Cut. The cut output point cloud dataset(s).
     - AREA [`choice`] : Choose Cut from .... Available Choices: [0] User Defined Extent [1] Grid System Extent [2] Shapes Extent [3] Polygons Default: 0
     - INVERSE [`boolean`] : Inverse. Default: 0 Invert selection.
     - XMIN [`floating point number`] : Left. Default: 0.000000
