@@ -145,7 +145,7 @@ def Line_Properties(LINES=None, OUTPUT=None, BPARTS=None, BPOINTS=None, BLENGTH=
     Arguments
     ----------
     - LINES [`input shapes`] : Lines
-    - OUTPUT [`output shapes`] : Lines with Property Attributes. If not set property attributes will be added to the orignal layer.
+    - OUTPUT [`output shapes`] : Lines with Property Attributes. If not set property attributes will be added to the original layer.
     - BPARTS [`boolean`] : Number of Parts. Default: 0
     - BPOINTS [`boolean`] : Number of Vertices. Default: 0
     - BLENGTH [`boolean`] : Length. Default: 1
@@ -174,7 +174,7 @@ def run_tool_shapes_lines_2(LINES=None, OUTPUT=None, BPARTS=None, BPOINTS=None,
     Arguments
     ----------
     - LINES [`input shapes`] : Lines
-    - OUTPUT [`output shapes`] : Lines with Property Attributes. If not set property attributes will be added to the orignal layer.
+    - OUTPUT [`output shapes`] : Lines with Property Attributes. If not set property attributes will be added to the original layer.
     - BPARTS [`boolean`] : Number of Parts. Default: 0
     - BPOINTS [`boolean`] : Number of Vertices. Default: 0
     - BLENGTH [`boolean`] : Length. Default: 1
@@ -262,7 +262,7 @@ def Line_Simplification(LINES=None, OUTPUT=None, TOLERANCE=None, Verbose=2):
     ----------
     [shapes_lines.4]\n
     Line simplification implementing the Ramer-Douglas-Peucker algorithm.\n
-    Refererences:\n
+    References:\n
     - Ramer, U. (1972): An iterative procedure for the polygonal approximation of plane curves. Computer Graphics and Image Processing, 1(3), 244-256\n
     - Douglas, D., Peucker, T. (1973): Algorithms for the reduction of the number of points required to represent a digitized line or its caricature. The Canadian Cartographer 10(2), 112-122\n
     - Polyline Reduction source code at [mappinghacks.com](http://mappinghacks.com/code/PolyLineReduction/)\n
@@ -291,7 +291,7 @@ def run_tool_shapes_lines_4(LINES=None, OUTPUT=None, TOLERANCE=None, Verbose=2):
     ----------
     [shapes_lines.4]\n
     Line simplification implementing the Ramer-Douglas-Peucker algorithm.\n
-    Refererences:\n
+    References:\n
     - Ramer, U. (1972): An iterative procedure for the polygonal approximation of plane curves. Computer Graphics and Image Processing, 1(3), 244-256\n
     - Douglas, D., Peucker, T. (1973): Algorithms for the reduction of the number of points required to represent a digitized line or its caricature. The Canadian Cartographer 10(2), 112-122\n
     - Polyline Reduction source code at [mappinghacks.com](http://mappinghacks.com/code/PolyLineReduction/)\n
