@@ -77,7 +77,7 @@ def Polygon_Properties(POLYGONS=None, OUTPUT=None, FIELDS=None, BPARTS=None, BPO
     Arguments
     ----------
     - POLYGONS [`input shapes`] : Polygons
-    - OUTPUT [`output shapes`] : Polygons with Property Attributes. If not set property attributes will be added to the orignal layer.
+    - OUTPUT [`output shapes`] : Polygons with Property Attributes. If not set property attributes will be added to the original layer.
     - FIELDS [`table fields`] : Copy Attributes. Select one or more attributes to be copied to the target layer.
     - BPARTS [`boolean`] : Number of Parts. Default: 0
     - BPOINTS [`boolean`] : Number of Vertices. Default: 0
@@ -116,7 +116,7 @@ def run_tool_shapes_polygons_2(POLYGONS=None, OUTPUT=None, FIELDS=None, BPARTS=N
     Arguments
     ----------
     - POLYGONS [`input shapes`] : Polygons
-    - OUTPUT [`output shapes`] : Polygons with Property Attributes. If not set property attributes will be added to the orignal layer.
+    - OUTPUT [`output shapes`] : Polygons with Property Attributes. If not set property attributes will be added to the original layer.
     - FIELDS [`table fields`] : Copy Attributes. Select one or more attributes to be copied to the target layer.
     - BPARTS [`boolean`] : Number of Parts. Default: 0
     - BPOINTS [`boolean`] : Number of Vertices. Default: 0
@@ -835,7 +835,7 @@ def Intersect(A=None, B=None, RESULT=None, SPLIT=None, Verbose=2):
     Intersect
     ----------
     [shapes_polygons.14]\n
-    Calculates the geometric intersection of the overlayed polygon layers, i.e. layer A and layer B.\n
+    Calculates the geometric intersection of the overlaid polygon layers, i.e. layer A and layer B.\n
     Uses the free and open source software library [Clipper] created by Angus Johnson.\n
     [Clipper Homepage](http://www.angusj.com/delphi/clipper.php)\n
     [Clipper at SourceForge](http://sourceforge.net/projects/polyclipping/)\n
@@ -865,7 +865,7 @@ def run_tool_shapes_polygons_14(A=None, B=None, RESULT=None, SPLIT=None, Verbose
     Intersect
     ----------
     [shapes_polygons.14]\n
-    Calculates the geometric intersection of the overlayed polygon layers, i.e. layer A and layer B.\n
+    Calculates the geometric intersection of the overlaid polygon layers, i.e. layer A and layer B.\n
     Uses the free and open source software library [Clipper] created by Angus Johnson.\n
     [Clipper Homepage](http://www.angusj.com/delphi/clipper.php)\n
     [Clipper at SourceForge](http://sourceforge.net/projects/polyclipping/)\n
@@ -895,7 +895,7 @@ def Difference(A=None, B=None, RESULT=None, SPLIT=None, Verbose=2):
     Difference
     ----------
     [shapes_polygons.15]\n
-    Calculates the geometric difference of the overlayed polygon layers, i.e. layer A less layer B. Sometimes referred to as 'Erase' command.\n
+    Calculates the geometric difference of the overlaid polygon layers, i.e. layer A less layer B. Sometimes referred to as 'Erase' command.\n
     Uses the free and open source software library [Clipper] created by Angus Johnson.\n
     [Clipper Homepage](http://www.angusj.com/delphi/clipper.php)\n
     [Clipper at SourceForge](http://sourceforge.net/projects/polyclipping/)\n
@@ -925,7 +925,7 @@ def run_tool_shapes_polygons_15(A=None, B=None, RESULT=None, SPLIT=None, Verbose
     Difference
     ----------
     [shapes_polygons.15]\n
-    Calculates the geometric difference of the overlayed polygon layers, i.e. layer A less layer B. Sometimes referred to as 'Erase' command.\n
+    Calculates the geometric difference of the overlaid polygon layers, i.e. layer A less layer B. Sometimes referred to as 'Erase' command.\n
     Uses the free and open source software library [Clipper] created by Angus Johnson.\n
     [Clipper Homepage](http://www.angusj.com/delphi/clipper.php)\n
     [Clipper at SourceForge](http://sourceforge.net/projects/polyclipping/)\n
@@ -955,7 +955,7 @@ def Symmetrical_Difference(A=None, B=None, RESULT=None, SPLIT=None, Verbose=2):
     Symmetrical Difference
     ----------
     [shapes_polygons.16]\n
-    Calculates the symmetrical geometric difference of the overlayed polygon layers, i.e. layer A less layer B plus layer B less layer A.\n
+    Calculates the symmetrical geometric difference of the overlaid polygon layers, i.e. layer A less layer B plus layer B less layer A.\n
     Uses the free and open source software library [Clipper] created by Angus Johnson.\n
     [Clipper Homepage](http://www.angusj.com/delphi/clipper.php)\n
     [Clipper at SourceForge](http://sourceforge.net/projects/polyclipping/)\n
@@ -985,7 +985,7 @@ def run_tool_shapes_polygons_16(A=None, B=None, RESULT=None, SPLIT=None, Verbose
     Symmetrical Difference
     ----------
     [shapes_polygons.16]\n
-    Calculates the symmetrical geometric difference of the overlayed polygon layers, i.e. layer A less layer B plus layer B less layer A.\n
+    Calculates the symmetrical geometric difference of the overlaid polygon layers, i.e. layer A less layer B plus layer B less layer A.\n
     Uses the free and open source software library [Clipper] created by Angus Johnson.\n
     [Clipper Homepage](http://www.angusj.com/delphi/clipper.php)\n
     [Clipper at SourceForge](http://sourceforge.net/projects/polyclipping/)\n
@@ -1015,7 +1015,7 @@ def Union(A=None, B=None, RESULT=None, SPLIT=None, Verbose=2):
     Union
     ----------
     [shapes_polygons.17]\n
-    Calculates the geometric union of the overlayed polygon layers, i.e. the intersection plus the symmetrical difference of layers A and B.\n
+    Calculates the geometric union of the overlaid polygon layers, i.e. the intersection plus the symmetrical difference of layers A and B.\n
     Uses the free and open source software library [Clipper] created by Angus Johnson.\n
     [Clipper Homepage](http://www.angusj.com/delphi/clipper.php)\n
     [Clipper at SourceForge](http://sourceforge.net/projects/polyclipping/)\n
@@ -1045,7 +1045,7 @@ def run_tool_shapes_polygons_17(A=None, B=None, RESULT=None, SPLIT=None, Verbose
     Union
     ----------
     [shapes_polygons.17]\n
-    Calculates the geometric union of the overlayed polygon layers, i.e. the intersection plus the symmetrical difference of layers A and B.\n
+    Calculates the geometric union of the overlaid polygon layers, i.e. the intersection plus the symmetrical difference of layers A and B.\n
     Uses the free and open source software library [Clipper] created by Angus Johnson.\n
     [Clipper Homepage](http://www.angusj.com/delphi/clipper.php)\n
     [Clipper at SourceForge](http://sourceforge.net/projects/polyclipping/)\n
@@ -1420,6 +1420,52 @@ def run_tool_shapes_polygons_23(POLYGONS=None, GENERALIZED=None, THRESHOLD=None,
         return Tool.Execute(Verbose)
     return False
 
+def Invert_Ring_Ordering(POLYGONS=None, INVERTED=None, Verbose=2):
+    '''
+    Invert Ring Ordering
+    ----------
+    [shapes_polygons.24]\n
+    The tool allows one to invert the ring ordering of polygons, i.e. to change their orientation.\n
+    Arguments
+    ----------
+    - POLYGONS [`input shapes`] : Polygons. The input polygon shapes layer.
+    - INVERTED [`output shapes`] : Inverted Polygons. The polygon shapes layer with the inverted ring ordering.
+
+    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
+    Returns
+    ----------
+    `boolean` : `True` on success, `False` on failure.
+    '''
+    Tool = Tool_Wrapper('shapes_polygons', '24', 'Invert Ring Ordering')
+    if Tool.is_Okay():
+        Tool.Set_Input ('POLYGONS', POLYGONS)
+        Tool.Set_Output('INVERTED', INVERTED)
+        return Tool.Execute(Verbose)
+    return False
+
+def run_tool_shapes_polygons_24(POLYGONS=None, INVERTED=None, Verbose=2):
+    '''
+    Invert Ring Ordering
+    ----------
+    [shapes_polygons.24]\n
+    The tool allows one to invert the ring ordering of polygons, i.e. to change their orientation.\n
+    Arguments
+    ----------
+    - POLYGONS [`input shapes`] : Polygons. The input polygon shapes layer.
+    - INVERTED [`output shapes`] : Inverted Polygons. The polygon shapes layer with the inverted ring ordering.
+
+    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
+    Returns
+    ----------
+    `boolean` : `True` on success, `False` on failure.
+    '''
+    Tool = Tool_Wrapper('shapes_polygons', '24', 'Invert Ring Ordering')
+    if Tool.is_Okay():
+        Tool.Set_Input ('POLYGONS', POLYGONS)
+        Tool.Set_Output('INVERTED', INVERTED)
+        return Tool.Execute(Verbose)
+    return False
+
 def Total_Length_of_Lines_per_Polygon(POLYGONS=None, LINES=None, Verbose=2):
     '''
     Total Length of Lines per Polygon
