@@ -180,22 +180,25 @@ def run_tool_shapes_tools_2(INPUT=None, MERGED=None, SRCINFO=None, MATCH=None, D
         return Tool.Execute(Verbose)
     return False
 
-def Select_by_Attributes_Numerical_Expression(SHAPES=None, FIELD=None, EXPRESSION=None, USE_NODATA=None, METHOD=None, Verbose=2):
+def Select_by_Attributes_Numerical_Expression(SHAPES=None, COPY=None, FIELD=None, EXPRESSION=None, INVERSE=None, USE_NODATA=None, METHOD=None, POSTJOB=None, Verbose=2):
     '''
     Select by Attributes... (Numerical Expression)
     ----------
     [shapes_tools.3]\n
-    Selects records for which the expression evaluates to non-zero. The expression syntax is the same as the one for the table calculator. If an attribute field is selected, the expression evaluates only this attribute, which can be addressed with the letter 'a' in the expression formula. If no attribute is selected, attributes are addressed by the character 'f' (for 'field') followed by the field number (i.e.: f1, f2, ..., fn) or by the field name in square brackets (e.g.: [Field Name]).\n
+    Selects records for which the expression evaluates to non-zero. The expression syntax is the same as the one for the table calculator. If an attribute field is selected, the expression evaluates only this attribute, which can be addressed with the letter 'x' in the expression formula. If no attribute is selected, attributes are addressed by the character 'f' (for 'field') followed by the field number (i.e.: f1, f2, ..., fn) or by the field in quota (e.g.: "Field Name").\n
     Examples:\n
-    - f1 > f2\n
-    - eq([Population] * 2, [Area])\n
+    (-) f1 > f2\n
+    (-) eq("Population" * 0.001, "Area")\n
     Arguments
     ----------
     - SHAPES [`input shapes`] : Shapes
-    - FIELD [`table field`] : Attribute. attribute to be evaluated by expression ('a'); if not set all attributes can be addressed (f1, f2, ..., fn).
-    - EXPRESSION [`text`] : Expression. Default: a > 0
+    - COPY [`output shapes`] : Copy
+    - FIELD [`table field`] : Attribute. attribute to be evaluated by expression ('x'); if not set all attributes can be addressed (f1, f2, ..., fn).
+    - EXPRESSION [`text`] : Expression. Default: f1 > 0
+    - INVERSE [`boolean`] : Inverse. Default: 0
     - USE_NODATA [`boolean`] : Use No-Data. Default: 0
     - METHOD [`choice`] : Method. Available Choices: [0] new selection [1] add to current selection [2] select from current selection [3] remove from current selection Default: 0
+    - POSTJOB [`choice`] : Post Job. Available Choices: [0] none [1] copy [2] move [3] delete Default: 0
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
     Returns
@@ -205,29 +208,35 @@ def Select_by_Attributes_Numerical_Expression(SHAPES=None, FIELD=None, EXPRESSIO
     Tool = Tool_Wrapper('shapes_tools', '3', 'Select by Attributes... (Numerical Expression)')
     if Tool.is_Okay():
         Tool.Set_Input ('SHAPES', SHAPES)
+        Tool.Set_Output('COPY', COPY)
         Tool.Set_Option('FIELD', FIELD)
         Tool.Set_Option('EXPRESSION', EXPRESSION)
+        Tool.Set_Option('INVERSE', INVERSE)
         Tool.Set_Option('USE_NODATA', USE_NODATA)
         Tool.Set_Option('METHOD', METHOD)
+        Tool.Set_Option('POSTJOB', POSTJOB)
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_tools_3(SHAPES=None, FIELD=None, EXPRESSION=None, USE_NODATA=None, METHOD=None, Verbose=2):
+def run_tool_shapes_tools_3(SHAPES=None, COPY=None, FIELD=None, EXPRESSION=None, INVERSE=None, USE_NODATA=None, METHOD=None, POSTJOB=None, Verbose=2):
     '''
     Select by Attributes... (Numerical Expression)
     ----------
     [shapes_tools.3]\n
-    Selects records for which the expression evaluates to non-zero. The expression syntax is the same as the one for the table calculator. If an attribute field is selected, the expression evaluates only this attribute, which can be addressed with the letter 'a' in the expression formula. If no attribute is selected, attributes are addressed by the character 'f' (for 'field') followed by the field number (i.e.: f1, f2, ..., fn) or by the field name in square brackets (e.g.: [Field Name]).\n
+    Selects records for which the expression evaluates to non-zero. The expression syntax is the same as the one for the table calculator. If an attribute field is selected, the expression evaluates only this attribute, which can be addressed with the letter 'x' in the expression formula. If no attribute is selected, attributes are addressed by the character 'f' (for 'field') followed by the field number (i.e.: f1, f2, ..., fn) or by the field in quota (e.g.: "Field Name").\n
     Examples:\n
-    - f1 > f2\n
-    - eq([Population] * 2, [Area])\n
+    (-) f1 > f2\n
+    (-) eq("Population" * 0.001, "Area")\n
     Arguments
     ----------
     - SHAPES [`input shapes`] : Shapes
-    - FIELD [`table field`] : Attribute. attribute to be evaluated by expression ('a'); if not set all attributes can be addressed (f1, f2, ..., fn).
-    - EXPRESSION [`text`] : Expression. Default: a > 0
+    - COPY [`output shapes`] : Copy
+    - FIELD [`table field`] : Attribute. attribute to be evaluated by expression ('x'); if not set all attributes can be addressed (f1, f2, ..., fn).
+    - EXPRESSION [`text`] : Expression. Default: f1 > 0
+    - INVERSE [`boolean`] : Inverse. Default: 0
     - USE_NODATA [`boolean`] : Use No-Data. Default: 0
     - METHOD [`choice`] : Method. Available Choices: [0] new selection [1] add to current selection [2] select from current selection [3] remove from current selection Default: 0
+    - POSTJOB [`choice`] : Post Job. Available Choices: [0] none [1] copy [2] move [3] delete Default: 0
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
     Returns
@@ -237,14 +246,17 @@ def run_tool_shapes_tools_3(SHAPES=None, FIELD=None, EXPRESSION=None, USE_NODATA
     Tool = Tool_Wrapper('shapes_tools', '3', 'Select by Attributes... (Numerical Expression)')
     if Tool.is_Okay():
         Tool.Set_Input ('SHAPES', SHAPES)
+        Tool.Set_Output('COPY', COPY)
         Tool.Set_Option('FIELD', FIELD)
         Tool.Set_Option('EXPRESSION', EXPRESSION)
+        Tool.Set_Option('INVERSE', INVERSE)
         Tool.Set_Option('USE_NODATA', USE_NODATA)
         Tool.Set_Option('METHOD', METHOD)
+        Tool.Set_Option('POSTJOB', POSTJOB)
         return Tool.Execute(Verbose)
     return False
 
-def Select_by_Attributes_String_Expression(SHAPES=None, FIELD=None, EXPRESSION=None, CASE=None, COMPARE=None, METHOD=None, Verbose=2):
+def Select_by_Attributes_String_Expression(SHAPES=None, COPY=None, FIELD=None, EXPRESSION=None, CASE=None, COMPARE=None, INVERSE=None, METHOD=None, POSTJOB=None, Verbose=2):
     '''
     Select by Attributes... (String Expression)
     ----------
@@ -253,11 +265,14 @@ def Select_by_Attributes_String_Expression(SHAPES=None, FIELD=None, EXPRESSION=N
     Arguments
     ----------
     - SHAPES [`input shapes`] : Shapes
+    - COPY [`output shapes`] : Copy
     - FIELD [`table field`] : Attribute. attribute to be searched; if not set all attributes will be searched
     - EXPRESSION [`text`] : Expression
     - CASE [`boolean`] : Case Sensitive. Default: 1
     - COMPARE [`choice`] : Select if.... Available Choices: [0] attribute is identical with search expression [1] attribute contains search expression [2] attribute is contained in search expression Default: 1
+    - INVERSE [`boolean`] : Inverse. Default: 0
     - METHOD [`choice`] : Method. Available Choices: [0] new selection [1] add to current selection [2] select from current selection [3] remove from current selection Default: 0
+    - POSTJOB [`choice`] : Post Job. Available Choices: [0] none [1] copy [2] move [3] delete Default: 0
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
     Returns
@@ -267,15 +282,18 @@ def Select_by_Attributes_String_Expression(SHAPES=None, FIELD=None, EXPRESSION=N
     Tool = Tool_Wrapper('shapes_tools', '4', 'Select by Attributes... (String Expression)')
     if Tool.is_Okay():
         Tool.Set_Input ('SHAPES', SHAPES)
+        Tool.Set_Output('COPY', COPY)
         Tool.Set_Option('FIELD', FIELD)
         Tool.Set_Option('EXPRESSION', EXPRESSION)
         Tool.Set_Option('CASE', CASE)
         Tool.Set_Option('COMPARE', COMPARE)
+        Tool.Set_Option('INVERSE', INVERSE)
         Tool.Set_Option('METHOD', METHOD)
+        Tool.Set_Option('POSTJOB', POSTJOB)
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_tools_4(SHAPES=None, FIELD=None, EXPRESSION=None, CASE=None, COMPARE=None, METHOD=None, Verbose=2):
+def run_tool_shapes_tools_4(SHAPES=None, COPY=None, FIELD=None, EXPRESSION=None, CASE=None, COMPARE=None, INVERSE=None, METHOD=None, POSTJOB=None, Verbose=2):
     '''
     Select by Attributes... (String Expression)
     ----------
@@ -284,11 +302,14 @@ def run_tool_shapes_tools_4(SHAPES=None, FIELD=None, EXPRESSION=None, CASE=None,
     Arguments
     ----------
     - SHAPES [`input shapes`] : Shapes
+    - COPY [`output shapes`] : Copy
     - FIELD [`table field`] : Attribute. attribute to be searched; if not set all attributes will be searched
     - EXPRESSION [`text`] : Expression
     - CASE [`boolean`] : Case Sensitive. Default: 1
     - COMPARE [`choice`] : Select if.... Available Choices: [0] attribute is identical with search expression [1] attribute contains search expression [2] attribute is contained in search expression Default: 1
+    - INVERSE [`boolean`] : Inverse. Default: 0
     - METHOD [`choice`] : Method. Available Choices: [0] new selection [1] add to current selection [2] select from current selection [3] remove from current selection Default: 0
+    - POSTJOB [`choice`] : Post Job. Available Choices: [0] none [1] copy [2] move [3] delete Default: 0
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
     Returns
@@ -298,11 +319,14 @@ def run_tool_shapes_tools_4(SHAPES=None, FIELD=None, EXPRESSION=None, CASE=None,
     Tool = Tool_Wrapper('shapes_tools', '4', 'Select by Attributes... (String Expression)')
     if Tool.is_Okay():
         Tool.Set_Input ('SHAPES', SHAPES)
+        Tool.Set_Output('COPY', COPY)
         Tool.Set_Option('FIELD', FIELD)
         Tool.Set_Option('EXPRESSION', EXPRESSION)
         Tool.Set_Option('CASE', CASE)
         Tool.Set_Option('COMPARE', COMPARE)
+        Tool.Set_Option('INVERSE', INVERSE)
         Tool.Set_Option('METHOD', METHOD)
+        Tool.Set_Option('POSTJOB', POSTJOB)
         return Tool.Execute(Verbose)
     return False
 
@@ -1255,7 +1279,7 @@ def Polar_to_Cartesian_Coordinates(POLAR=None, CARTES=None, F_EXAGG=None, D_EXAG
     Arguments
     ----------
     - POLAR [`input shapes`] : Polar Coordinates
-    - CARTES [`output shapes`] : Cartesion Coordinates
+    - CARTES [`output shapes`] : Cartesian Coordinates
     - F_EXAGG [`table field`] : Exaggeration
     - D_EXAGG [`floating point number`] : Exaggeration Factor. Default: 1.000000
     - RADIUS [`floating point number`] : Radius. Minimum: 0.000000 Default: 6371000.000000
@@ -1286,7 +1310,7 @@ def run_tool_shapes_tools_21(POLAR=None, CARTES=None, F_EXAGG=None, D_EXAGG=None
     Arguments
     ----------
     - POLAR [`input shapes`] : Polar Coordinates
-    - CARTES [`output shapes`] : Cartesion Coordinates
+    - CARTES [`output shapes`] : Cartesian Coordinates
     - F_EXAGG [`table field`] : Exaggeration
     - D_EXAGG [`floating point number`] : Exaggeration Factor. Default: 1.000000
     - RADIUS [`floating point number`] : Radius. Minimum: 0.000000 Default: 6371000.000000
@@ -1513,7 +1537,7 @@ def Land_Use_Scenario_Generator(FIELDS=None, STATISTICS=None, KNOWN_CROPS=None,
     Arguments
     ----------
     - FIELDS [`input shapes`] : Fields
-    - STATISTICS [`input table`] : Crop Statistics. The first column specifies a crop type id. The second column provides a human readible name for the crop type (e.g. 'potatoes') .The third column must be an integer value, though this value is not yet used by this tool. The following columns provide the yearly amount of each crop type [%] for a sequence of years. 
+    - STATISTICS [`input table`] : Crop Statistics. The first column specifies a crop type id. The second column provides a human readable name for the crop type (e.g. 'potatoes') .The third column must be an integer value, though this value is not yet used by this tool. The following columns provide the yearly amount of each crop type [%] for a sequence of years. 
     - KNOWN_CROPS [`optional input table`] : Known Crops. The first column specifies the field id as given by the 'Fields' layer. The following columns specify the crop type for each field and year and refer to the crop type identifiers used in the crop statistics table. The sequence of years must be identical with that of the crop statistics table.
     - SCENARIO [`output shapes`] : Land Use Scenario
     - FIELD_ID [`table field`] : Field Identifier
@@ -1544,7 +1568,7 @@ def run_tool_shapes_tools_25(FIELDS=None, STATISTICS=None, KNOWN_CROPS=None, SCE
     Arguments
     ----------
     - FIELDS [`input shapes`] : Fields
-    - STATISTICS [`input table`] : Crop Statistics. The first column specifies a crop type id. The second column provides a human readible name for the crop type (e.g. 'potatoes') .The third column must be an integer value, though this value is not yet used by this tool. The following columns provide the yearly amount of each crop type [%] for a sequence of years. 
+    - STATISTICS [`input table`] : Crop Statistics. The first column specifies a crop type id. The second column provides a human readable name for the crop type (e.g. 'potatoes') .The third column must be an integer value, though this value is not yet used by this tool. The following columns provide the yearly amount of each crop type [%] for a sequence of years. 
     - KNOWN_CROPS [`optional input table`] : Known Crops. The first column specifies the field id as given by the 'Fields' layer. The following columns specify the crop type for each field and year and refer to the crop type identifiers used in the crop statistics table. The sequence of years must be identical with that of the crop statistics table.
     - SCENARIO [`output shapes`] : Land Use Scenario
     - FIELD_ID [`table field`] : Field Identifier
