@@ -14,7 +14,7 @@ Cellular Automata
 
 from PySAGA.helper import Tool_Wrapper
 
-def Conways_Game_of_Life(TARGET_TEMPLATE=None, LIFE=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, REFRESH=None, FADECOLOR=None, Verbose=2):
+def Conways_Game_of_Life(TARGET_TEMPLATE=None, LIFE=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, REFRESH=None, FADECOLOR=None, Verbose=2):
     '''
     Conway's Game of Life
     ----------
@@ -32,6 +32,7 @@ def Conways_Game_of_Life(TARGET_TEMPLATE=None, LIFE=None, TARGET_DEFINITION=None
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - REFRESH [`choice`] : Refresh. Available Choices: [0] no refresh [1] random [2] virus 1 [3] virus 2 Default: 1
@@ -54,6 +55,7 @@ def Conways_Game_of_Life(TARGET_TEMPLATE=None, LIFE=None, TARGET_DEFINITION=None
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('REFRESH', REFRESH)
@@ -61,7 +63,7 @@ def Conways_Game_of_Life(TARGET_TEMPLATE=None, LIFE=None, TARGET_DEFINITION=None
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_sim_cellular_automata_0(TARGET_TEMPLATE=None, LIFE=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, REFRESH=None, FADECOLOR=None, Verbose=2):
+def run_tool_sim_cellular_automata_0(TARGET_TEMPLATE=None, LIFE=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, REFRESH=None, FADECOLOR=None, Verbose=2):
     '''
     Conway's Game of Life
     ----------
@@ -79,6 +81,7 @@ def run_tool_sim_cellular_automata_0(TARGET_TEMPLATE=None, LIFE=None, TARGET_DEF
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - REFRESH [`choice`] : Refresh. Available Choices: [0] no refresh [1] random [2] virus 1 [3] virus 2 Default: 1
@@ -101,6 +104,7 @@ def run_tool_sim_cellular_automata_0(TARGET_TEMPLATE=None, LIFE=None, TARGET_DEF
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('REFRESH', REFRESH)
@@ -108,7 +112,7 @@ def run_tool_sim_cellular_automata_0(TARGET_TEMPLATE=None, LIFE=None, TARGET_DEF
         return Tool.Execute(Verbose)
     return False
 
-def WaTor(TARGET_TEMPLATE=None, GRID=None, TABLE=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, REFRESH=None, INIT_FISH=None, INIT_SHARK=None, FISH_BIRTH=None, SHARK_BIRTH=None, SHARK_STARVE=None, Verbose=2):
+def WaTor(TARGET_TEMPLATE=None, GRID=None, TABLE=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, REFRESH=None, INIT_FISH=None, INIT_SHARK=None, FISH_BIRTH=None, SHARK_BIRTH=None, SHARK_STARVE=None, Verbose=2):
     '''
     Wa-Tor
     ----------
@@ -127,6 +131,7 @@ def WaTor(TARGET_TEMPLATE=None, GRID=None, TABLE=None, TARGET_DEFINITION=None, T
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - REFRESH [`boolean`] : Refresh. Default: 1
@@ -154,6 +159,7 @@ def WaTor(TARGET_TEMPLATE=None, GRID=None, TABLE=None, TARGET_DEFINITION=None, T
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('REFRESH', REFRESH)
@@ -165,7 +171,7 @@ def WaTor(TARGET_TEMPLATE=None, GRID=None, TABLE=None, TARGET_DEFINITION=None, T
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_sim_cellular_automata_1(TARGET_TEMPLATE=None, GRID=None, TABLE=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, REFRESH=None, INIT_FISH=None, INIT_SHARK=None, FISH_BIRTH=None, SHARK_BIRTH=None, SHARK_STARVE=None, Verbose=2):
+def run_tool_sim_cellular_automata_1(TARGET_TEMPLATE=None, GRID=None, TABLE=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, REFRESH=None, INIT_FISH=None, INIT_SHARK=None, FISH_BIRTH=None, SHARK_BIRTH=None, SHARK_STARVE=None, Verbose=2):
     '''
     Wa-Tor
     ----------
@@ -184,6 +190,7 @@ def run_tool_sim_cellular_automata_1(TARGET_TEMPLATE=None, GRID=None, TABLE=None
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - REFRESH [`boolean`] : Refresh. Default: 1
@@ -211,6 +218,7 @@ def run_tool_sim_cellular_automata_1(TARGET_TEMPLATE=None, GRID=None, TABLE=None
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('REFRESH', REFRESH)
@@ -222,7 +230,7 @@ def run_tool_sim_cellular_automata_1(TARGET_TEMPLATE=None, GRID=None, TABLE=None
         return Tool.Execute(Verbose)
     return False
 
-def Hodgepodge_Machine(TARGET_TEMPLATE=None, GRID=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, REFRESH=None, RADIUS=None, NSTATES=None, TSICK=None, TINFECTED=None, SPEED=None, Verbose=2):
+def Hodgepodge_Machine(TARGET_TEMPLATE=None, GRID=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, REFRESH=None, RADIUS=None, NSTATES=None, TSICK=None, TINFECTED=None, SPEED=None, Verbose=2):
     '''
     Hodgepodge Machine
     ----------
@@ -240,6 +248,7 @@ def Hodgepodge_Machine(TARGET_TEMPLATE=None, GRID=None, TARGET_DEFINITION=None,
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - REFRESH [`boolean`] : Refresh. Default: 1
@@ -266,6 +275,7 @@ def Hodgepodge_Machine(TARGET_TEMPLATE=None, GRID=None, TARGET_DEFINITION=None,
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('REFRESH', REFRESH)
@@ -277,7 +287,7 @@ def Hodgepodge_Machine(TARGET_TEMPLATE=None, GRID=None, TARGET_DEFINITION=None,
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_sim_cellular_automata_2(TARGET_TEMPLATE=None, GRID=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, REFRESH=None, RADIUS=None, NSTATES=None, TSICK=None, TINFECTED=None, SPEED=None, Verbose=2):
+def run_tool_sim_cellular_automata_2(TARGET_TEMPLATE=None, GRID=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, REFRESH=None, RADIUS=None, NSTATES=None, TSICK=None, TINFECTED=None, SPEED=None, Verbose=2):
     '''
     Hodgepodge Machine
     ----------
@@ -295,6 +305,7 @@ def run_tool_sim_cellular_automata_2(TARGET_TEMPLATE=None, GRID=None, TARGET_DEF
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - REFRESH [`boolean`] : Refresh. Default: 1
@@ -321,6 +332,7 @@ def run_tool_sim_cellular_automata_2(TARGET_TEMPLATE=None, GRID=None, TARGET_DEF
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('REFRESH', REFRESH)
