@@ -425,7 +425,7 @@ def Zonal_Grid_Statistics(ZONES=None, CATLIST=None, STATLIST=None, ASPECT=None,
     [statistics_grid.5]\n
     The tool allows one to calculate zonal statistics over a set of input grids and reports the statistics in a table.\n
     The tool first creates a contingency table of unique condition units (UCUs) on which the statistics are calculated. These UCUs are delineated from a zonal grid (e.g. sub catchments) and optional categorical grids (e.g. landcover, soil, ...). The derived UCUs can be output as a grid dataset.\n
-    The tool then calculates descriptive statistics (n, min, max, mean, standard deviation and sum) for each UCU from (optional) grids with continious data (e.g. slope). A grid storing aspect must be treated specially (circular statistics), please use the "Aspect" input parameter for such a grid.\n
+    The tool then calculates descriptive statistics (n, min, max, mean, standard deviation and sum) for each UCU from (optional) grids with continuous data (e.g. slope). A grid storing aspect must be treated specially (circular statistics), please use the "Aspect" input parameter for such a grid.\n
     The tool has four different modes of operation:\n
     (1) only a zonal grid is used as input. This results in a simple contingency table with the number of grid cells in each zone.\n
     (2) a zonal grid and additional categorical grids are used as input. This results in a contingency table with the number of cells in each UCU.\n
@@ -472,7 +472,7 @@ def run_tool_statistics_grid_5(ZONES=None, CATLIST=None, STATLIST=None, ASPECT=N
     [statistics_grid.5]\n
     The tool allows one to calculate zonal statistics over a set of input grids and reports the statistics in a table.\n
     The tool first creates a contingency table of unique condition units (UCUs) on which the statistics are calculated. These UCUs are delineated from a zonal grid (e.g. sub catchments) and optional categorical grids (e.g. landcover, soil, ...). The derived UCUs can be output as a grid dataset.\n
-    The tool then calculates descriptive statistics (n, min, max, mean, standard deviation and sum) for each UCU from (optional) grids with continious data (e.g. slope). A grid storing aspect must be treated specially (circular statistics), please use the "Aspect" input parameter for such a grid.\n
+    The tool then calculates descriptive statistics (n, min, max, mean, standard deviation and sum) for each UCU from (optional) grids with continuous data (e.g. slope). A grid storing aspect must be treated specially (circular statistics), please use the "Aspect" input parameter for such a grid.\n
     The tool has four different modes of operation:\n
     (1) only a zonal grid is used as input. This results in a simple contingency table with the number of grid cells in each zone.\n
     (2) a zonal grid and additional categorical grids are used as input. This results in a contingency table with the number of cells in each UCU.\n
@@ -640,7 +640,7 @@ def Global_Morans_I_for_Grids(GRID=None, RESULT=None, CONTIGUITY=None, DIALOG=No
     ----------
     - GRID [`input grid`] : Grid
     - RESULT [`output table`] : Result
-    - CONTIGUITY [`choice`] : Case of contiguity. Available Choices: [0] Rook [1] Queen Default: 1 Choose case: Rook's case contiguity compares only cell wich share an edge. Queen's case contiguity compares also cells which share just corners.
+    - CONTIGUITY [`choice`] : Case of contiguity. Available Choices: [0] Rook [1] Queen Default: 1 Choose case: Rook's case contiguity compares only cell which share an edge. Queen's case contiguity compares also cells which share just corners.
     - DIALOG [`boolean`] : Show Result in Dialog. Default: 1
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
@@ -667,7 +667,7 @@ def run_tool_statistics_grid_7(GRID=None, RESULT=None, CONTIGUITY=None, DIALOG=N
     ----------
     - GRID [`input grid`] : Grid
     - RESULT [`output table`] : Result
-    - CONTIGUITY [`choice`] : Case of contiguity. Available Choices: [0] Rook [1] Queen Default: 1 Choose case: Rook's case contiguity compares only cell wich share an edge. Queen's case contiguity compares also cells which share just corners.
+    - CONTIGUITY [`choice`] : Case of contiguity. Available Choices: [0] Rook [1] Queen Default: 1 Choose case: Rook's case contiguity compares only cell which share an edge. Queen's case contiguity compares also cells which share just corners.
     - DIALOG [`boolean`] : Show Result in Dialog. Default: 1
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
