@@ -14,7 +14,7 @@ Kriging - tools for the geostatistical interpolation of irregularly distributed
 
 from PySAGA.helper import Tool_Wrapper
 
-def Ordinary_Kriging(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=None, VARIANCE=None, CV_SUMMARY=None, CV_RESIDUALS=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TQUALITY=None, VAR_MAXDIST=None, VAR_NCLASSES=None, VAR_NSKIP=None, VAR_MODEL=None, LOG=None, BLOCK=None, DBLOCK=None, CV_METHOD=None, CV_SAMPLES=None, SEARCH_RANGE=None, SEARCH_RADIUS=None, SEARCH_POINTS_ALL=None, SEARCH_POINTS_MIN=None, SEARCH_POINTS_MAX=None, Verbose=2):
+def Ordinary_Kriging(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=None, VARIANCE=None, CV_SUMMARY=None, CV_RESIDUALS=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TQUALITY=None, VAR_MAXDIST=None, VAR_NCLASSES=None, VAR_NSKIP=None, VAR_MODEL=None, LOG=None, BLOCK=None, DBLOCK=None, CV_METHOD=None, CV_SAMPLES=None, SEARCH_RANGE=None, SEARCH_RADIUS=None, SEARCH_POINTS_ALL=None, SEARCH_POINTS_MIN=None, SEARCH_POINTS_MAX=None, Verbose=2):
     '''
     Ordinary Kriging
     ----------
@@ -37,6 +37,7 @@ def Ordinary_Kriging(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=None, VARIANC
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - TQUALITY [`choice`] : Error Measure. Available Choices: [0] Standard Deviation [1] Variance Default: 1
@@ -77,6 +78,7 @@ def Ordinary_Kriging(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=None, VARIANC
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('TQUALITY', TQUALITY)
@@ -97,7 +99,7 @@ def Ordinary_Kriging(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=None, VARIANC
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_kriging_0(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=None, VARIANCE=None, CV_SUMMARY=None, CV_RESIDUALS=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TQUALITY=None, VAR_MAXDIST=None, VAR_NCLASSES=None, VAR_NSKIP=None, VAR_MODEL=None, LOG=None, BLOCK=None, DBLOCK=None, CV_METHOD=None, CV_SAMPLES=None, SEARCH_RANGE=None, SEARCH_RADIUS=None, SEARCH_POINTS_ALL=None, SEARCH_POINTS_MIN=None, SEARCH_POINTS_MAX=None, Verbose=2):
+def run_tool_statistics_kriging_0(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=None, VARIANCE=None, CV_SUMMARY=None, CV_RESIDUALS=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TQUALITY=None, VAR_MAXDIST=None, VAR_NCLASSES=None, VAR_NSKIP=None, VAR_MODEL=None, LOG=None, BLOCK=None, DBLOCK=None, CV_METHOD=None, CV_SAMPLES=None, SEARCH_RANGE=None, SEARCH_RADIUS=None, SEARCH_POINTS_ALL=None, SEARCH_POINTS_MIN=None, SEARCH_POINTS_MAX=None, Verbose=2):
     '''
     Ordinary Kriging
     ----------
@@ -120,6 +122,7 @@ def run_tool_statistics_kriging_0(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - TQUALITY [`choice`] : Error Measure. Available Choices: [0] Standard Deviation [1] Variance Default: 1
@@ -160,6 +163,7 @@ def run_tool_statistics_kriging_0(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('TQUALITY', TQUALITY)
@@ -180,7 +184,7 @@ def run_tool_statistics_kriging_0(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=
         return Tool.Execute(Verbose)
     return False
 
-def Simple_Kriging(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=None, VARIANCE=None, CV_SUMMARY=None, CV_RESIDUALS=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TQUALITY=None, VAR_MAXDIST=None, VAR_NCLASSES=None, VAR_NSKIP=None, VAR_MODEL=None, LOG=None, BLOCK=None, DBLOCK=None, CV_METHOD=None, CV_SAMPLES=None, SEARCH_RANGE=None, SEARCH_RADIUS=None, SEARCH_POINTS_ALL=None, SEARCH_POINTS_MIN=None, SEARCH_POINTS_MAX=None, Verbose=2):
+def Simple_Kriging(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=None, VARIANCE=None, CV_SUMMARY=None, CV_RESIDUALS=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TQUALITY=None, VAR_MAXDIST=None, VAR_NCLASSES=None, VAR_NSKIP=None, VAR_MODEL=None, LOG=None, BLOCK=None, DBLOCK=None, CV_METHOD=None, CV_SAMPLES=None, SEARCH_RANGE=None, SEARCH_RADIUS=None, SEARCH_POINTS_ALL=None, SEARCH_POINTS_MIN=None, SEARCH_POINTS_MAX=None, Verbose=2):
     '''
     Simple Kriging
     ----------
@@ -203,6 +207,7 @@ def Simple_Kriging(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=None, VARIANCE=
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - TQUALITY [`choice`] : Error Measure. Available Choices: [0] Standard Deviation [1] Variance Default: 1
@@ -243,6 +248,7 @@ def Simple_Kriging(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=None, VARIANCE=
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('TQUALITY', TQUALITY)
@@ -263,7 +269,7 @@ def Simple_Kriging(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=None, VARIANCE=
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_kriging_1(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=None, VARIANCE=None, CV_SUMMARY=None, CV_RESIDUALS=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TQUALITY=None, VAR_MAXDIST=None, VAR_NCLASSES=None, VAR_NSKIP=None, VAR_MODEL=None, LOG=None, BLOCK=None, DBLOCK=None, CV_METHOD=None, CV_SAMPLES=None, SEARCH_RANGE=None, SEARCH_RADIUS=None, SEARCH_POINTS_ALL=None, SEARCH_POINTS_MIN=None, SEARCH_POINTS_MAX=None, Verbose=2):
+def run_tool_statistics_kriging_1(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=None, VARIANCE=None, CV_SUMMARY=None, CV_RESIDUALS=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TQUALITY=None, VAR_MAXDIST=None, VAR_NCLASSES=None, VAR_NSKIP=None, VAR_MODEL=None, LOG=None, BLOCK=None, DBLOCK=None, CV_METHOD=None, CV_SAMPLES=None, SEARCH_RANGE=None, SEARCH_RADIUS=None, SEARCH_POINTS_ALL=None, SEARCH_POINTS_MIN=None, SEARCH_POINTS_MAX=None, Verbose=2):
     '''
     Simple Kriging
     ----------
@@ -286,6 +292,7 @@ def run_tool_statistics_kriging_1(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - TQUALITY [`choice`] : Error Measure. Available Choices: [0] Standard Deviation [1] Variance Default: 1
@@ -326,6 +333,7 @@ def run_tool_statistics_kriging_1(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('TQUALITY', TQUALITY)
@@ -346,7 +354,7 @@ def run_tool_statistics_kriging_1(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=
         return Tool.Execute(Verbose)
     return False
 
-def Universal_Kriging(POINTS=None, TARGET_TEMPLATE=None, PREDICTORS=None, PREDICTION=None, VARIANCE=None, CV_SUMMARY=None, CV_RESIDUALS=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TQUALITY=None, VAR_MAXDIST=None, VAR_NCLASSES=None, VAR_NSKIP=None, VAR_MODEL=None, LOG=None, BLOCK=None, DBLOCK=None, CV_METHOD=None, CV_SAMPLES=None, SEARCH_RANGE=None, SEARCH_RADIUS=None, SEARCH_POINTS_ALL=None, SEARCH_POINTS_MIN=None, SEARCH_POINTS_MAX=None, RESAMPLING=None, COORDS=None, Verbose=2):
+def Universal_Kriging(POINTS=None, TARGET_TEMPLATE=None, PREDICTORS=None, PREDICTION=None, VARIANCE=None, CV_SUMMARY=None, CV_RESIDUALS=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TQUALITY=None, VAR_MAXDIST=None, VAR_NCLASSES=None, VAR_NSKIP=None, VAR_MODEL=None, LOG=None, BLOCK=None, DBLOCK=None, CV_METHOD=None, CV_SAMPLES=None, SEARCH_RANGE=None, SEARCH_RADIUS=None, SEARCH_POINTS_ALL=None, SEARCH_POINTS_MIN=None, SEARCH_POINTS_MAX=None, RESAMPLING=None, COORDS=None, Verbose=2):
     '''
     Universal Kriging
     ----------
@@ -370,6 +378,7 @@ def Universal_Kriging(POINTS=None, TARGET_TEMPLATE=None, PREDICTORS=None, PREDIC
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - TQUALITY [`choice`] : Error Measure. Available Choices: [0] Standard Deviation [1] Variance Default: 1
@@ -413,6 +422,7 @@ def Universal_Kriging(POINTS=None, TARGET_TEMPLATE=None, PREDICTORS=None, PREDIC
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('TQUALITY', TQUALITY)
@@ -435,7 +445,7 @@ def Universal_Kriging(POINTS=None, TARGET_TEMPLATE=None, PREDICTORS=None, PREDIC
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_kriging_2(POINTS=None, TARGET_TEMPLATE=None, PREDICTORS=None, PREDICTION=None, VARIANCE=None, CV_SUMMARY=None, CV_RESIDUALS=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TQUALITY=None, VAR_MAXDIST=None, VAR_NCLASSES=None, VAR_NSKIP=None, VAR_MODEL=None, LOG=None, BLOCK=None, DBLOCK=None, CV_METHOD=None, CV_SAMPLES=None, SEARCH_RANGE=None, SEARCH_RADIUS=None, SEARCH_POINTS_ALL=None, SEARCH_POINTS_MIN=None, SEARCH_POINTS_MAX=None, RESAMPLING=None, COORDS=None, Verbose=2):
+def run_tool_statistics_kriging_2(POINTS=None, TARGET_TEMPLATE=None, PREDICTORS=None, PREDICTION=None, VARIANCE=None, CV_SUMMARY=None, CV_RESIDUALS=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TQUALITY=None, VAR_MAXDIST=None, VAR_NCLASSES=None, VAR_NSKIP=None, VAR_MODEL=None, LOG=None, BLOCK=None, DBLOCK=None, CV_METHOD=None, CV_SAMPLES=None, SEARCH_RANGE=None, SEARCH_RADIUS=None, SEARCH_POINTS_ALL=None, SEARCH_POINTS_MIN=None, SEARCH_POINTS_MAX=None, RESAMPLING=None, COORDS=None, Verbose=2):
     '''
     Universal Kriging
     ----------
@@ -459,6 +469,7 @@ def run_tool_statistics_kriging_2(POINTS=None, TARGET_TEMPLATE=None, PREDICTORS=
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - TQUALITY [`choice`] : Error Measure. Available Choices: [0] Standard Deviation [1] Variance Default: 1
@@ -502,6 +513,7 @@ def run_tool_statistics_kriging_2(POINTS=None, TARGET_TEMPLATE=None, PREDICTORS=
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('TQUALITY', TQUALITY)
@@ -752,7 +764,7 @@ def run_tool_statistics_kriging_4(POINTS=None, VARIOGRAM=None, ATTRIBUTE=None, L
         return Tool.Execute(Verbose)
     return False
 
-def Simple_Kriging_3D(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=None, VARIANCE=None, CV_SUMMARY=None, CV_RESIDUALS=None, Z_FIELD=None, Z_SCALE=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TARGET_USER_ZSIZE=None, TARGET_USER_ZMIN=None, TARGET_USER_ZMAX=None, TARGET_USER_ZNUM=None, TQUALITY=None, VAR_MAXDIST=None, VAR_NCLASSES=None, VAR_NSKIP=None, VAR_MODEL=None, LOG=None, BLOCK=None, DBLOCK=None, CV_METHOD=None, CV_SAMPLES=None, SEARCH_RANGE=None, SEARCH_RADIUS=None, SEARCH_POINTS_ALL=None, SEARCH_POINTS_MIN=None, SEARCH_POINTS_MAX=None, Verbose=2):
+def Simple_Kriging_3D(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=None, VARIANCE=None, CV_SUMMARY=None, CV_RESIDUALS=None, Z_FIELD=None, Z_SCALE=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TARGET_USER_ZSIZE=None, TARGET_USER_ZMIN=None, TARGET_USER_ZMAX=None, TARGET_USER_ZNUM=None, TQUALITY=None, VAR_MAXDIST=None, VAR_NCLASSES=None, VAR_NSKIP=None, VAR_MODEL=None, LOG=None, BLOCK=None, DBLOCK=None, CV_METHOD=None, CV_SAMPLES=None, SEARCH_RANGE=None, SEARCH_RADIUS=None, SEARCH_POINTS_ALL=None, SEARCH_POINTS_MIN=None, SEARCH_POINTS_MAX=None, Verbose=2):
     '''
     Simple Kriging (3D)
     ----------
@@ -777,6 +789,7 @@ def Simple_Kriging_3D(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=None, VARIAN
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - TARGET_USER_ZSIZE [`floating point number`] : Cellsize. Minimum: 0.000000 Default: 1.000000
@@ -823,6 +836,7 @@ def Simple_Kriging_3D(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=None, VARIAN
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('TARGET_USER_ZSIZE', TARGET_USER_ZSIZE)
@@ -847,7 +861,7 @@ def Simple_Kriging_3D(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=None, VARIAN
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_kriging_5(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=None, VARIANCE=None, CV_SUMMARY=None, CV_RESIDUALS=None, Z_FIELD=None, Z_SCALE=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TARGET_USER_ZSIZE=None, TARGET_USER_ZMIN=None, TARGET_USER_ZMAX=None, TARGET_USER_ZNUM=None, TQUALITY=None, VAR_MAXDIST=None, VAR_NCLASSES=None, VAR_NSKIP=None, VAR_MODEL=None, LOG=None, BLOCK=None, DBLOCK=None, CV_METHOD=None, CV_SAMPLES=None, SEARCH_RANGE=None, SEARCH_RADIUS=None, SEARCH_POINTS_ALL=None, SEARCH_POINTS_MIN=None, SEARCH_POINTS_MAX=None, Verbose=2):
+def run_tool_statistics_kriging_5(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=None, VARIANCE=None, CV_SUMMARY=None, CV_RESIDUALS=None, Z_FIELD=None, Z_SCALE=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TARGET_USER_ZSIZE=None, TARGET_USER_ZMIN=None, TARGET_USER_ZMAX=None, TARGET_USER_ZNUM=None, TQUALITY=None, VAR_MAXDIST=None, VAR_NCLASSES=None, VAR_NSKIP=None, VAR_MODEL=None, LOG=None, BLOCK=None, DBLOCK=None, CV_METHOD=None, CV_SAMPLES=None, SEARCH_RANGE=None, SEARCH_RADIUS=None, SEARCH_POINTS_ALL=None, SEARCH_POINTS_MIN=None, SEARCH_POINTS_MAX=None, Verbose=2):
     '''
     Simple Kriging (3D)
     ----------
@@ -872,6 +886,7 @@ def run_tool_statistics_kriging_5(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - TARGET_USER_ZSIZE [`floating point number`] : Cellsize. Minimum: 0.000000 Default: 1.000000
@@ -918,6 +933,7 @@ def run_tool_statistics_kriging_5(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('TARGET_USER_ZSIZE', TARGET_USER_ZSIZE)
@@ -942,7 +958,7 @@ def run_tool_statistics_kriging_5(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=
         return Tool.Execute(Verbose)
     return False
 
-def Ordinary_Kriging_3D(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=None, VARIANCE=None, CV_SUMMARY=None, CV_RESIDUALS=None, Z_FIELD=None, Z_SCALE=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TARGET_USER_ZSIZE=None, TARGET_USER_ZMIN=None, TARGET_USER_ZMAX=None, TARGET_USER_ZNUM=None, TQUALITY=None, VAR_MAXDIST=None, VAR_NCLASSES=None, VAR_NSKIP=None, VAR_MODEL=None, LOG=None, BLOCK=None, DBLOCK=None, CV_METHOD=None, CV_SAMPLES=None, SEARCH_RANGE=None, SEARCH_RADIUS=None, SEARCH_POINTS_ALL=None, SEARCH_POINTS_MIN=None, SEARCH_POINTS_MAX=None, Verbose=2):
+def Ordinary_Kriging_3D(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=None, VARIANCE=None, CV_SUMMARY=None, CV_RESIDUALS=None, Z_FIELD=None, Z_SCALE=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TARGET_USER_ZSIZE=None, TARGET_USER_ZMIN=None, TARGET_USER_ZMAX=None, TARGET_USER_ZNUM=None, TQUALITY=None, VAR_MAXDIST=None, VAR_NCLASSES=None, VAR_NSKIP=None, VAR_MODEL=None, LOG=None, BLOCK=None, DBLOCK=None, CV_METHOD=None, CV_SAMPLES=None, SEARCH_RANGE=None, SEARCH_RADIUS=None, SEARCH_POINTS_ALL=None, SEARCH_POINTS_MIN=None, SEARCH_POINTS_MAX=None, Verbose=2):
     '''
     Ordinary Kriging (3D)
     ----------
@@ -967,6 +983,7 @@ def Ordinary_Kriging_3D(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=None, VARI
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - TARGET_USER_ZSIZE [`floating point number`] : Cellsize. Minimum: 0.000000 Default: 1.000000
@@ -1013,6 +1030,7 @@ def Ordinary_Kriging_3D(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=None, VARI
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('TARGET_USER_ZSIZE', TARGET_USER_ZSIZE)
@@ -1037,7 +1055,7 @@ def Ordinary_Kriging_3D(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=None, VARI
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_kriging_6(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=None, VARIANCE=None, CV_SUMMARY=None, CV_RESIDUALS=None, Z_FIELD=None, Z_SCALE=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TARGET_USER_ZSIZE=None, TARGET_USER_ZMIN=None, TARGET_USER_ZMAX=None, TARGET_USER_ZNUM=None, TQUALITY=None, VAR_MAXDIST=None, VAR_NCLASSES=None, VAR_NSKIP=None, VAR_MODEL=None, LOG=None, BLOCK=None, DBLOCK=None, CV_METHOD=None, CV_SAMPLES=None, SEARCH_RANGE=None, SEARCH_RADIUS=None, SEARCH_POINTS_ALL=None, SEARCH_POINTS_MIN=None, SEARCH_POINTS_MAX=None, Verbose=2):
+def run_tool_statistics_kriging_6(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=None, VARIANCE=None, CV_SUMMARY=None, CV_RESIDUALS=None, Z_FIELD=None, Z_SCALE=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TARGET_USER_ZSIZE=None, TARGET_USER_ZMIN=None, TARGET_USER_ZMAX=None, TARGET_USER_ZNUM=None, TQUALITY=None, VAR_MAXDIST=None, VAR_NCLASSES=None, VAR_NSKIP=None, VAR_MODEL=None, LOG=None, BLOCK=None, DBLOCK=None, CV_METHOD=None, CV_SAMPLES=None, SEARCH_RANGE=None, SEARCH_RADIUS=None, SEARCH_POINTS_ALL=None, SEARCH_POINTS_MIN=None, SEARCH_POINTS_MAX=None, Verbose=2):
     '''
     Ordinary Kriging (3D)
     ----------
@@ -1062,6 +1080,7 @@ def run_tool_statistics_kriging_6(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - TARGET_USER_ZSIZE [`floating point number`] : Cellsize. Minimum: 0.000000 Default: 1.000000
@@ -1108,6 +1127,7 @@ def run_tool_statistics_kriging_6(POINTS=None, TARGET_TEMPLATE=None, PREDICTION=
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('TARGET_USER_ZSIZE', TARGET_USER_ZSIZE)
