@@ -14,7 +14,7 @@ Tools for table based analyses and calculations.
 
 from PySAGA.helper import Tool_Wrapper
 
-def Function_Fit(SOURCE=None, YFIELD=None, USE_X=None, XFIELD=None, FORMEL=None, ITER=None, LAMDA=None, Verbose=2):
+def Function_Fit(SOURCE=None, YFIELD=None, USE_X=None, XFIELD=None, FORMEL=None, ITER=None, LAMBDA=None, Verbose=2):
     '''
     Function Fit
     ----------
@@ -51,7 +51,7 @@ The Fitting variables are single characters like a,b,m .. alphabetical order wit
 Example: m*x+a 
 
     - ITER [`integer number`] : Iterationen. Minimum: 1 Default: 1000
-    - LAMDA [`floating point number`] : Max Lamda. Minimum: 1.000000 Default: 10000.000000
+    - LAMBDA [`floating point number`] : Max Lambda. Minimum: 1.000000 Default: 10000.000000
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
     Returns
@@ -66,11 +66,11 @@ Example: m*x+a
         Tool.Set_Option('XFIELD', XFIELD)
         Tool.Set_Option('FORMEL', FORMEL)
         Tool.Set_Option('ITER', ITER)
-        Tool.Set_Option('LAMDA', LAMDA)
+        Tool.Set_Option('LAMBDA', LAMBDA)
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_calculus_0(SOURCE=None, YFIELD=None, USE_X=None, XFIELD=None, FORMEL=None, ITER=None, LAMDA=None, Verbose=2):
+def run_tool_table_calculus_0(SOURCE=None, YFIELD=None, USE_X=None, XFIELD=None, FORMEL=None, ITER=None, LAMBDA=None, Verbose=2):
     '''
     Function Fit
     ----------
@@ -107,7 +107,7 @@ The Fitting variables are single characters like a,b,m .. alphabetical order wit
 Example: m*x+a 
 
     - ITER [`integer number`] : Iterationen. Minimum: 1 Default: 1000
-    - LAMDA [`floating point number`] : Max Lamda. Minimum: 1.000000 Default: 10000.000000
+    - LAMBDA [`floating point number`] : Max Lambda. Minimum: 1.000000 Default: 10000.000000
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
     Returns
@@ -122,7 +122,7 @@ Example: m*x+a
         Tool.Set_Option('XFIELD', XFIELD)
         Tool.Set_Option('FORMEL', FORMEL)
         Tool.Set_Option('ITER', ITER)
-        Tool.Set_Option('LAMDA', LAMDA)
+        Tool.Set_Option('LAMBDA', LAMBDA)
         return Tool.Execute(Verbose)
     return False
 
@@ -131,10 +131,10 @@ def Field_Calculator(TABLE=None, RESULT_TABLE=None, RESULT_SHAPES=None, FIELD=No
     Field Calculator
     ----------
     [table_calculus.1]\n
-    The table calculator calculates a new attribute from existing attributes based on a mathematical formula. Attributes are addressed by the character 'f' (for 'field') followed by the field number (i.e.: f1, f2, ..., fn) or by the field name in square brackets (e.g.: [Field Name]).\n
+    The table calculator calculates a new attribute from existing attributes based on a mathematical formula. Attributes are addressed by the character 'f' (for 'field') followed by the field number (i.e.: f1, f2, ..., fn) or by the field name in quotation marks or square brackets (e.g.: "Field Name").\n
     Examples:\n
     - sin(f1) * f2 + f3\n
-    - [Population] / [Area]\n
+    - "Population" / "Area"\n
     One can also use the drop-down-menu to append fields numbers to the formula.\n
     If the use no-data flag is unchecked and a no-data value appears in a record's input, no calculation is performed for it and the result is set to no-data.\n
     Following operators are available for the formula definition:\n
@@ -211,10 +211,10 @@ def run_tool_table_calculus_1(TABLE=None, RESULT_TABLE=None, RESULT_SHAPES=None,
     Field Calculator
     ----------
     [table_calculus.1]\n
-    The table calculator calculates a new attribute from existing attributes based on a mathematical formula. Attributes are addressed by the character 'f' (for 'field') followed by the field number (i.e.: f1, f2, ..., fn) or by the field name in square brackets (e.g.: [Field Name]).\n
+    The table calculator calculates a new attribute from existing attributes based on a mathematical formula. Attributes are addressed by the character 'f' (for 'field') followed by the field number (i.e.: f1, f2, ..., fn) or by the field name in quotation marks or square brackets (e.g.: "Field Name").\n
     Examples:\n
     - sin(f1) * f2 + f3\n
-    - [Population] / [Area]\n
+    - "Population" / "Area"\n
     One can also use the drop-down-menu to append fields numbers to the formula.\n
     If the use no-data flag is unchecked and a no-data value appears in a record's input, no calculation is performed for it and the result is set to no-data.\n
     Following operators are available for the formula definition:\n
