@@ -50,7 +50,6 @@
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-#include <wx/stdpaths.h>
 #include <wx/app.h>
 
 #include "api_core.h"
@@ -620,6 +619,19 @@ bool		SG_UI_DataObject_Add(CSG_Data_Object *pDataObject, int Show)
 	return( false );
 }
 
+//---------------------------------------------------------
+bool		SG_UI_DataObject_Del(CSG_Data_Object *pDataObject, bool bConfirm)
+{
+	if( gSG_UI_Callback && pDataObject )
+	{
+		CSG_UI_Parameter p1(pDataObject), p2(bConfirm);
+
+		return( gSG_UI_Callback(CALLBACK_DATAOBJECT_DEL, p1, p2) != 0 );
+	}
+
+	return( false );
+}
+
 //---------------------------------------------------------
 bool		SG_UI_DataObject_Update(CSG_Data_Object *pDataObject, int Show, CSG_Parameters *pParameters)
 {
@@ -795,26 +807,6 @@ void *		SG_UI_Get_Window_Main		(void)
 	return( NULL );
 }
 
-//---------------------------------------------------------
-CSG_String	SG_UI_Get_Application_Path	(bool bPathOnly)
-{
-	CSG_String App_Path(wxStandardPaths::Get().GetExecutablePath().wc_str());
-
-	if( bPathOnly )
-	{
-		App_Path = SG_File_Get_Path(App_Path);
-	}
-
-	return( SG_File_Get_Path_Absolute(App_Path) );
-}
-
-//---------------------------------------------------------
-CSG_String	SG_UI_Get_Application_Name	(void)
-{
-	return( wxApp::GetInstance()->GetAppName().wc_str() );
-//	return( SG_File_Get_Name(SG_UI_Get_Application_Path(false), false) );
-}
-
 
 ///////////////////////////////////////////////////////////
 //														 //
