@@ -75,6 +75,12 @@ long		SG_Color_Get_Random	(void)
 	return(	SG_GET_RGB(CSG_Random::Get_Uniform(0, 255), CSG_Random::Get_Uniform(0, 255), CSG_Random::Get_Uniform(0, 255)) );
 }
 
+//---------------------------------------------------------
+long		SG_Color_From_RGB	(int Red, int Green, int Blue, int Alpha)
+{
+	return(	SG_GET_RGBA(Red, Green, Blue, Alpha) );
+}
+
 //---------------------------------------------------------
 bool		SG_Color_From_Text	(const CSG_String &Text, long &Color)
 {	// from wx/src/common/colourcmn.cpp, hexadecimal prefixed with # ("HTML syntax") see https://drafts.csswg.org/css-color/#hex-notation
@@ -432,7 +438,7 @@ int CSG_Colors::Get_Predefined_Count(void)
 }
 
 //---------------------------------------------------------
-const SG_Char * CSG_Colors::Get_Predefined_Name(int Index)
+CSG_String CSG_Colors::Get_Predefined_Name(int Index)
 {
 	switch( Index )
 	{
@@ -641,11 +647,11 @@ bool CSG_Colors::Set_Predefined(int Index, bool bRevert, int nColors)
 
 	case SG_COLORS_TOPOGRAPHY:
 		Set_Count(5);
-		Set_Color(0, SG_GET_RGB(  0,  63, 127));
+		Set_Color(0, SG_GET_RGB(  0, 143, 127));
 		Set_Color(1, SG_GET_RGB(127, 255,   0));
 		Set_Color(2, SG_GET_RGB(255, 255, 127));
-		Set_Color(3, SG_GET_RGB(191, 127,   0));
-		Set_Color(4, SG_GET_RGB(127,  63,   0));
+		Set_Color(3, SG_GET_RGB(255, 192,   0));
+		Set_Color(4, SG_GET_RGB(192, 143,   0));
 		break;
 
 	case SG_COLORS_TOPOGRAPHY_2:
@@ -808,11 +814,11 @@ bool CSG_Colors::Set_Predefined(int Index, bool bRevert, int nColors)
 
 	case SG_COLORS_COUNT + 9:
 		Set_Count(5);
-		Set_Color(0, SG_GET_RGB(  0,   0, 127));
-		Set_Color(1, SG_GET_RGB(  0, 127, 255));
+		Set_Color(0, SG_GET_RGB(255, 255, 127));
+		Set_Color(1, SG_GET_RGB(191, 255,   0));
 		Set_Color(2, SG_GET_RGB(  0, 191,   0));
-		Set_Color(3, SG_GET_RGB(191, 255,   0));
-		Set_Color(4, SG_GET_RGB(255, 255, 127));
+		Set_Color(3, SG_GET_RGB(  0, 127, 255));
+		Set_Color(4, SG_GET_RGB(  0,   0, 127));
 		break;
 
 	case SG_COLORS_COUNT + 10:
