@@ -56,6 +56,7 @@
 #include <wx/wxcrtvararg.h>
 #include <wx/wfstream.h>
 #include <wx/zipstrm.h>
+#include <wx/tarstrm.h>
 #include <wx/txtstrm.h>
 #include <wx/log.h>
 #include <wx/version.h>
@@ -64,9 +65,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -77,9 +78,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -89,7 +90,7 @@ CSG_File::CSG_File(void)
 }
 
 //---------------------------------------------------------
-CSG_File::CSG_File(const CSG_String &FileName, int Mode, bool bBinary, int Encoding)
+CSG_File::CSG_File(const SG_Char *FileName, int Mode, bool bBinary, int Encoding)
 {
 	On_Construction();
 
@@ -104,14 +105,16 @@ CSG_File::~CSG_File(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-bool CSG_File::Open(const CSG_String &FileName, int Mode, bool bBinary, int Encoding)
+bool CSG_File::Open(const SG_Char *_FileName, int Mode, bool bBinary, int Encoding)
 {
 	Close();
 
+	if( !_FileName ) { return( false ); } CSG_String FileName(_FileName);
+
 	CSG_String Path(SG_File_Get_Path(FileName));
 
 	if( !Path.is_Empty() && !SG_Dir_Exists(Path) )
@@ -173,7 +176,7 @@ bool CSG_File::Close(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -219,7 +222,7 @@ bool CSG_File::Set_Encoding(int Encoding)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -273,6 +276,12 @@ sLong CSG_File::Tell(void) const
 	return( -1 );
 }
 
+//---------------------------------------------------------
+bool CSG_File::Flush(void)
+{
+	return( m_pStream_O && m_pStream_O->GetFile()->Flush() );
+}
+
 //---------------------------------------------------------
 int CSG_File::Printf(const char *Format, ...)
 {
@@ -557,19 +566,19 @@ CSG_String CSG_File::Scan_String(SG_Char Separator) const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-CSG_File_Zip::CSG_File_Zip(void)
+CSG_Archive::CSG_Archive(void)
 {
 	On_Construction();
 }
 
 //---------------------------------------------------------
-CSG_File_Zip::CSG_File_Zip(const CSG_String &FileName, int Mode, int Encoding)
+CSG_Archive::CSG_Archive(const SG_Char *FileName, int Mode, int Encoding)
 {
 	On_Construction();
 
@@ -577,24 +586,37 @@ CSG_File_Zip::CSG_File_Zip(const CSG_String &FileName, int Mode, int Encoding)
 }
 
 //---------------------------------------------------------
-CSG_File_Zip::~CSG_File_Zip(void)
+CSG_Archive::~CSG_Archive(void)
 {
 	Close();
 }
 
 //---------------------------------------------------------
-bool CSG_File_Zip::Open(const CSG_String &FileName, int Mode, int Encoding)
+bool CSG_Archive::Open(const SG_Char *_FileName, int Mode, int Encoding)
 {
 	Close();
 
-	CSG_String Path(SG_File_Get_Path(FileName));
+	if( !_FileName ) { return( false ); } CSG_String FileName(_FileName);
+
+	if( SG_File_Cmp_Extension(FileName, "tar") )
+	{
+		m_Type = SG_FILE_TYPE_TAR;
+	}
+	else // if( SG_File_Cmp_Extension(FileName, "zip") )
+	{
+		m_Type = SG_FILE_TYPE_ZIP;
+	}
+
+	m_Archive = FileName;
+
+	CSG_String Path(SG_File_Get_Path(m_Archive));
 
 	if( !Path.is_Empty() && !SG_Dir_Exists(Path) )
 	{
 		return( false );
 	}
 
-	if( Mode == SG_FILE_R && !SG_File_Exists(FileName) )
+	if( Mode == SG_FILE_R && !SG_File_Exists(m_Archive) )
 	{
 		return( false );
 	}
@@ -605,11 +627,25 @@ bool CSG_File_Zip::Open(const CSG_String &FileName, int Mode, int Encoding)
 
 	if( Mode == SG_FILE_W )
 	{
-		m_pStream = new wxZipOutputStream(new wxFileOutputStream(FileName.c_str()));
+		if( is_Zip() )
+		{
+			m_pStream = new wxZipOutputStream(new wxFileOutputStream(m_Archive.c_str()));
+		}
+		else
+		{
+			m_pStream = new wxTarOutputStream(new wxFileOutputStream(m_Archive.c_str()));
+		}
 	}
-	else if( Mode == SG_FILE_R && SG_File_Exists(FileName) )
+	else if( Mode == SG_FILE_R && SG_File_Exists(m_Archive) )
 	{
-		m_pStream = new wxZipInputStream (new wxFileInputStream (FileName.c_str()));
+		if( is_Zip() )
+		{
+			m_pStream = new wxZipInputStream (new wxFileInputStream (m_Archive.c_str()));
+		}
+		else
+		{
+			m_pStream = new wxTarInputStream (new wxFileInputStream (m_Archive.c_str()));
+		}
 	}
 
 	if( !m_pStream || !m_pStream_Base->IsOk() )
@@ -621,9 +657,9 @@ bool CSG_File_Zip::Open(const CSG_String &FileName, int Mode, int Encoding)
 
 	if( is_Reading() )
 	{
-		wxZipEntry *pEntry;
+		wxArchiveEntry *pEntry;
 
-		while( (pEntry = ((wxZipInputStream *)m_pStream)->GetNextEntry()) != NULL )
+		while( (pEntry = ((wxArchiveInputStream *)m_pStream)->GetNextEntry()) != NULL )
 		{
 			m_Files += pEntry;
 		}
@@ -633,40 +669,58 @@ bool CSG_File_Zip::Open(const CSG_String &FileName, int Mode, int Encoding)
 }
 
 //---------------------------------------------------------
-bool CSG_File_Zip::Close(void)
+bool CSG_Archive::Close(void)
 {
 	for(sLong i=0; i<m_Files.Get_Size(); i++)
 	{
-		delete((wxZipEntry *)m_Files[i]);
+		if( is_Zip() )
+		{
+			delete((wxZipEntry *)m_Files[i]);
+		}
+		else
+		{
+			delete((wxTarEntry *)m_Files[i]);
+		}
 	}
 
 	m_Files.Set_Array(0);
 
+	m_Archive.Clear();
+
 	return( CSG_File::Close() );
 }
 
 //---------------------------------------------------------
-bool CSG_File_Zip::Add_Directory(const CSG_String &Name)
+bool CSG_Archive::Add_Directory(const SG_Char *Name)
 {
-	return( is_Writing() && ((wxZipOutputStream *)m_pStream)->PutNextDirEntry(Name.c_str()) );
+	return( is_Writing() && Name && ((wxArchiveOutputStream *)m_pStream)->PutNextDirEntry(Name) );
 }
 
 //---------------------------------------------------------
-bool CSG_File_Zip::Add_File(const CSG_String &Name, bool bBinary)
+bool CSG_Archive::Add_File(const SG_Char *Name, bool bBinary)
 {
-	if( is_Writing() )
+	if( is_Writing() && Name )
 	{
-		wxZipEntry	*pEntry	= new wxZipEntry(Name.c_str());
+		wxArchiveEntry *pEntry = NULL;
 
-		pEntry->SetIsText(bBinary == false);
-
-		#if wxCHECK_VERSION(3, 1, 1)
-		((wxZipOutputStream *)m_pStream)->SetFormat(wxZIP_FORMAT_ZIP64);
-		#endif
-
-		if( ((wxZipOutputStream *)m_pStream)->PutNextEntry(pEntry) )
+		if( is_Zip() )
 		{
-			m_FileName	= Name;
+			pEntry = new wxZipEntry(Name);
+
+			((wxZipEntry *)pEntry)->SetIsText(bBinary == false);
+
+			#if wxCHECK_VERSION(3, 1, 1)
+			((wxZipOutputStream *)m_pStream)->SetFormat(wxZIP_FORMAT_ZIP64);
+			#endif
+		}
+		else
+		{
+			pEntry = new wxTarEntry(Name);
+		}
+
+		if( ((wxArchiveOutputStream *)m_pStream)->PutNextEntry(pEntry) )
+		{
+			m_FileName = Name;
 
 			return( true );
 		}
@@ -676,24 +730,24 @@ bool CSG_File_Zip::Add_File(const CSG_String &Name, bool bBinary)
 }
 
 //---------------------------------------------------------
-bool CSG_File_Zip::is_Directory(size_t Index)
+bool CSG_Archive::is_Directory(size_t Index)
 {
 	if( is_Reading() && m_Files[Index] )
 	{
-		return( ((wxZipEntry *)m_Files[Index])->IsDir() );
+		return( ((wxArchiveEntry *)m_Files[Index])->IsDir() );
 	}
 
 	return( false );
 }
 
 //---------------------------------------------------------
-bool CSG_File_Zip::Get_File(size_t Index)
+bool CSG_Archive::Get_File(size_t Index)
 {
 	if( is_Reading() && m_Files[Index] )
 	{
-		if( ((wxZipInputStream *)m_pStream)->OpenEntry(*(wxZipEntry *)m_Files[Index]) )
+		if( ((wxArchiveInputStream *)m_pStream)->OpenEntry(*(wxArchiveEntry *)m_Files[Index]) )
 		{
-			m_FileName	= Get_File_Name(Index);
+			m_FileName = Get_File_Name(Index);
 
 			return( true );
 		}
@@ -703,13 +757,13 @@ bool CSG_File_Zip::Get_File(size_t Index)
 }
 
 //---------------------------------------------------------
-bool CSG_File_Zip::Get_File(const CSG_String &Name)
+bool CSG_Archive::Get_File(const SG_Char *Name)
 {
-	if( is_Reading() )
+	if( is_Reading() && Name )
 	{
 		for(sLong i=0; i<m_Files.Get_Size(); i++)
 		{
-			if( !((wxZipEntry *)m_Files[i])->GetName().Cmp(Name.c_str()) )
+			if( !((wxArchiveEntry *)m_Files[i])->GetName().Cmp(Name) )
 			{
 				return( Get_File(i) );
 			}
@@ -720,13 +774,13 @@ bool CSG_File_Zip::Get_File(const CSG_String &Name)
 }
 
 //---------------------------------------------------------
-CSG_String CSG_File_Zip::Get_File_Name(size_t Index)
+CSG_String CSG_Archive::Get_File_Name(size_t Index)
 {
-	CSG_String	s;
+	CSG_String s;
 
 	if( is_Reading() && m_Files[Index] )
 	{
-		wxString Name(((wxZipEntry *)m_Files[Index])->GetName()); s	= &Name;
+		wxString Name(((wxArchiveEntry *)m_Files[Index])->GetName()); s = &Name;
 	}
 
 	return( s );
@@ -734,9 +788,94 @@ CSG_String CSG_File_Zip::Get_File_Name(size_t Index)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool CSG_Archive::Extract_All(const SG_Char *_Directory)
+{
+	if( !is_Reading() )
+	{
+		return( false );
+	}
+
+	#ifdef _SAGA_MSW
+		const char Separator = '\\';
+	#else
+		const char Separator = '/';
+	#endif
+
+	CSG_String Directory(_Directory ? _Directory : SG_T(""));
+
+	if( Directory.is_Empty() )
+	{
+		Directory = SG_File_Get_Path(m_Archive);
+	}
+	else if( !SG_Dir_Exists(Directory) )
+	{
+		SG_Dir_Create(Directory, true);
+	}
+
+	Directory += Separator;
+
+	//-----------------------------------------------------
+	for(size_t i=0; i<Get_File_Count() && SG_UI_Process_Set_Progress((int)i, (int)Get_File_Count()); i++)
+	{
+		if( is_Directory(i) )
+		{
+			SG_Dir_Create(Directory + Get_File_Name(i));
+		}
+		else
+		{
+			Extract(Get_File_Name(i), Directory + Get_File_Name(i));
+		}
+	}
+
+	return( true );
+}
+
+//---------------------------------------------------------
+bool CSG_Archive::Extract(const SG_Char *File, const SG_Char *_toFile)
+{
+	if( !is_Reading() || !Get_File(File) )
+	{
+		return( false );
+	}
+
+	CSG_String toFile(_toFile ? _toFile : SG_T(""));
+
+	if( toFile.is_Empty() )
+	{
+		toFile = SG_File_Make_Path(SG_File_Get_Path(m_Archive), File);
+	}
+
+	CSG_File Stream(toFile, SG_FILE_W, true, m_Encoding);
+
+	if( !Stream.is_Open() )
+	{
+		return( false );
+	}
+
+	//-----------------------------------------------------
+	#define UNZIP_BUFFER 4096
+
+	char *Buffer[UNZIP_BUFFER];
+
+	while( !is_EOF() )
+	{
+		size_t nBytes = Read(Buffer, sizeof(char), UNZIP_BUFFER);
+
+		Stream.Write(Buffer, 1, nBytes); Stream.Flush();
+	}
+
+	return( true );
+}
+
+
+///////////////////////////////////////////////////////////
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -841,9 +980,9 @@ bool			SG_Dir_List_Files			(CSG_Strings &List, const CSG_String &Directory, cons
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -983,9 +1122,9 @@ CSG_String		SG_File_Get_Extension(const CSG_String &FileName)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1016,9 +1155,9 @@ bool			SG_Set_Environment(const CSG_String &Variable, const CSG_String &Value)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
