@@ -56,9 +56,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -114,9 +114,9 @@ CSG_String	SG_Get_DataObject_Class_Name(TSG_Data_Object_Type Type)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //				Data Object Statistics					 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -143,9 +143,9 @@ sLong				SG_DataObject_Get_Max_Samples	(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -176,9 +176,9 @@ int		SG_Get_History_Ignore_Lists		(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -196,9 +196,9 @@ bool		SG_Data_Object_Delete		(CSG_Data_Object *pObject)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -291,7 +291,7 @@ bool CSG_Data_Object::Destroy(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -413,12 +413,12 @@ int CSG_Data_Object::Get_File_Type(void)	const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 /*
-* If the data object has a file asssociation, this function
+* If the data object has a file association, this function
 * can be used to reload its content.
 */
 //---------------------------------------------------------
@@ -430,7 +430,7 @@ bool CSG_Data_Object::Reload(void)
 //---------------------------------------------------------
 /*
 * If the data object is stored in a native SAGA format,
-* this function can be used to delete all files asssociated
+* this function can be used to delete all files associated
 * with it.
 */
 //---------------------------------------------------------
@@ -473,7 +473,7 @@ bool CSG_Data_Object::Delete(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -565,7 +565,7 @@ CSG_Grids * CSG_Data_Object::asGrids(bool bPolymorph) const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -610,7 +610,7 @@ bool CSG_Data_Object::On_NoData_Changed(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -630,7 +630,7 @@ bool CSG_Data_Object::Set_Max_Samples(sLong Max_Samples)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -647,13 +647,13 @@ const CSG_Projection & CSG_Data_Object::Get_Projection(void) const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 bool CSG_Data_Object::Load_MetaData(const CSG_String &_FileName)
 {
-	CSG_String	FileName(_FileName);
+	CSG_String FileName(_FileName);
 
 	switch( Get_ObjectType() )
 	{
@@ -663,12 +663,16 @@ bool CSG_Data_Object::Load_MetaData(const CSG_String &_FileName)
 	case SG_DATAOBJECT_TYPE_Shapes    : SG_File_Set_Extension(FileName, "mshp"   ); break;
 	case SG_DATAOBJECT_TYPE_TIN       : SG_File_Set_Extension(FileName, "sg-info"); break;
 	case SG_DATAOBJECT_TYPE_PointCloud: SG_File_Set_Extension(FileName, "sg-info");
-		if( !SG_File_Get_Extension(_FileName).CmpNoCase("spc") ) SG_File_Set_Extension(FileName, "mpts"); break;
+		if( !SG_File_Get_Extension(_FileName).CmpNoCase("spc") )
+		{
+			SG_File_Set_Extension(FileName, "mpts");
+		}
+		break;
 
-	default:	return( false );
+	default: return( false );
 	}
 
-	CSG_File	Stream(FileName, SG_FILE_R, false);
+	CSG_File Stream(FileName, SG_FILE_R, false);
 
 	return( Load_MetaData(Stream) );
 }
@@ -786,7 +790,7 @@ bool CSG_Data_Object::Update(bool bForce)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -809,7 +813,7 @@ bool CSG_Data_Object::Assign(CSG_Data_Object *pObject)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -823,9 +827,9 @@ bool CSG_Data_Object::Save_History_to_Model(const CSG_String &File)	const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
