@@ -55,9 +55,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -208,9 +208,9 @@ TSG_Parameter_Type SG_Parameter_Type_Get_Type(const CSG_String &Identifier)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Node							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -222,9 +222,9 @@ CSG_Parameter_Node::CSG_Parameter_Node(CSG_Parameters *pOwner, CSG_Parameter *pP
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Bool							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -319,9 +319,9 @@ bool CSG_Parameter_Bool::_Serialize(CSG_MetaData &Entry, bool bSave)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Value							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -421,9 +421,9 @@ bool CSG_Parameter_Value::_Assign(CSG_Parameter *pSource)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Int								 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -510,9 +510,9 @@ bool CSG_Parameter_Int::_Serialize(CSG_MetaData &Entry, bool bSave)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Double							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -599,9 +599,9 @@ bool CSG_Parameter_Double::_Serialize(CSG_MetaData &Entry, bool bSave)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Degree							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -625,9 +625,9 @@ void CSG_Parameter_Degree::_Set_String(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Date							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -737,9 +737,9 @@ bool CSG_Parameter_Date::_Serialize(CSG_MetaData &Entry, bool bSave)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Range							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -882,9 +882,9 @@ bool CSG_Parameter_Range::_Serialize(CSG_MetaData &Entry, bool bSave)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Choice							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1124,9 +1124,9 @@ bool CSG_Parameter_Choice::_Serialize(CSG_MetaData &Entry, bool bSave)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Data Type						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1256,9 +1256,9 @@ bool CSG_Parameter_Data_Type::_Serialize(CSG_MetaData &Entry, bool bSave)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Choices							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1438,9 +1438,9 @@ bool CSG_Parameter_Choices::_Serialize(CSG_MetaData &Entry, bool bSave)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						String							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1507,9 +1507,9 @@ bool CSG_Parameter_String::_Serialize(CSG_MetaData &Entry, bool bSave)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Text							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1521,9 +1521,9 @@ CSG_Parameter_Text::CSG_Parameter_Text(CSG_Parameters *pOwner, CSG_Parameter *pP
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						FilePath						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1618,9 +1618,9 @@ bool CSG_Parameter_File_Name::_Assign(CSG_Parameter *pSource)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Font							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1725,9 +1725,9 @@ bool CSG_Parameter_Font::_Serialize(CSG_MetaData &Entry, bool bSave)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Color							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1778,9 +1778,9 @@ bool CSG_Parameter_Color::_Serialize(CSG_MetaData &Entry, bool bSave)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Colors							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1866,9 +1866,9 @@ bool CSG_Parameter_Colors::_Serialize(CSG_MetaData &Entry, bool bSave)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						FixedTable						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1878,6 +1878,17 @@ CSG_Parameter_Fixed_Table::CSG_Parameter_Fixed_Table(CSG_Parameters *pOwner, CSG
 	m_Table.Set_Name(_TL("Table"));
 }
 
+//---------------------------------------------------------
+int CSG_Parameter_Fixed_Table::_Set_Value(void *Value)
+{
+	if( Value && m_Table.Assign_Values((CSG_Table *)Value) )
+	{
+		return( SG_PARAMETER_DATA_SET_CHANGED );
+	}
+
+	return( SG_PARAMETER_DATA_SET_TRUE );
+}
+
 //---------------------------------------------------------
 void CSG_Parameter_Fixed_Table::_Set_String(void)
 {
@@ -1976,9 +1987,9 @@ bool CSG_Parameter_Fixed_Table::_Serialize(CSG_MetaData &Entry, bool bSave)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Grid_System						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -2136,9 +2147,9 @@ bool CSG_Parameter_Grid_System::_Serialize(CSG_MetaData &Entry, bool bSave)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //					Table Field							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -2314,9 +2325,9 @@ CSG_String CSG_Parameter_Table_Field::Get_Choices(const CSG_Table &Table, bool b
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //					Table Fields						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -2451,9 +2462,9 @@ bool CSG_Parameter_Table_Fields::_Serialize(CSG_MetaData &Entry, bool bSave)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						DataObject						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -2594,9 +2605,9 @@ bool CSG_Parameter_Data_Object::_Serialize(CSG_MetaData &Entry, bool bSave)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //					DataObject_Output					 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -2609,29 +2620,33 @@ CSG_Parameter_Data_Object_Output::CSG_Parameter_Data_Object_Output(CSG_Parameter
 //---------------------------------------------------------
 int CSG_Parameter_Data_Object_Output::_Set_Value(void *Value)
 {
-	CSG_Data_Object	*pDataObject	= (CSG_Data_Object *)Value;
+	CSG_Data_Object *pDataObject = (CSG_Data_Object *)Value;
 
-	if( pDataObject == DATAOBJECT_CREATE )
+	if( m_pDataObject != pDataObject )
 	{
-		pDataObject	= NULL;
-	}
-
-	if( m_pDataObject != pDataObject && (pDataObject == NULL || pDataObject->Get_ObjectType() == m_Type) )
-	{
-		m_pDataObject	= pDataObject;
-
-		if( Get_Manager() )
+		if( pDataObject == DATAOBJECT_NOTSET || pDataObject == DATAOBJECT_CREATE )
 		{
-			Get_Manager()->Add(m_pDataObject);
+			m_pDataObject = pDataObject;
+		}
+		else if( pDataObject->Get_ObjectType() == m_Type )
+		{
+			m_pDataObject = pDataObject;
 
-			if( Get_Manager() == &SG_Get_Data_Manager() )	// prevent that local data manager send their data objects to gui
+			if( Get_Manager() )
 			{
-				SG_UI_DataObject_Add(m_pDataObject, false);
+				Get_Manager()->Add(m_pDataObject);
+
+				if( Get_Manager() == &SG_Get_Data_Manager() )	// prevent that local data manager send their data objects to gui
+				{
+					SG_UI_DataObject_Add(m_pDataObject, false);
+				}
 			}
 		}
+
+		return( SG_PARAMETER_DATA_SET_CHANGED );
 	}
 
-	return( SG_PARAMETER_DATA_SET_CHANGED );
+	return( SG_PARAMETER_DATA_SET_TRUE );
 }
 
 //---------------------------------------------------------
@@ -2661,9 +2676,9 @@ bool CSG_Parameter_Data_Object_Output::Set_DataObject_Type(TSG_Data_Object_Type
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Grid							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -2797,9 +2812,9 @@ bool CSG_Parameter_Grid::_Assign(CSG_Parameter *pSource)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Grids							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -2811,9 +2826,9 @@ CSG_Parameter_Grids::CSG_Parameter_Grids(CSG_Parameters *pOwner, CSG_Parameter *
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Table							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -2852,9 +2867,9 @@ int CSG_Parameter_Table::_Set_Value(void *Value)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Shapes							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -2913,9 +2928,9 @@ bool CSG_Parameter_Shapes::_Assign(CSG_Parameter *pSource)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						TIN								 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -2954,9 +2969,9 @@ int CSG_Parameter_TIN::_Set_Value(void *Value)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						PointCloud						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -3001,9 +3016,9 @@ bool CSG_Parameter_PointCloud::_Assign(CSG_Parameter *pSource)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						List							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -3068,6 +3083,22 @@ bool CSG_Parameter_List::Del_Items(void)
 	return( false );
 }
 
+//---------------------------------------------------------
+int CSG_Parameter_List::_Set_Value(void *Value)
+{
+	if( Value == NULL && Get_Item_Count() > 0 && Del_Items() )
+	{
+		return( SG_PARAMETER_DATA_SET_CHANGED );
+	}
+
+	if( Value != NULL && Add_Item((CSG_Data_Object *)Value) )
+	{
+		return( SG_PARAMETER_DATA_SET_CHANGED );
+	}
+
+	return( SG_PARAMETER_DATA_SET_TRUE );
+}
+
 //---------------------------------------------------------
 void CSG_Parameter_List::_Set_String(void)
 {
@@ -3156,9 +3187,9 @@ bool CSG_Parameter_List::_Serialize(CSG_MetaData &Entry, bool bSave)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Grid_List						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -3296,9 +3327,9 @@ bool CSG_Parameter_Grid_List::Update_Data(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Grids_List						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -3373,9 +3404,9 @@ bool CSG_Parameter_Grids_List::Add_Item(CSG_Data_Object *pObject)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Table_List						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 
@@ -3388,9 +3419,9 @@ CSG_Parameter_Table_List::CSG_Parameter_Table_List(CSG_Parameters *pOwner, CSG_P
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Shapes_List						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 
@@ -3417,9 +3448,9 @@ bool CSG_Parameter_Shapes_List::_Assign(CSG_Parameter *pSource)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						TIN_List						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 
@@ -3432,9 +3463,9 @@ CSG_Parameter_TIN_List::CSG_Parameter_TIN_List(CSG_Parameters *pOwner, CSG_Param
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //					PointCloud_List						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 
@@ -3447,9 +3478,9 @@ CSG_Parameter_PointCloud_List::CSG_Parameter_PointCloud_List(CSG_Parameters *pOw
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Parameters						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -3509,9 +3540,9 @@ bool CSG_Parameter_Parameters::_Serialize(CSG_MetaData &Entry, bool bSave)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
