@@ -55,9 +55,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -70,9 +70,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -85,9 +85,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -112,9 +112,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -168,9 +168,9 @@ TSG_Parameter_Type;
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -180,9 +180,9 @@ SAGA_API_DLL_EXPORT TSG_Parameter_Type	SG_Parameter_Type_Get_Type			(const CSG_S
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -197,9 +197,9 @@ SAGA_API_DLL_EXPORT TSG_Parameter_Type	SG_Parameter_Type_Get_Type			(const CSG_S
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //					CSG_Parameter						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1001,6 +1001,8 @@ protected:
 	CSG_Table					m_Table;
 
 
+	virtual int					_Set_Value				(void *Value);
+
 	virtual void				_Set_String				(void);
 
 	virtual void *				_asPointer				(void)	const;
@@ -1378,6 +1380,8 @@ protected:
 	CSG_Parameter_List(CSG_Parameters *pOwner, CSG_Parameter *pParent, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, int Constraint);
 
 
+	virtual int					_Set_Value				(void *Value);
+
 	virtual void				_Set_String				(void);
 
 	virtual int					_asInt					(void)	const;
@@ -1592,9 +1596,41 @@ protected:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//				Grid Target Selector					 //
-//														 //
+//                                                       //
+//         Coordinate System Reference Picker            //
+//                                                       //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+class SAGA_API_DLL_EXPORT CSG_Parameters_CRSPicker
+{
+public:
+	CSG_Parameters_CRSPicker(void);
+
+	bool						Create					(CSG_Parameters &Parameters, const CSG_String &ParentID = "");
+
+	bool						Activate_GUI			(bool bReset = false);
+	bool						Deactivate_GUI			(void);
+
+	static bool					On_Parameter_Changed	(CSG_Parameters *pParameters, CSG_Parameter *pParameter);
+	static bool					On_Parameters_Enable	(CSG_Parameters *pParameters, CSG_Parameter *pParameter);
+
+	bool						Get_CRS					(CSG_Projection &Projection, bool bMessage = false)	const;
+
+
+private:
+
+	CSG_Parameters				*m_pParameters { NULL };
+
+	class CSG_Tool				*m_pCRS { NULL };
+
+};
+
+
+///////////////////////////////////////////////////////////
+//                                                       //
+//                Grid Target Selector                   //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1621,7 +1657,8 @@ public:
 
 	bool						Set_User_Defined_ZLevels	(CSG_Parameters *pParameters, double zMin, double zMax, int nLevels, int Rounding = 2);
 
-	CSG_Grid_System				Get_System					(void);
+	CSG_Grid_System				Get_System					(void)                        const;
+	CSG_Grid_System				Get_System					(CSG_Parameters *pParameters) const;
 
 	CSG_Grid *					Get_Grid					(const CSG_String &ID, TSG_Data_Type Type = SG_DATATYPE_Float);
 	CSG_Grid *					Get_Grid					(                      TSG_Data_Type Type = SG_DATATYPE_Float);
@@ -1640,9 +1677,9 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //					CSG_Parameters						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1712,8 +1749,11 @@ public:
 	//-----------------------------------------------------
 	CSG_Parameters &			operator =				(const CSG_Parameters &Parameters)	{	Create(Parameters);	return( *this );	}
 
-	CSG_Parameter *				Get_Parameter			(int i               )	const	{	return( i >= 0 && i < m_nParameters ? m_Parameters[i] : NULL );	}
-	CSG_Parameter *				Get_Parameter			(const CSG_String &ID)	const;
+	CSG_Parameter *				Get_Parameter			(int i                                        )	const { return( i >= 0 && i < m_nParameters ? m_Parameters[i] : NULL ); }
+	CSG_Parameter *				Get_Parameter			(int i               , bool MsgOnError        )	const;
+	CSG_Parameter *				Get_Parameter			(const CSG_String &ID, bool MsgOnError = false)	const;
+	CSG_Parameter *				Get_Parameter			(const char       *ID, bool MsgOnError = false)	const;
+	CSG_Parameter *				Get_Parameter			(const wchar_t    *ID, bool MsgOnError = false)	const;
 
 	CSG_Parameter *				operator()				(int i               )	const	{	return(  Get_Parameter(i ) );	}
 	CSG_Parameter *				operator()				(const CSG_String &ID)	const	{	return(  Get_Parameter(ID) );	}
@@ -1759,8 +1799,9 @@ public:
 
 	CSG_Parameter *				Add_FilePath			(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, const SG_Char *Filter = NULL, const SG_Char *Default = NULL, bool bSave = false, bool bDirectory = false, bool bMultiple = false);
 
+	CSG_Parameter *				Add_Colors				(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, int Palette = 0, int nColors = 11, bool bRevert = false);
+	CSG_Parameter *				Add_Colors				(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, CSG_Colors    *pInit);
 	CSG_Parameter *				Add_Font				(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, const SG_Char *pInit = NULL);
-	CSG_Parameter *				Add_Colors				(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, CSG_Colors    *pInit = NULL);
 	CSG_Parameter *				Add_FixedTable			(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, CSG_Table     *pInit = NULL);
 
 	CSG_Parameter *				Add_Grid_System			(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, CSG_Grid_System *pInit = NULL);
@@ -1985,9 +2026,9 @@ public:	// DEPRECATED BEGIN
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
