@@ -52,9 +52,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -67,9 +67,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -89,7 +89,14 @@ CSG_PointCloud * SG_Create_PointCloud(const char       *File) { return( SG_Creat
 CSG_PointCloud * SG_Create_PointCloud(const wchar_t    *File) { return( SG_Create_PointCloud(CSG_String(File)) ); }
 CSG_PointCloud * SG_Create_PointCloud(const CSG_String &File)
 {
-	return( new CSG_PointCloud(File) );
+	CSG_PointCloud *pPoints = new CSG_PointCloud();
+
+	if( pPoints->Create(File) )
+	{
+		return( pPoints );
+	}
+
+	delete(pPoints); return( NULL );
 }
 
 //---------------------------------------------------------
@@ -100,9 +107,9 @@ CSG_PointCloud * SG_Create_PointCloud(CSG_PointCloud *pStructure)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -241,9 +248,9 @@ bool CSG_PointCloud::Destroy(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						File							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -255,7 +262,7 @@ bool CSG_PointCloud::_Load(const CSG_String &File)
 
 	if( SG_File_Cmp_Extension(File, "sg-pts-z") ) // POINTCLOUD_FILE_FORMAT_Compressed
 	{
-		CSG_File_Zip Stream(File, SG_FILE_R);
+		CSG_Archive Stream(File, SG_FILE_R);
 
 		CSG_String _File(SG_File_Get_Name(File, false) + ".");
 
@@ -321,6 +328,11 @@ bool CSG_PointCloud::_Load(const CSG_String &File)
 //---------------------------------------------------------
 bool CSG_PointCloud::Save(const CSG_String &_File, int Format)
 {
+	if( _File.is_Empty() )
+	{
+		return( *Get_File_Name(false) ? Save(Get_File_Name(false), Format) : false );
+	}
+
 	if( Format == POINTCLOUD_FILE_FORMAT_Undefined )
 	{
 		Format	= SG_File_Cmp_Extension(_File, "sg-pts-z")
@@ -341,7 +353,7 @@ bool CSG_PointCloud::Save(const CSG_String &_File, int Format)
 
 			SG_UI_Msg_Add(CSG_String::Format("%s %s: %s...", _TL("Saving"), _TL("point cloud"), File.c_str()), true);
 
-			CSG_File_Zip Stream(File, SG_FILE_W);
+			CSG_Archive Stream(File, SG_FILE_W);
 
 			CSG_String Name(SG_File_Get_Name(File, false) + ".");
 
@@ -419,7 +431,7 @@ bool CSG_PointCloud::Get_Header_Content(const CSG_String &File, CSG_MetaData &He
 
 	if( SG_File_Cmp_Extension(File, "sg-pts-z") ) // POINTCLOUD_FILE_FORMAT_Compressed
 	{
-		CSG_File_Zip Stream(File, SG_FILE_R);
+		CSG_Archive Stream(File, SG_FILE_R);
 
 		CSG_String _File(SG_File_Get_Name(File, false) + ".");
 
@@ -437,7 +449,7 @@ bool CSG_PointCloud::Get_Header_Content(const CSG_String &File, CSG_MetaData &He
 }
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -589,9 +601,9 @@ CSG_MetaData CSG_PointCloud::_Create_Header(void) const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Assign							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -624,9 +636,9 @@ bool CSG_PointCloud::Assign(CSG_Data_Object *pObject)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Checks							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -650,9 +662,9 @@ bool CSG_PointCloud::is_Compatible(CSG_PointCloud *pPointCloud) const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Fields							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -849,7 +861,7 @@ bool CSG_PointCloud::Mov_Field(int Index, int Position)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1009,9 +1021,9 @@ bool CSG_PointCloud::_Get_Field_Value(char *pPoint, int iField, CSG_String &Valu
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1079,9 +1091,9 @@ bool CSG_PointCloud::Set_Point(sLong Index, const TSG_Point_3D &Point)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1167,9 +1179,9 @@ bool CSG_PointCloud::Del_Points(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1204,9 +1216,9 @@ bool CSG_PointCloud::_Dec_Array(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Statistics						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1290,9 +1302,9 @@ bool CSG_PointCloud::_Stats_Update(int Field) const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1309,9 +1321,9 @@ bool CSG_PointCloud::On_Delete(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1390,9 +1402,9 @@ CSG_Table_Record * CSG_PointCloud::Get_Record(sLong Index)	const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1466,9 +1478,9 @@ CSG_Shape * CSG_PointCloud::Add_Shape(CSG_Table_Record *pCopy, TSG_ADD_Shape_Cop
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1548,7 +1560,7 @@ bool CSG_PointCloud::Select(const TSG_Point &Point, bool bInvert)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1559,7 +1571,7 @@ bool CSG_PointCloud::is_Selected(sLong Index)	const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1599,7 +1611,7 @@ const CSG_Rect & CSG_PointCloud::Get_Selection_Extent(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1667,9 +1679,40 @@ sLong CSG_PointCloud::Inv_Selection(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool CSG_PointCloud::Sort(const CSG_Index &Index)
+{
+	m_Points[m_nRecords++]	= (char *)SG_Calloc(m_nPointBytes, sizeof(char));
+
+	if( Get_Count() > 0 && Get_Count() == Index.Get_Count() )
+	{
+		char **Points = (char **)SG_Malloc(m_nBuffer * sizeof(char *)); memcpy(Points, m_Points, Get_Count());
+
+		for(sLong i=0; i<Get_Count(); i++)
+		{
+			m_Points[i] = Points[Index[i]];
+		}
+
+		SG_Free(Points);
+
+		Del_Index(); m_Cursor = NULL;
+
+		return( true );
+	}
+
+	return( false );
+}
+
+
+///////////////////////////////////////////////////////////
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
