@@ -56,9 +56,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -138,9 +138,9 @@ CSG_Table * SG_Create_Table(const CSG_String &File, TSG_Table_File_Type Format,
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -288,7 +288,7 @@ bool CSG_Table::Create(const CSG_Table *pTemplate)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -312,7 +312,7 @@ void CSG_Table::_On_Construction(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -353,9 +353,9 @@ bool CSG_Table::Destroy(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Assign							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -414,9 +414,9 @@ bool CSG_Table::Assign_Values(const SG_Char *FileName)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Checks							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -465,9 +465,9 @@ bool CSG_Table::is_Compatible(CSG_Table *pTable, bool bExactMatch) const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Fields							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -597,7 +597,7 @@ bool CSG_Table::Mov_Field(int iField, int Position)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -728,9 +728,9 @@ bool CSG_Table::Find_Field(const CSG_String &Name, int &Index) const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Records							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -932,7 +932,7 @@ bool CSG_Table::Set_Count(sLong nRecords)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1097,9 +1097,9 @@ CSG_Table_Record * CSG_Table::Find_Record(int iField, double Value, bool bCreate
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Value Access					 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1184,9 +1184,9 @@ bool CSG_Table::Get_Value(sLong iRecord, int iField, double      &Value) const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Statistics						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1264,9 +1264,9 @@ bool CSG_Table::_Stats_Update(int iField) const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1292,9 +1292,47 @@ bool CSG_Table::On_Update(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
+//						Sort							 //
+//                                                       //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool CSG_Table::Sort(const char       *Field, bool bAscending) { return( Sort(Get_Field(Field), bAscending) ); }
+bool CSG_Table::Sort(const wchar_t    *Field, bool bAscending) { return( Sort(Get_Field(Field), bAscending) ); }
+bool CSG_Table::Sort(const CSG_String &Field, bool bAscending) { return( Sort(Get_Field(Field), bAscending) ); }
+bool CSG_Table::Sort(int               Field, bool bAscending)
+{
+	CSG_Index Index; return( Set_Index(Index, Field, bAscending) && Sort(Index) );
+}
+
+//---------------------------------------------------------
+bool CSG_Table::Sort(const CSG_Index &Index)
+{
+	if( Get_Count() > 0 && Get_Count() == Index.Get_Count() )
+	{
+		CSG_Table_Record **Records = m_Records; m_Records = (CSG_Table_Record **)SG_Malloc(m_nBuffer * sizeof(CSG_Table_Record *));
+
+		for(sLong i=0; i<Get_Count(); i++)
+		{
+			m_Records[i] = Records[Index[i]];
+		}
+
+		SG_Free(Records);
+
+		Del_Index();
+
+		return( true );
+	}
+
+	return( false );
+}
+
+
+///////////////////////////////////////////////////////////
+//                                                       //
 //						Index							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1359,7 +1397,7 @@ bool CSG_Table::Toggle_Index(int iField)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1425,7 +1463,7 @@ bool CSG_Table::Set_Index(CSG_Index &Index, int Field, bool bAscending) const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1433,7 +1471,7 @@ class CSG_Table_Record_Compare_Fields : public CSG_Index::CSG_Index_Compare
 {
 public:
 	CSG_Table_Record_Compare_Fields(const CSG_Table *pTable, int Fields[], int nFields, bool Ascending)
-		: m_pTable(pTable), m_Fields(Fields), m_nFields(nFields)
+		: m_Fields(Fields), m_nFields(nFields), m_pTable(pTable)
 	{
 		m_Ascending.Create(nFields);
 
@@ -1449,7 +1487,7 @@ public:
 	}
 
 	CSG_Table_Record_Compare_Fields(const CSG_Table *pTable, int Fields[], int nFields, int Ascending[])
-		: m_pTable(pTable), m_Fields(Fields), m_nFields(nFields)
+		: m_Fields(Fields), m_nFields(nFields), m_pTable(pTable)
 	{
 		m_Ascending.Create(nFields);
 
@@ -1547,9 +1585,9 @@ void CSG_Table::_Index_Update(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
