@@ -55,9 +55,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -74,7 +74,7 @@ bool CSG_Table::On_Delete(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -82,7 +82,7 @@ bool CSG_Table::Set_File_Encoding(int Encoding)
 {
 	if( Encoding >= 0 && Encoding < SG_FILE_ENCODING_UNDEFINED )
 	{
-		m_Encoding	= Encoding;
+		m_Encoding = Encoding;
 
 		return( true );
 	}
@@ -92,15 +92,15 @@ bool CSG_Table::Set_File_Encoding(int Encoding)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-bool CSG_Table::Load(const CSG_String &FileName, int Format, SG_Char Separator, int Encoding)
+bool CSG_Table::Load(const CSG_String &File, int Format, SG_Char Separator, int Encoding)
 {
 	Set_File_Encoding(Encoding);
 
-	if( !SG_File_Exists(FileName) )
+	if( !SG_File_Exists(File) )
 	{
 		return( false );
 	}
@@ -108,12 +108,7 @@ bool CSG_Table::Load(const CSG_String &FileName, int Format, SG_Char Separator,
 	//-----------------------------------------------------
 	if( Format == TABLE_FILETYPE_Undefined )
 	{
-		Format	= SG_File_Cmp_Extension(FileName, "dbf") ? TABLE_FILETYPE_DBase : TABLE_FILETYPE_Text;
-	}
-
-	if( Separator == '\0' )
-	{
-		Separator	= SG_File_Cmp_Extension(FileName, "csv") ? ',' : '\t';	// comma separated values or tab spaced text
+		Format = SG_File_Cmp_Extension(File, "dbf") ? TABLE_FILETYPE_DBase : TABLE_FILETYPE_Text;
 	}
 
 	//-----------------------------------------------------
@@ -121,23 +116,23 @@ bool CSG_Table::Load(const CSG_String &FileName, int Format, SG_Char Separator,
 
 	switch( Format )
 	{
-	case TABLE_FILETYPE_Text:   default: if( !_Load_Text (FileName, true , Separator) ) return( false ); break;
-	case TABLE_FILETYPE_Text_NoHeadLine: if( !_Load_Text (FileName, false, Separator) ) return( false ); break;
-	case TABLE_FILETYPE_DBase          : if( !_Load_DBase(FileName                  ) ) return( false ); break;
+	case TABLE_FILETYPE_Text:   default: if( !_Load_Text (File, true , Separator) ) return( false ); break;
+	case TABLE_FILETYPE_Text_NoHeadLine: if( !_Load_Text (File, false, Separator) ) return( false ); break;
+	case TABLE_FILETYPE_DBase          : if( !_Load_DBase(File                  ) ) return( false ); break;
 	}
 
 	//-----------------------------------------------------
-	Set_Name(SG_File_Get_Name(FileName, false));
+	Set_Name(SG_File_Get_Name(File, false));
 
-	Load_MetaData(FileName);
+	Load_MetaData(File);
 
-	CSG_MetaData	*pFields	= Get_MetaData_DB().Get_Child("FIELDS");
+	CSG_MetaData *pFields = Get_MetaData_DB().Get_Child("FIELDS");
 
 	if( pFields && pFields->Get_Children_Count() == Get_Field_Count() )
 	{
-		for(int iField=0; iField<Get_Field_Count(); iField++)
+		for(int Field=0; Field<Get_Field_Count(); Field++)
 		{
-			Set_Field_Name(iField, pFields->Get_Content(iField));
+			Set_Field_Name(Field, pFields->Get_Content(Field));
 		}
 	}
 
@@ -146,59 +141,64 @@ bool CSG_Table::Load(const CSG_String &FileName, int Format, SG_Char Separator,
 }
 
 //---------------------------------------------------------
-bool CSG_Table::Save(const CSG_String &FileName, int Format)
+bool CSG_Table::Save(const CSG_String &File, int Format)
 {
-	return( Save(FileName, Format, '\0', m_Encoding) );
+	return( Save(File, Format, '\0', m_Encoding) );
 }
 
 //---------------------------------------------------------
-bool CSG_Table::Save(const CSG_String &FileName, int Format, SG_Char Separator, int Encoding)
+bool CSG_Table::Save(const CSG_String &File, int Format, SG_Char Separator, int Encoding)
 {
-	SG_UI_Msg_Add(CSG_String::Format("%s %s: %s...", _TL("Saving"), _TL("table"), FileName.c_str()), true);
+	if( File.is_Empty() )
+	{
+		return( *Get_File_Name(false) ? Save(Get_File_Name(false), Format) : false );
+	}
+
+	SG_UI_Msg_Add(CSG_String::Format("%s %s: %s...", _TL("Saving"), _TL("table"), File.c_str()), true);
 
 	Set_File_Encoding(Encoding);
 
 	//-----------------------------------------------------
 	if( Format <= TABLE_FILETYPE_Undefined || Format > TABLE_FILETYPE_DBase )
 	{
-		if( SG_File_Cmp_Extension(FileName, "dbf") )
+		if( SG_File_Cmp_Extension(File, "dbf") )
 		{
-			Format	= TABLE_FILETYPE_DBase;
+			Format = TABLE_FILETYPE_DBase;
 		}
 		else
 		{
-			Format	= TABLE_FILETYPE_Text;
+			Format = TABLE_FILETYPE_Text;
 
 			if( Separator == '\0' )
 			{
-				Separator	= SG_File_Cmp_Extension(FileName, "csv") ? ',' : '\t';	// comma separated values or tab spaced text
+				Separator = SG_File_Cmp_Extension(File, "csv") ? ',' : '\t'; // comma separated values or tab spaced text
 			}
 		}
 	}
 
 	//-----------------------------------------------------
-	bool	bResult	= false;
+	bool bResult = false;
 
 	switch( Format )
 	{
-	case TABLE_FILETYPE_Text:   default: bResult = _Save_Text (FileName, true , Separator); break;
-	case TABLE_FILETYPE_Text_NoHeadLine: bResult = _Save_Text (FileName, false, Separator); break;
-	case TABLE_FILETYPE_DBase          : bResult = _Save_DBase(FileName                  ); break;
+	case TABLE_FILETYPE_Text:   default: bResult = _Save_Text (File, true , Separator); break;
+	case TABLE_FILETYPE_Text_NoHeadLine: bResult = _Save_Text (File, false, Separator); break;
+	case TABLE_FILETYPE_DBase          : bResult = _Save_DBase(File                  ); break;
 	}
 
 	//-----------------------------------------------------
-	CSG_MetaData	*pFields	= Get_MetaData_DB().Get_Child("FIELDS");
+	CSG_MetaData *pFields = Get_MetaData_DB().Get_Child("FIELDS");
 
 	if( !pFields )
 	{
-		pFields	= Get_MetaData_DB().Add_Child("FIELDS");
+		pFields = Get_MetaData_DB().Add_Child("FIELDS");
 	}
 
 	pFields->Del_Children();
 
-	for(int iField=0; iField<Get_Field_Count(); iField++)
+	for(int Field=0; Field<Get_Field_Count(); Field++)
 	{
-		pFields->Add_Child("FIELD", Get_Field_Name(iField))->Add_Property("TYPE", gSG_Data_Type_Identifier[Get_Field_Type(iField)]);
+		pFields->Add_Child("FIELD", Get_Field_Name(Field))->Add_Property("TYPE", gSG_Data_Type_Identifier[Get_Field_Type(Field)]);
 	}
 
 	//-----------------------------------------------------
@@ -210,9 +210,9 @@ bool CSG_Table::Save(const CSG_String &FileName, int Format, SG_Char Separator,
 
 		Set_File_Type(Format);
 
-		Set_File_Name(FileName, true);
+		Set_File_Name(File, true);
 
-		Save_MetaData(FileName);
+		Save_MetaData(File);
 
 		SG_UI_Msg_Add(_TL("okay"), false, SG_UI_MSG_STYLE_SUCCESS);
 
@@ -226,9 +226,9 @@ bool CSG_Table::Save(const CSG_String &FileName, int Format, SG_Char Separator,
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//						Text							 //
-//														 //
+//                                                       //
+//                         Text                          //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -236,13 +236,13 @@ size_t CSG_Table::_Load_Text_Trim(CSG_String &s, const SG_Char Separator)
 {
 	for(size_t i=0; i<s.Length(); i++)
 	{
-		SG_Char	c	= s[i];
+		SG_Char c = s[i];
 
 		if( c == Separator || (c != ' ' && c != '\t' && c != '\n' && c != '\v' && c != '\f' && c != '\r') )
 		{
 			if( i > 0 )
 			{
-				s	= s.Right(s.Length() - i);
+				s = s.Right(s.Length() - i);
 			}
 
 			return( i );
@@ -257,7 +257,7 @@ size_t	CSG_Table::_Load_Text_EndQuote(const CSG_String &s, const SG_Char Separat
 {
 	if( s.Length() > 1 && s[0] == '\"' )
 	{
-		bool	bInQuotes	= true;
+		bool bInQuotes = true;
 
 		for(size_t i=1; i<s.Length(); i++)
 		{
@@ -265,12 +265,12 @@ size_t	CSG_Table::_Load_Text_EndQuote(const CSG_String &s, const SG_Char Separat
 			{
 				if( s[i] == '\"' )
 				{
-					bInQuotes	= false;
+					bInQuotes = false;
 				}
 			}
 			else if( s[i] == '\"' )
 			{
-				bInQuotes	= true;
+				bInQuotes = true;
 			}
 			else if( s[i] == Separator )
 			{
@@ -288,64 +288,97 @@ size_t	CSG_Table::_Load_Text_EndQuote(const CSG_String &s, const SG_Char Separat
 }
 
 //---------------------------------------------------------
-bool CSG_Table::_Load_Text(const CSG_String &FileName, bool bHeadline, const SG_Char Separator)
+bool CSG_Table::_Load_Text(const CSG_String &File, bool bHeadline, const SG_Char _Separator)
 {
-	CSG_File	Stream;
+	CSG_File Stream;
 
-	if( Stream.Open(FileName, SG_FILE_R, false, m_Encoding) == false )
+	if( Stream.Open(File, SG_FILE_R, false, m_Encoding) == false )
 	{
 		return( false );
 	}
 
 	sLong fLength = Stream.Length();
 
-	if( fLength <= 0 )
-	{
-		return( false );
-	}
-
-	CSG_String	sLine;
-
-	if( !Stream.Read_Line(sLine) )
+	if( fLength < 1 )
 	{
 		return( false );
 	}
 
 	//-----------------------------------------------------
-	CSG_Table	Table;
+	CSG_String Line;
 
-	_Load_Text_Trim(sLine, Separator);
-
-	while( !sLine.is_Empty() )
+	if( !Stream.Read_Line(Line) ) // end-of-file !
 	{
-		CSG_String	sField;
+		return( false );
+	}
 
-		if( sLine[0] == '\"' )	// value in quotas
+	if( Line[0] == 65279 ) // 65279 => '\uFEFF' => BOM => zero-width no-break space ! ...to do: recognizing other 'magic' first characters !
+	{
+		Line.Remove(0, 1);
+	}
+
+	bool bCSV = SG_File_Cmp_Extension(File, "csv");
+
+	while( Line.is_Empty() || (bCSV && Line[0] == '#') ) // empty or comment
+	{
+		if( !Stream.Read_Line(Line) ) // end-of-file !
 		{
-			sField	= sLine.AfterFirst('\"').BeforeFirst('\"');
-			sLine	= sLine.AfterFirst('\"').AfterFirst ('\"');
+			return( false );
+		}
+	}
+
+	//-----------------------------------------------------
+	SG_Char Separator = _Separator;
+
+	if( Separator == '\0' )
+	{
+		if( bCSV ) // comma separated values
+		{
+			Separator = Line.Find(';') >= 0 ? ';' : ','; // assume semicolon as value separator, comma as decimal separator!
+		}
+		else // assume tab spaced text table
+		{
+			Separator = '\t';
+		}
+	}
+
+	bool bComma2Point = bCSV && Separator == ';';
+
+	//-----------------------------------------------------
+	CSG_Table Table;
+
+	_Load_Text_Trim(Line, Separator);
+
+	while( !Line.is_Empty() )
+	{
+		CSG_String Value;
+
+		if( Line[0] == '\"' ) // value in quotas
+		{
+			Value = Line.AfterFirst('\"').BeforeFirst('\"');
+			Line  = Line.AfterFirst('\"').AfterFirst ('\"');
 		}
 		else
 		{
-			sField	= sLine.BeforeFirst(Separator);
+			Value = Line.BeforeFirst(Separator);
 		}
 
-		sLine	= sLine.AfterFirst(Separator);	_Load_Text_Trim(sLine, Separator);
+		Line = Line.AfterFirst(Separator); _Load_Text_Trim(Line, Separator);
 
-		if( !bHeadline || sField.Length() == 0 )
+		if( !bHeadline || Value.Length() == 0 )
 		{
-			sField.Printf("F%02d", Table.Get_Field_Count() + 1);
+			Value.Printf("F%02d", Table.Get_Field_Count() + 1);
 		}
 
-		Table.Add_Field(sField, SG_DATATYPE_String);
+		Table.Add_Field(Value, SG_DATATYPE_String);
 	}
 
 	//-----------------------------------------------------
-	TSG_Data_Type	*Type	= new TSG_Data_Type[Table.Get_Field_Count()];
+	TSG_Data_Type *Types = new TSG_Data_Type[Table.Get_Field_Count()];
 
-	for(int iField=0; iField<Table.Get_Field_Count(); iField++)
+	for(int Field=0; Field<Table.Get_Field_Count(); Field++)
 	{
-		Type[iField]	= SG_DATATYPE_Int;
+		Types[Field] = SG_DATATYPE_Int;
 	}
 
 	if( !bHeadline )
@@ -353,96 +386,105 @@ bool CSG_Table::_Load_Text(const CSG_String &FileName, bool bHeadline, const SG_
 		Stream.Seek_Start();
 	}
 
-	while( Stream.Read_Line(sLine) && SG_UI_Process_Set_Progress((double)Stream.Tell(), (double)fLength) )
+	while( Stream.Read_Line(Line) && SG_UI_Process_Set_Progress((double)Stream.Tell(), (double)fLength) )
 	{
-		if( sLine.Length() < 1 )
+		if( Line.is_Empty() || (bCSV && Line[0] == '#') ) // empty or comment
 		{
 			continue;
 		}
 
-		CSG_Table_Record *pRecord = Table.Add_Record();
+		CSG_Table_Record &Record = *Table.Add_Record();
 
-		_Load_Text_Trim(sLine, Separator);
+		_Load_Text_Trim(Line, Separator);
 
-		for(int iField=0; iField<Table.Get_Field_Count() && !sLine.is_Empty(); iField++)
+		for(int Field=0; Field<Table.Get_Field_Count() && !Line.is_Empty(); Field++)
 		{
-			size_t Position = _Load_Text_EndQuote(sLine, Separator); CSG_String sField;
+			size_t Position = _Load_Text_EndQuote(Line, Separator); CSG_String Value;
 
-			if( Position > 0 )	// value in quotas !!!
+			if( Position > 0 ) // value in quotas !!!
 			{
 				if( Position - 2 > 0 )
 				{
-					sField	= sLine.Mid(1, Position - 2);
+					Value = Line.Mid(1, Position - 2);
 				}
 				else
 				{
-					sField.Clear();
+					Value.Clear();
 				}
 
-				sLine	= sLine.Right(sLine.Length() - Position);
+				Line = Line.Right(Line.Length() - Position);
 
-				Type[iField]	= SG_DATATYPE_String;
+				Types[Field] = SG_DATATYPE_String;
 			}
 			else
 			{
-				sField	= sLine.BeforeFirst(Separator);
+				Value = Line.BeforeFirst(Separator);
+
+				if( bComma2Point )
+				{
+					Value.Replace(",", ".");
+				}
 			}
 
-			sLine	= sLine.AfterFirst(Separator);	_Load_Text_Trim(sLine, Separator);
+			Line = Line.AfterFirst(Separator); _Load_Text_Trim(Line, Separator);
 
 			//---------------------------------------------
-			if( Type[iField] != SG_DATATYPE_String && !sField.is_Empty() )
+			if( Types[Field] != SG_DATATYPE_String && !Value.is_Empty() )
 			{
-				try
+				if( Value[0] == '0' && Value[1] != '.' ) // keep leading zero(s) => don't interpret as number !
 				{
-					size_t pos; double Value = std::stod(sField.to_StdString(), &pos);
+					Types[Field] = SG_DATATYPE_String;
+				}
+				else try
+				{
+					size_t pos; double number = std::stod(Value.to_StdString(), &pos);
 
-					if( pos < sField.Length() )
+					if( pos < Value.Length() )
 					{
-						Type[iField]	= SG_DATATYPE_String;
+						Types[Field] = SG_DATATYPE_String;
 					}
-					else if( Type[iField] != SG_DATATYPE_Double && (Value - (int)Value != 0. || sField.Find('.') >= 0) )
+					else if( Types[Field] != SG_DATATYPE_Double && (number - (int)number != 0. || Value.Find('.') >= 0) )
 					{
-						Type[iField]	= SG_DATATYPE_Double;
+						Types[Field] = SG_DATATYPE_Double;
 					}
 				}
 				catch(...)
 				{
-					Type[iField]	= SG_DATATYPE_String;
+					Types[Field] = SG_DATATYPE_String;
 				}
 			}
 
-			pRecord->Set_Value(iField, sField);
+			Record.Set_Value(Field, Value);
 		}
 	}
 
 	//-----------------------------------------------------
 	if( Table.Get_Field_Count() > 0 )
 	{
-		for(int iField=0; iField<Table.Get_Field_Count(); iField++)
+		for(int Field=0; Field<Table.Get_Field_Count(); Field++)
 		{
-			Add_Field(Table.Get_Field_Name(iField), Type[iField]);
+			Add_Field(Table.Get_Field_Name(Field), Types[Field]);
 		}
 
-		for(sLong iRecord=0; iRecord<Table.Get_Count() && SG_UI_Process_Set_Progress(iRecord, Table.Get_Count()); iRecord++)
+		for(sLong i=0; i<Table.Get_Count() && SG_UI_Process_Set_Progress(i, Table.Get_Count()); i++)
 		{
-			CSG_Table_Record *pRecord = Add_Record();
+			CSG_Table_Record &Record = *Add_Record();
 
-			for(int iField=0; iField<Get_Field_Count(); iField++)
+			for(int Field=0; Field<Get_Field_Count(); Field++)
 			{
-				if( *Table[iRecord].asString(iField) )
+				if( *Table[i].asString(Field) )
 				{
-					pRecord->Set_Value(iField, Table[iRecord].asString(iField));
+					Record.Set_Value(Field, Table[i].asString(Field));
 				}
 				else
 				{
-					pRecord->Set_NoData(iField);
+					Record.Set_NoData(Field);
 				}
 			}
 		}
 	}
 
-	delete[](Type);
+	delete[](Types);
 
 	SG_UI_Process_Set_Ready();
 
@@ -450,35 +492,35 @@ bool CSG_Table::_Load_Text(const CSG_String &FileName, bool bHeadline, const SG_
 }
 
 //---------------------------------------------------------
-bool CSG_Table::_Save_Text(const CSG_String &FileName, bool bHeadline, const SG_Char Separator)
+bool CSG_Table::_Save_Text(const CSG_String &File, bool bHeadline, const SG_Char Separator)
 {
 	CSG_File Stream;
 
-	if( Get_Field_Count() <= 0 || Stream.Open(FileName, SG_FILE_W, false, m_Encoding) == false )
+	if( Get_Field_Count() <= 0 || Stream.Open(File, SG_FILE_W, false, m_Encoding) == false )
 	{
 		return( false );
 	}
 
 	//-----------------------------------------------------
-	for(int iField=0; iField<Get_Field_Count(); iField++)
+	for(int Field=0; Field<Get_Field_Count(); Field++)
 	{
-		Stream.Printf("%s%c", Get_Field_Name(iField), iField < Get_Field_Count() - 1 ? Separator : '\n');
+		Stream.Printf("%s%c", Get_Field_Name(Field), Field < Get_Field_Count() - 1 ? Separator : '\n');
 	}
 
 	//-----------------------------------------------------
-	for(sLong iRecord=0; iRecord<Get_Count() && SG_UI_Process_Set_Progress(iRecord, Get_Count()); iRecord++)
+	for(sLong i=0; i<Get_Count() && SG_UI_Process_Set_Progress(i, Get_Count()); i++)
 	{
-		CSG_Table_Record *pRecord = Get_Record_byIndex(iRecord);
+		CSG_Table_Record &Record = *Get_Record_byIndex(i);
 
-		for(int iField=0; iField<Get_Field_Count(); iField++)
+		for(int Field=0; Field<Get_Field_Count(); Field++)
 		{
-			switch( Get_Field_Type(iField) )
+			switch( Get_Field_Type(Field) )
 			{
 			case SG_DATATYPE_String:
 			case SG_DATATYPE_Date  :
-				if( !pRecord->is_NoData(iField) )
+				if( !Record.is_NoData(Field) )
 				{
-					Stream.Printf("\"%s\"", pRecord->asString(iField));
+					Stream.Printf("\"%s\"", Record.asString(Field));
 				}
 				else
 				{
@@ -487,14 +529,14 @@ bool CSG_Table::_Save_Text(const CSG_String &FileName, bool bHeadline, const SG_
 				break;
 
 			default:
-				if( !pRecord->is_NoData(iField) )
+				if( !Record.is_NoData(Field) )
 				{
-					Stream.Printf("%s", pRecord->asString(iField));
+					Stream.Printf("%s", Record.asString(Field));
 				}
 				break;
 			}
 
-			Stream.Printf("%c", iField < Get_Field_Count() - 1 ? Separator : '\n');
+			Stream.Printf("%c", Field < Get_Field_Count() - 1 ? Separator : '\n');
 		}
 	}
 
@@ -506,32 +548,142 @@ bool CSG_Table::_Save_Text(const CSG_String &FileName, bool bHeadline, const SG_
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//						DBase							 //
-//														 //
+//                                                       //
+//                        DBase                          //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-bool CSG_Table::_Load_DBase(const CSG_String &FileName)
+bool CSG_Table::_Load_DBase(const CSG_String &File)
 {
 	CSG_Table_DBase dbf(m_Encoding);
 
-	return( dbf.Open_Read(FileName, this) );
+	return( dbf.Open_Read(File, this) );
 }
 
 //---------------------------------------------------------
-bool CSG_Table::_Save_DBase(const CSG_String &FileName)
+bool CSG_Table::_Save_DBase(const CSG_String &File)
 {
 	CSG_Table_DBase dbf(m_Encoding);
 
-	return( dbf.Open_Write(FileName, this) );
+	return( dbf.Open_Write(File, this) );
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//						Serialize						 //
-//														 //
+//                                                       //
+//                     From/To Text                      //
+//                                                       //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool CSG_Table::from_Text(const CSG_String &Text)
+{
+	if( Text.is_Empty() )
+	{
+		return( false );
+	}
+
+	Destroy(); Set_Name(_TL("New Table"));
+
+	//-----------------------------------------------------
+	CSG_Strings Values, Records(SG_String_Tokenize(Text, "\r\n"));
+
+	Values = (SG_String_Tokenize(Records[0], "\t"));
+
+	TSG_Data_Type *Types = new TSG_Data_Type[Values.Get_Count()];
+
+	for(int Field=0; Field<Values.Get_Count(); Field++)
+	{
+		Add_Field(Values[Field], SG_DATATYPE_String); Types[Field] = SG_DATATYPE_Int;
+	}
+
+	//-----------------------------------------------------
+	for(int i=1; i<Records.Get_Count(); i++)
+	{
+		CSG_Table_Record &Record = *Add_Record();
+
+		Values = (SG_String_Tokenize(Records[i], "\t"));
+
+		for(int Field=0; Field<Values.Get_Count() && Field<Get_Field_Count(); Field++)
+		{
+			CSG_String Value(Values[Field]);
+
+			if( Value.Length() >= 2 && Value[0] == '\"' && Value[Value.Length() - 1] == '\"' ) // is string, remove quota
+			{
+				Types[Field] = SG_DATATYPE_String; Value = Value.Mid(1, Value.Length() - 2);
+			}
+
+			Record.Set_Value(Field, Value);
+
+			if( Types[Field] != SG_DATATYPE_String && !Value.is_Empty() )
+			{
+				if( Value[0] == '0' && Value[1] != '.' ) // keep leading zero(s) => don't interpret as number !
+				{
+					Types[Field] = SG_DATATYPE_String;
+				}
+				else try
+				{
+					size_t pos; double number = std::stod(Value.to_StdString(), &pos);
+
+					if( pos < Value.Length() )
+					{
+						Types[Field] = SG_DATATYPE_String;
+					}
+					else if( Types[Field] != SG_DATATYPE_Double && (number - (int)number != 0. || Value.Find('.') >= 0) )
+					{
+						Types[Field] = SG_DATATYPE_Double;
+					}
+				}
+				catch(...)
+				{
+					Types[Field] = SG_DATATYPE_String;
+				}
+			}
+		}
+	}
+
+	//-----------------------------------------------------
+	for(int Field=0; Field<Get_Field_Count(); Field++)
+	{
+		Set_Field_Type(Field, Types[Field]);
+	}
+
+	delete[](Types);
+
+	return( Get_Field_Count() > 1 || Get_Count() > 0 );
+}
+
+//---------------------------------------------------------
+CSG_String CSG_Table::to_Text(bool Selection) const
+{
+	CSG_String Text;
+
+	for(int Field=0; Field<Get_Field_Count(); Field++)
+	{
+		Text += Get_Field_Name(Field); Text += 1 + Field < Get_Field_Count() ? '\t' : '\n';
+	}
+
+	sLong n = Selection ? Get_Selection_Count() : Get_Count();
+
+	for(sLong i=0; i<n; i++)
+	{
+		CSG_Table_Record &Record = Selection ? *Get_Selection(i) : *Get_Record_byIndex(i);
+
+		for(int Field=0; Field<Get_Field_Count(); Field++)
+		{
+			Text += Record.asString(Field); Text += 1 + Field < Get_Field_Count() ? '\t' : '\n';
+		}
+	}
+
+	return( Text );
+}
+
+
+///////////////////////////////////////////////////////////
+//                                                       //
+//                      Serialize                        //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -544,16 +696,16 @@ bool CSG_Table::Serialize(CSG_File &Stream, bool bSave)
 	{
 		Stream.Printf("%d %d\n", m_nFields, m_nRecords);
 
-		for(int iField=0; iField<m_nFields; iField++)
+		for(int Field=0; Field<m_nFields; Field++)
 		{
-			Stream.Printf("%d \"%s\"\n", Get_Field_Type(iField), Get_Field_Name(iField));
+			Stream.Printf("%d \"%s\"\n", Get_Field_Type(Field), Get_Field_Name(Field));
 		}
 
-		for(sLong iRecord=0; iRecord<m_nRecords; iRecord++)
+		for(sLong i=0; i<m_nRecords; i++)
 		{
-			for(int iField=0; iField<m_nFields; iField++)
+			for(int Field=0; Field<m_nFields; Field++)
 			{
-				Stream.Printf("%s%c", Get_Record(iRecord)->asString(iField), iField < m_nFields - 1 ? Separator : '\n');
+				Stream.Printf("%s%c", Get_Record(i)->asString(Field), Field < m_nFields - 1 ? Separator : '\n');
 			}
 		}
 
@@ -567,7 +719,7 @@ bool CSG_Table::Serialize(CSG_File &Stream, bool bSave)
 	{
 		Destroy();
 
-		for(int iField=0; iField<nFields; iField++)
+		for(int Field=0; Field<nFields; Field++)
 		{
 			if( Stream.Read_Line(sLine) && SG_SSCANF(sLine, SG_T("%d"), &FieldType) == 1 )
 			{
@@ -575,15 +727,15 @@ bool CSG_Table::Serialize(CSG_File &Stream, bool bSave)
 			}
 		}
 
-		for(sLong iRecord=0; iRecord<nRecords; iRecord++)
+		for(sLong i=0; i<nRecords; i++)
 		{
 			if( Stream.Read_Line(sLine) )
 			{
-				CSG_Table_Record *pRecord = Add_Record();
+				CSG_Table_Record &Record = *Add_Record();
 
-				for(int iField=0; iField<m_nFields; iField++)
+				for(int Field=0; Field<m_nFields; Field++)
 				{
-					pRecord->Set_Value(iField, sLine.BeforeFirst(Separator));
+					Record.Set_Value(Field, sLine.BeforeFirst(Separator));
 
 					sLine = sLine.AfterFirst(Separator);
 				}
@@ -599,9 +751,9 @@ bool CSG_Table::Serialize(CSG_File &Stream, bool bSave)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
