@@ -1346,40 +1346,40 @@ CSG_String CSG_Tool::Get_Script(TSG_Tool_Script_Type Type, bool bHeader, bool bA
 //---------------------------------------------------------
 CSG_String CSG_Tool::_Get_Script_CMD(bool bHeader, bool bAllParameters, TSG_Tool_Script_Type Type)
 {
-	CSG_String	Script;
+	CSG_String Script;
 
 	if( bHeader )
 	{
 		switch( Type )
 		{
 		case TOOL_SCRIPT_CMD_BATCH:	// DOS/Windows Batch Script
-			Script	+= "@ECHO OFF\n\n";
-			Script	+= "PUSHD %~dp0\n\n";
-			Script	+= "REM SET SAGA_TLB=C:\\MyTools\n\n";
-			Script	+= "SET SAGA_CMD=" + SG_UI_Get_Application_Path(true) + "saga_cmd.exe\n\n";
-			Script	+= "REM Tool: " + Get_Name() + "\n\n";
-			Script	+= "%SAGA_CMD%";
+			Script += "@ECHO OFF\n\n";
+			Script += "PUSHD %~dp0\n\n";
+			Script += "REM SET SAGA_TLB=C:\\MyTools\n\n";
+			Script += "SET SAGA_CMD=" + SG_UI_Get_Application_Path(true) + "saga_cmd.exe\n\n";
+			Script += "REM Tool: " + Get_Name() + "\n\n";
+			Script += "%SAGA_CMD%";
 			break;
 
 		default                   :	// Bash Shell Script
-			Script	+= "#!/bin/bash\n\n";
-			Script	+= "# export SAGA_TLB=/home/myhome/mytools\n\n";
-			Script	+= "# tool: " + Get_Name() + "\n\n";
-			Script	+= "saga_cmd";
+			Script += "#!/bin/bash\n\n";
+			Script += "# export SAGA_TLB=~/mytools\n\n";
+			Script += "# tool: " + Get_Name() + "\n\n";
+			Script += "saga_cmd";
 			break;
 		}
 	}
 	else
 	{
-		Script	+= "saga_cmd";
+		Script += "saga_cmd";
 	}
 
 	//-----------------------------------------------------
-	Script	+= Get_Library().Contains(" ")	// white space? use quotation marks!
+	Script += Get_Library().Contains(" ")	// white space? use quotation marks!
 		? " \"" + Get_Library() + "\""
 		: " "   + Get_Library();
 
-	Script	+= Get_ID().Contains     (" ")	// white space? use quotation marks!
+	Script += Get_ID().Contains     (" ")	// white space? use quotation marks!
 		? " \"" + Get_ID     () + "\""
 		: " "   + Get_ID     ();
 
@@ -1391,9 +1391,9 @@ CSG_String CSG_Tool::_Get_Script_CMD(bool bHeader, bool bAllParameters, TSG_Tool
 	}
 
 	//-----------------------------------------------------
-	if( bHeader && Type == TOOL_SCRIPT_CMD_BATCH )
+	if( bHeader )
 	{
-		Script	+= "\n\nPAUSE\n";
+		Script += Type == TOOL_SCRIPT_CMD_BATCH ? "\n\nPAUSE\n" : "\n";
 	}
 
 	return( Script );
@@ -1402,19 +1402,14 @@ CSG_String CSG_Tool::_Get_Script_CMD(bool bHeader, bool bAllParameters, TSG_Tool
 //---------------------------------------------------------
 void CSG_Tool::_Get_Script_CMD(CSG_String &Script, CSG_Parameters *pParameters, bool bAllParameters, TSG_Tool_Script_Type Type)
 {
-	#define GET_ID1(p)		(p->Get_Parameters()->Get_Identifier().Length() > 0 \
+	#define GET_ID1(p) (p->Get_Parameters()->Get_Identifier().Length() > 0 \
 		? CSG_String::Format("%s_%s", p->Get_Parameters()->Get_Identifier().c_str(), p->Get_Identifier()) \
 		: CSG_String::Format(p->Get_Identifier())).c_str()
 
-	#define GET_ID2(p, s)	CSG_String::Format("%s_%s", GET_ID1(p), s).c_str()
+	#define GET_ID2(p, s) CSG_String::Format("%s_%s", GET_ID1(p), s).c_str()
 
-	CSG_String Prefix;
-
-	switch( Type )
-	{
-	case TOOL_SCRIPT_CMD_BATCH:	Prefix = " ^\n -" ; break;
-	default                   :	Prefix = " \\\n -"; break;
-	}
+	const char *Prefix = Type == TOOL_SCRIPT_CMD_BATCH ? " ^\n -"    : " \\\n -";
+	const char *StrFmt = Type == TOOL_SCRIPT_CMD_BATCH ? "%s=\"%s\"" : "%s=\\\"\"%s\"\\\"";
 
 	//-----------------------------------------------------
 	for(int iParameter=0; iParameter<pParameters->Get_Count(); iParameter++)
@@ -1432,61 +1427,63 @@ void CSG_Tool::_Get_Script_CMD(CSG_String &Script, CSG_Parameters *pParameters,
 			break;
 
 		case PARAMETER_TYPE_Bool             :
-			Script	+= Prefix + CSG_String::Format("%s=%d", GET_ID1(p), p->asBool() ? 1 : 0);
+			Script += Prefix + CSG_String::Format("%s=%d", GET_ID1(p), p->asBool() ? 1 : 0);
 			break;
 
 		case PARAMETER_TYPE_Int              :
 		case PARAMETER_TYPE_Data_Type        :
 		case PARAMETER_TYPE_Choice           :
 		case PARAMETER_TYPE_Table_Field      :
-			Script	+= Prefix + CSG_String::Format("%s=%d", GET_ID1(p), p->asInt());
+			Script += Prefix + CSG_String::Format("%s=%d", GET_ID1(p), p->asInt());
 			break;
 
 		case PARAMETER_TYPE_Choices          :
-		case PARAMETER_TYPE_Table_Fields:
+		case PARAMETER_TYPE_Table_Fields     :
 			if( p->asString() && *p->asString() )
-				Script	+= Prefix + CSG_String::Format("%s=%s", GET_ID1(p), p->asString());
+			{
+				Script += Prefix + CSG_String::Format(StrFmt, GET_ID1(p), p->asString());
+			}
 			break;
 
         case PARAMETER_TYPE_Color            :
-            Script	+= Prefix + CSG_String::Format("%s=\"%s\"", GET_ID1(p), SG_Color_To_Text(p->asColor()).c_str());
+            Script += Prefix + CSG_String::Format("%s=\"%s\"", GET_ID1(p), SG_Color_To_Text(p->asColor()).c_str());
             break;
 
 		case PARAMETER_TYPE_Double           :
 		case PARAMETER_TYPE_Degree           :
-			Script	+= Prefix + CSG_String::Format("%s=%g", GET_ID1(p), p->asDouble());
+			Script += Prefix + CSG_String::Format("%s=%g", GET_ID1(p), p->asDouble());
 			break;
 
 		case PARAMETER_TYPE_Range            :
-			Script	+= Prefix + CSG_String::Format("%s=%g", GET_ID2(p, SG_T("MIN")), p->asRange()->Get_Min());
-			Script	+= Prefix + CSG_String::Format("%s=%g", GET_ID2(p, SG_T("MAX")), p->asRange()->Get_Max());
+			Script += Prefix + CSG_String::Format("%s=%g", GET_ID2(p, SG_T("MIN")), p->asRange()->Get_Min());
+			Script += Prefix + CSG_String::Format("%s=%g", GET_ID2(p, SG_T("MAX")), p->asRange()->Get_Max());
 			break;
 
 		case PARAMETER_TYPE_String           :
 			if( ((CSG_Parameter_String *)p)->is_Password() )
 			{
-				Script	+= Prefix + CSG_String::Format("%s=\"***\"", GET_ID1(p));
+				Script += Prefix + CSG_String::Format("%s=\"***\"", GET_ID1(p));
 				break;
 			}
 
 		case PARAMETER_TYPE_Date             :
 		case PARAMETER_TYPE_Text             :
 		case PARAMETER_TYPE_FilePath         :
-			Script	+= Prefix + CSG_String::Format("%s=\"%s\"", GET_ID1(p), p->asString());
+			Script += Prefix + CSG_String::Format(StrFmt, GET_ID1(p), p->asString());
 			break;
 
 		case PARAMETER_TYPE_FixedTable       :
-			Script	+= Prefix + CSG_String::Format("%s=%s", GET_ID1(p), p->asString());
+			Script += Prefix + CSG_String::Format(StrFmt, GET_ID1(p), p->asString());
 			break;
 
 		case PARAMETER_TYPE_Grid_System      :
 			if( p->Get_Children_Count() == 0 )
 			{
-				Script	+= Prefix + CSG_String::Format("%s=%d", GET_ID2(p, SG_T("NX")), p->asGrid_System()->Get_NX());
-				Script	+= Prefix + CSG_String::Format("%s=%d", GET_ID2(p, SG_T("NY")), p->asGrid_System()->Get_NY());
-				Script	+= Prefix + CSG_String::Format("%s=%g", GET_ID2(p, SG_T( "X")), p->asGrid_System()->Get_XMin());
-				Script	+= Prefix + CSG_String::Format("%s=%g", GET_ID2(p, SG_T( "Y")), p->asGrid_System()->Get_YMin());
-				Script	+= Prefix + CSG_String::Format("%s=%g", GET_ID2(p, SG_T( "D")), p->asGrid_System()->Get_Cellsize());
+				Script += Prefix + CSG_String::Format("%s=%d", GET_ID2(p, SG_T("NX")), p->asGrid_System()->Get_NX      ());
+				Script += Prefix + CSG_String::Format("%s=%d", GET_ID2(p, SG_T("NY")), p->asGrid_System()->Get_NY      ());
+				Script += Prefix + CSG_String::Format("%s=%g", GET_ID2(p, SG_T( "X")), p->asGrid_System()->Get_XMin    ());
+				Script += Prefix + CSG_String::Format("%s=%g", GET_ID2(p, SG_T( "Y")), p->asGrid_System()->Get_YMin    ());
+				Script += Prefix + CSG_String::Format("%s=%g", GET_ID2(p, SG_T( "D")), p->asGrid_System()->Get_Cellsize());
 			}
 			break;
 
@@ -1499,24 +1496,24 @@ void CSG_Tool::_Get_Script_CMD(CSG_String &Script, CSG_Parameters *pParameters,
 		case PARAMETER_TYPE_PointCloud       :
 			if( p->is_Input() )
 			{
-				Script	+= Prefix + CSG_String::Format("%s=\"%s\"", GET_ID1(p), SG_Get_Data_Manager().Exists(p->asDataObject()) && p->asDataObject()->Get_File_Name() ? p->asDataObject()->Get_File_Name() : SG_T("input file"));
+				Script += Prefix + CSG_String::Format(StrFmt, GET_ID1(p), SG_Get_Data_Manager().Exists(p->asDataObject()) && p->asDataObject()->Get_File_Name() ? p->asDataObject()->Get_File_Name() : SG_T("input file"));
 			}
 			else
 			{
-				CSG_String	ext;
+				CSG_String File(p->Get_Name());
 
 				switch( p->Get_DataObject_Type() )
 				{
-				case SG_DATAOBJECT_TYPE_Grid      : ext = "sg-grd-z"; break;
-				case SG_DATAOBJECT_TYPE_Grids     : ext = "sg-gds-z"; break;
-				case SG_DATAOBJECT_TYPE_Table     : ext = "txt"     ; break;
-				case SG_DATAOBJECT_TYPE_Shapes    : ext = "geojson" ; break;
-				case SG_DATAOBJECT_TYPE_PointCloud: ext = "sg-pts-z"; break;
-				case SG_DATAOBJECT_TYPE_TIN       : ext = "geojson" ; break;
-				default                           : ext = "dat"     ; break;
+				case SG_DATAOBJECT_TYPE_Grid      : File += ".sg-grd-z"; break;
+				case SG_DATAOBJECT_TYPE_Grids     : File += ".sg-gds-z"; break;
+				case SG_DATAOBJECT_TYPE_Table     : File += ".txt"     ; break;
+				case SG_DATAOBJECT_TYPE_Shapes    : File += ".geojson" ; break;
+				case SG_DATAOBJECT_TYPE_PointCloud: File += ".sg-pts-z"; break;
+				case SG_DATAOBJECT_TYPE_TIN       : File += ".geojson" ; break;
+				default                           : File += ".dat"     ; break;
 				}
 
-				Script	+= Prefix + CSG_String::Format("%s=\"%s.%s\"", GET_ID1(p), p->Get_Name(), ext.c_str());
+				Script += Prefix + CSG_String::Format(StrFmt, GET_ID1(p), File.c_str());
 			}
 			break;
 
@@ -1528,28 +1525,28 @@ void CSG_Tool::_Get_Script_CMD(CSG_String &Script, CSG_Parameters *pParameters,
 		case PARAMETER_TYPE_PointCloud_List  :
 			if( p->is_Input() )
 			{
-				Script	+= Prefix + CSG_String::Format("%s=", GET_ID1(p));
+				Script += Prefix + CSG_String::Format("%s=", GET_ID1(p));
 
 				if( p->asList()->Get_Item_Count() == 0 )
 				{
-					Script	+= "file(s)";
+					Script += "file(s)";
 				}
 				else
 				{
-					Script	+= SG_File_Exists(p->asList()->Get_Item(0)->Get_File_Name())
+					Script += SG_File_Exists(p->asList()->Get_Item(0)->Get_File_Name())
 						? p->asList()->Get_Item(0)->Get_File_Name() : _TL("memory");
 
 					for(int iObject=1; iObject<p->asList()->Get_Item_Count(); iObject++)
 					{
-						Script	+= ";";
-						Script	+= SG_File_Exists(p->asList()->Get_Item(iObject)->Get_File_Name())
+						Script += ";";
+						Script += SG_File_Exists(p->asList()->Get_Item(iObject)->Get_File_Name())
 							? p->asList()->Get_Item(iObject)->Get_File_Name() : _TL("memory");
 					}
 				}
 			}
 			else
 			{
-				Script	+= Prefix + CSG_String::Format("%s=\"%s\"", GET_ID1(p), p->Get_Name());
+				Script += Prefix + CSG_String::Format(StrFmt, GET_ID1(p), p->Get_Name());
 			}
 			break;
 		}
@@ -1872,59 +1869,59 @@ void CSG_Tool::_Get_Script_Python(CSG_String &Script, CSG_Parameters *pParameter
 			break;
 
 		case PARAMETER_TYPE_Bool           :
-			Script	+= CSG_String::Format("    Tool.Set_Parameter('%s', %s)\n", ID.c_str(), p->asBool() ? SG_T("True") : SG_T("False"));
+			Script += CSG_String::Format("    Tool.Set_Parameter('%s', %s)\n", ID.c_str(), p->asBool() ? SG_T("True") : SG_T("False"));
 			break;
 
 		case PARAMETER_TYPE_Int            :
-			Script	+= CSG_String::Format("    Tool.Set_Parameter('%s', %d)\n", ID.c_str(), p->asInt());
+			Script += CSG_String::Format("    Tool.Set_Parameter('%s', %d)\n", ID.c_str(), p->asInt());
 			break;
 
 		case PARAMETER_TYPE_Data_Type      :
 		case PARAMETER_TYPE_Choice         :
-			Script	+= CSG_String::Format("    Tool.Set_Parameter('%s', %d) # '%s'\n", ID.c_str(), p->asInt(), p->asString());
+			Script += CSG_String::Format("    Tool.Set_Parameter('%s', %d) # '%s'\n", ID.c_str(), p->asInt(), p->asString());
 			break;
 
 		case PARAMETER_TYPE_Choices        :
 		case PARAMETER_TYPE_Table_Field    :
 		case PARAMETER_TYPE_Table_Fields   :
-			Script	+= CSG_String::Format("    Tool.Set_Parameter('%s', '%s')\n", ID.c_str(), p->asString());
+			Script += CSG_String::Format("    Tool.Set_Parameter('%s', '%s')\n", ID.c_str(), p->asString());
 			break;
 
         case PARAMETER_TYPE_Color          :
-            Script	+= CSG_String::Format("    Tool.Set_Parameter('%s', '%s')\n", ID.c_str(), SG_Color_To_Text(p->asColor()).c_str());
+			Script += CSG_String::Format("    Tool.Set_Parameter('%s', '%s')\n", ID.c_str(), SG_Color_To_Text(p->asColor()).c_str());
             break;
 
 		case PARAMETER_TYPE_Double         :
 		case PARAMETER_TYPE_Degree         :
-			Script	+= CSG_String::Format("    Tool.Set_Parameter('%s', %g)\n", ID.c_str(), p->asDouble());
+			Script += CSG_String::Format("    Tool.Set_Parameter('%s', %g)\n", ID.c_str(), p->asDouble());
 			break;
 
 		case PARAMETER_TYPE_Range          :
-			Script	+= CSG_String::Format("    Tool.Set_Parameter('%s.MIN', %g)\n", ID.c_str(), p->asRange()->Get_Min());
-			Script	+= CSG_String::Format("    Tool.Set_Parameter('%s.MAX', %g)\n", ID.c_str(), p->asRange()->Get_Max());
+			Script += CSG_String::Format("    Tool.Set_Parameter('%s.MIN', %g)\n", ID.c_str(), p->asRange()->Get_Min());
+			Script += CSG_String::Format("    Tool.Set_Parameter('%s.MAX', %g)\n", ID.c_str(), p->asRange()->Get_Max());
 			break;
 
 		case PARAMETER_TYPE_String         :
 			if( ((CSG_Parameter_String *)p)->is_Password() )
 			{
-				Script	+= CSG_String::Format("    Tool.Set_Parameter('%s', '***')\n", ID.c_str());
+				Script += CSG_String::Format("    Tool.Set_Parameter('%s', '***')\n", ID.c_str());
 				break;
 			}
 
 		case PARAMETER_TYPE_Date           :
 		case PARAMETER_TYPE_Text           :
 		case PARAMETER_TYPE_FilePath       :
-			Script	+= CSG_String::Format("    Tool.Set_Parameter('%s', '%s')\n", ID.c_str(), p->asString());
+			Script += CSG_String::Format("    Tool.Set_Parameter('%s', '%s')\n", ID.c_str(), p->asString());
 			break;
 
 		case PARAMETER_TYPE_FixedTable     :
-			Script	+= CSG_String::Format("    Tool.Set_Parameter('%s', saga_api.SG_Create_Table('table.txt'))\n", ID.c_str());
+			Script += CSG_String::Format("    Tool.Set_Parameter('%s', saga_api.SG_Create_Table('table.txt'))\n", ID.c_str());
 			break;
 
 		case PARAMETER_TYPE_Grid_System    :
 			if( p->Get_Children_Count() == 0 )
 			{
-				Script	+= CSG_String::Format("    Tool.Set_Parameter('%s', saga_api.CSG_Grid_System(%g, %g, %g, %d, %d))\n", ID.c_str(),
+				Script += CSG_String::Format("    Tool.Set_Parameter('%s', saga_api.CSG_Grid_System(%g, %g, %g, %d, %d))\n", ID.c_str(),
 					p->asGrid_System()->Get_Cellsize(),
 					p->asGrid_System()->Get_XMin(), p->asGrid_System()->Get_YMin(),
 					p->asGrid_System()->Get_NX  (), p->asGrid_System()->Get_NY  ()
@@ -1940,13 +1937,13 @@ void CSG_Tool::_Get_Script_Python(CSG_String &Script, CSG_Parameters *pParameter
 		case PARAMETER_TYPE_PointCloud     :
 			if( p->is_Input() )
 			{
-				Script	+= CSG_String::Format("    Tool.Set_Parameter('%s', saga_api.SG_Get_Data_Manager().Add('%s input file%s'))\n", ID.c_str(),
+				Script += CSG_String::Format("    Tool.Set_Parameter('%s', saga_api.SG_Get_Data_Manager().Add('%s input file%s'))\n", ID.c_str(),
 					SG_Get_DataObject_Name(p->Get_DataObject_Type()).c_str(), p->is_Optional() ? SG_T(", optional") : SG_T("")
 				);
 			}
 			else if( p->is_Output() && p->is_Optional() )
 			{
-				Script	+= CSG_String::Format("    Tool.Set_Parameter('%s', saga_api.SG_Get_Create_Pointer()) # optional output, remove this line, if you don't want to create it\n", ID.c_str());
+				Script += CSG_String::Format("    Tool.Set_Parameter('%s', saga_api.SG_Get_Create_Pointer()) # optional output, remove this line, if you don't want to create it\n", ID.c_str());
 			}
 			break;
 
@@ -1958,7 +1955,7 @@ void CSG_Tool::_Get_Script_Python(CSG_String &Script, CSG_Parameters *pParameter
 		case PARAMETER_TYPE_PointCloud_List:
 			if( p->is_Input() )
 			{
-				Script	+= CSG_String::Format("    Tool.Get_Parameter('%s').asList().Add_Item('%s input list%s')\n", ID.c_str(),
+				Script += CSG_String::Format("    Tool.Get_Parameter('%s').asList().Add_Item('%s input list%s')\n", ID.c_str(),
 					SG_Get_DataObject_Name(p->Get_DataObject_Type()).c_str(), p->is_Optional() ? SG_T(", optional") : SG_T("")
 				);
 			}
