@@ -80,8 +80,8 @@ public:
 	CSG_Tool_Chain(void);
 	virtual ~CSG_Tool_Chain(void);
 
-								CSG_Tool_Chain			(const CSG_Tool_Chain &Tool, bool bWithGUI);
-	bool						Create					(const CSG_Tool_Chain &Tool, bool bWithGUI);
+								CSG_Tool_Chain			(const CSG_Tool_Chain &Tool, bool bWithGUI, bool bWithCMD);
+	bool						Create					(const CSG_Tool_Chain &Tool, bool bWithGUI, bool bWithCMD);
 
 								CSG_Tool_Chain			(const CSG_String &File);
 	bool						Create					(const CSG_String &File);
@@ -176,7 +176,7 @@ class SAGA_API_DLL_EXPORT CSG_Tool_Chains : public CSG_Tool_Library
 
 public:
 
-	virtual TSG_Tool_Library_Type	Get_Type			(void)		const	{	return( TOOL_CHAINS );	}
+	virtual ESG_Library_Type		Get_Type			(void)		const	{	return( ESG_Library_Type::Chain );	}
 
 	virtual CSG_String				Get_Info			(int Type)	const;
 
@@ -186,7 +186,7 @@ public:
 
 	virtual CSG_Tool *				Get_Tool			(int Index, TSG_Tool_Type Type = TOOL_TYPE_Base)	const;
 
-	virtual CSG_Tool *				Create_Tool			(const CSG_String &Name, bool bWithGUI = false);
+	virtual CSG_Tool *				Create_Tool			(const CSG_String &Name, bool bWithGUI = false, bool bWithCMD = true);
 	virtual bool					Delete_Tool			(CSG_Tool *pTool);
 	virtual bool					Delete_Tools		(void);
 
