@@ -56,6 +56,7 @@
 #include <wx/wfstream.h>
 #include <wx/quantize.h>
 #include <wx/filedlg.h>
+#include <wx/settings.h>
 
 #include "3d_view.h"
 
@@ -193,6 +194,10 @@ END_EVENT_TABLE()
 CSG_3DView_Panel::CSG_3DView_Panel(wxWindow *pParent, CSG_Grid *pDrape)
 	: wxPanel(pParent, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxTAB_TRAVERSAL|wxSUNKEN_BORDER|wxNO_FULL_REPAINT_ON_RESIZE)
 {
+	wxColour bgColor = wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOW);
+
+	SetBackgroundColour(bgColor);
+
 	m_Parameters.Create(this, _TL("3D View"));
 
 	m_Parameters.Set_Callback_On_Parameter_Changed(_On_Parameter_Changed);
@@ -214,18 +219,19 @@ CSG_3DView_Panel::CSG_3DView_Panel(wxWindow *pParent, CSG_Grid *pDrape)
 	m_Parameters.Add_Double("SHIFT"   , "SHIFT_Z"     , _TL("In/Out"               ), _TL(""), m_Projector.Get_zShift());
 
 	m_Parameters.Add_Choice("3D_VIEW" , "CENTRAL"     , _TL("Projection"           ), _TL(""), CSG_String::Format("%s|%s", _TL("parallel"), _TL("central")), 1);
-	m_Parameters.Add_Double("CENTRAL" , "CENTRAL_DIST", _TL("Perspectivic Distance"), _TL(""), m_Projector.Get_Central_Distance(), 0.1, true);
+	m_Parameters.Add_Double("CENTRAL" , "CENTRAL_DIST", _TL("Perspective Distance" ), _TL(""), m_Projector.Get_Central_Distance(), 0.1, true);
 
 	m_Parameters.Add_Bool  ("3D_VIEW" , "BOX"         , _TL("Bounding Box"         ), _TL(""), true);
 
 	m_Parameters.Add_Choice("3D_VIEW" , "NORTH"       , _TL("North Arrow"          ), _TL(""), CSG_String::Format("%s|%s|%s", _TL("no"), _TL("yes"), _TL("yes, without bounding box")), m_North);
 	m_Parameters.Add_Double("NORTH"   , "NORTH_SIZE"  , _TL("Size"                 ), _TL(""), m_North_Size, 1., true);
 
-	m_Parameters.Add_Choice("3D_VIEW" , "LABELS"      , _TL("Axis Labeling"        ), _TL(""), CSG_String::Format("%s|%s|%s", _TL("all"), _TL("horizontal"), _TL("none")), m_Labels);
+	m_Parameters.Add_Choice("3D_VIEW" , "LABELS"      , _TL("Axis Labeling"        ), _TL(""), CSG_String::Format("%s|%s|%s", _TL("all axes"), _TL("frontal axes"), _TL("none")), m_Labels);
+	m_Parameters.Add_Choice("LABELS"  , "LABEL_DIR"   , _TL("Label Orientation"    ), _TL(""), CSG_String::Format("%s|%s", _TL("along axis"), _TL("cross axis")), m_Label_Dir);
 	m_Parameters.Add_Int   ("LABELS"  , "LABEL_RES"   , _TL("Resolution"           ), _TL(""), m_Label_Res, 20, true, 1000, true);
 	m_Parameters.Add_Double("LABELS"  , "LABEL_SCALE" , _TL("Size"                 ), _TL(""), m_Label_Scale, 0.1, true, 10., true);
 
-	m_Parameters.Add_Color ("3D_VIEW" , "BGCOLOR"     , _TL("Background Color"     ), _TL(""), SG_COLOR_WHITE);
+	m_Parameters.Add_Color ("3D_VIEW" , "BGCOLOR"     , _TL("Background Color"     ), _TL(""), m_bgColor = SG_GET_RGB(bgColor.Red(), bgColor.Green(), bgColor.Blue()));
 
 	m_Parameters.Add_Choice("3D_VIEW" , "STEREO"      , _TL("Stereo View"          ), _TL(""), CSG_String::Format("%s|%s|%s", _TL("off"), _TL("anaglyph"), _TL("twin window for right eye")));
 	m_Parameters.Add_Double("STEREO"  , "STEREO_DIST" , _TL("Eye Distance [Degree]"), _TL(""), m_dStereo, 0., true, 180., true);
@@ -349,6 +355,7 @@ bool CSG_3DView_Panel::Update_Parameters(bool bSave)
 		m_Parameters["NORTH_SIZE"  ].Set_Value(m_North_Size );
 
 		m_Parameters["LABELS"      ].Set_Value(m_Labels     );
+		m_Parameters["LABEL_DIR"   ].Set_Value(m_Label_Dir  );
 		m_Parameters["LABEL_RES"   ].Set_Value(m_Label_Res  );
 		m_Parameters["LABEL_SCALE" ].Set_Value(m_Label_Scale);
 
@@ -389,6 +396,7 @@ bool CSG_3DView_Panel::Update_Parameters(bool bSave)
 		m_North_Size  = m_Parameters["NORTH_SIZE" ].asDouble();
 
 		m_Labels      = m_Parameters["LABELS"     ].asInt   ();
+		m_Label_Dir   = m_Parameters["LABEL_DIR"  ].asInt   ();
 		m_Label_Res   = m_Parameters["LABEL_RES"  ].asInt   ();
 		m_Label_Scale = m_Parameters["LABEL_SCALE"].asDouble();
 
@@ -1008,7 +1016,7 @@ bool CSG_3DView_Panel::Update_View(bool bStatistics)
 	}
 
 	//-----------------------------------------------------
-	CSG_Grid *pDrape = m_pDrape; if( m_pDrape && !m_Parameters("MAP_DRAPE")->asBool() ) m_pDrape = NULL;
+	CSG_Grid *pDrape = m_pDrape; if( m_pDrape && (!m_pDrape->is_Valid() || !m_Parameters("MAP_DRAPE")->asBool()) ) { m_pDrape = NULL; }
 
 	if( Draw() )
 	{
@@ -1292,7 +1300,11 @@ bool CSG_3DView_Panel::_Play(void)
 
 					wxQuantize::Quantize(m_Image, *pImage, m_Parameters["PLAY_COLORS"].asInt());
 
-					Images.Add(pImage);
+					#if wxMAJOR_VERSION >= 3 && wxMINOR_VERSION >= 3
+						Images.Add(*pImage);
+					#else
+						Images.Add(pImage);
+					#endif
 				}
 				else
 				{
