@@ -98,12 +98,12 @@ BEGIN_EVENT_TABLE(CActive_Attributes_Control, wxGrid)
 	EVT_MENU(ID_CMD_TABLE_FIELD_OPEN_APP , CActive_Attributes_Control::On_Cell_Open    )
 	EVT_MENU(ID_CMD_TABLE_FIELD_OPEN_DATA, CActive_Attributes_Control::On_Cell_Open    )
 
-	EVT_MENU(ID_CMD_TABLE_TO_CLIPBOARD   , CActive_Attributes_Control::On_ToClipboard  )
-
 	EVT_MENU(ID_CMD_TABLE_FIELD_ADD      , CActive_Attributes_Control::On_Field_Add    )
 	EVT_MENU(ID_CMD_TABLE_FIELD_DEL      , CActive_Attributes_Control::On_Field_Del    )
 	EVT_MENU(ID_CMD_TABLE_FIELD_RENAME   , CActive_Attributes_Control::On_Field_Rename )
 	EVT_MENU(ID_CMD_TABLE_FIELD_TYPE     , CActive_Attributes_Control::On_Field_Type   )
+
+	EVT_MENU(ID_CMD_ACTIVE_CLIPBOARD_COPY, CActive_Attributes_Control::On_ToClipboard  )
 END_EVENT_TABLE()
 
 
@@ -352,18 +352,15 @@ void CActive_Attributes_Control::On_RClick(wxGridEvent &event)
 	switch( m_Table.Get_Field_Type(event.GetCol()) )
 	{
 	default:
-	{
 		// nop
-	}
-	break;
+		break;
 
-	case SG_DATATYPE_String:
-	{
-		wxMenu	Menu;
+	case SG_DATATYPE_String: {
+		wxMenu Menu;
 
 		CMD_Menu_Add_Item(&Menu, false, ID_CMD_TABLE_FIELD_OPEN_APP);
 
-		wxString	Value	= GetCellValue(event.GetRow(), event.GetCol());
+		wxString Value = GetCellValue(event.GetRow(), event.GetCol());
 
 		if( m_pData->is_DataSource(Value) )
 		{
@@ -371,22 +368,22 @@ void CActive_Attributes_Control::On_RClick(wxGridEvent &event)
 		}
 
 		PopupMenu(&Menu, event.GetPosition());
-	}
-	break;
+	
+		break; }
 	}
 }
 
 //---------------------------------------------------------
 void CActive_Attributes_Control::On_RClick_Label(wxGridEvent &event)
 {
-	wxMenu	Menu;
+	wxMenu Menu;
 
 	//-----------------------------------------------------
 	if( event.GetCol() != -1 )
 	{
 		Menu.SetTitle(_TL("Columns"));
 
-		CMD_Menu_Add_Item(&Menu, false, ID_CMD_TABLE_TO_CLIPBOARD);
+		CMD_Menu_Add_Item(&Menu, false, ID_CMD_ACTIVE_CLIPBOARD_COPY);
 		CMD_Menu_Add_Item(&Menu, false, ID_CMD_TABLE_AUTOSIZE_COLS);
 
 		if( g_pActive->Get_Active_Data_Item() && g_pActive->Get_Active_Data_Item()->Get_Type() == WKSP_ITEM_Grids )
@@ -403,14 +400,14 @@ void CActive_Attributes_Control::On_RClick_Label(wxGridEvent &event)
 	{
 		Menu.SetTitle(_TL("Rows"));
 
-		CMD_Menu_Add_Item(&Menu, false, ID_CMD_TABLE_TO_CLIPBOARD);
+		CMD_Menu_Add_Item(&Menu, false, ID_CMD_ACTIVE_CLIPBOARD_COPY);
 		CMD_Menu_Add_Item(&Menu, false, ID_CMD_TABLE_AUTOSIZE_ROWS);
 	}
 	else
 	{
 		Menu.SetTitle(_TL("Attributes"));
 
-		CMD_Menu_Add_Item(&Menu, false, ID_CMD_TABLE_TO_CLIPBOARD);
+		CMD_Menu_Add_Item(&Menu, false, ID_CMD_ACTIVE_CLIPBOARD_COPY);
 	}
 
 	//-----------------------------------------------------
