@@ -60,6 +60,7 @@
 
 #include "helper.h"
 
+#include "res_controls.h"
 #include "res_dialogs.h"
 
 #include "saga.h"
@@ -322,24 +323,24 @@ wxColour	SYS_Get_Color(wxSystemColour index)
 }
 
 //---------------------------------------------------------
-void		SYS_Set_Color_BG(wxWindow *pWindow, wxSystemColour index)
+wxColour	SYS_Get_Color_Background(int Mode)
 {
-	if( pWindow )
+	switch( Mode )
 	{
-		pWindow->SetBackgroundColour(SYS_Get_Color(index));
+	default: return( wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOW) );
+	case  1: return( *wxWHITE ); // bright
+	case  2: return( *wxBLACK ); // dark
 	}
 }
 
 //---------------------------------------------------------
-void		SYS_Set_Color_BG_Window(wxWindow *pWindow)
+wxColour	SYS_Get_Color_Foreground(int Mode)
 {
-	if( pWindow )
+	switch( Mode )
 	{
-#if defined(__WXMSW__)
-		pWindow->SetBackgroundColour(SYS_Get_Color(wxSYS_COLOUR_WINDOW));
-#else
-		pWindow->SetBackgroundColour(*wxWHITE);
-#endif
+	default: return( wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOWTEXT) );
+	case  1: return( *wxBLACK ); // bright
+	case  2: return( *wxWHITE ); // dark
 	}
 }
 
@@ -351,13 +352,25 @@ void		SYS_Set_Color_BG_Window(wxWindow *pWindow)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-wxWindow *	MDI_Get_Frame(void)
+wxWindow *		MDI_Get_Frame(void)
 {
 	return( g_pSAGA_Frame );
 }
 
 //---------------------------------------------------------
-wxPoint		MDI_Get_Def_Position(void)
+CVIEW_Base *	MDI_Get_Active_View(int View_ID)
+{
+	return( g_pSAGA_Frame->Get_Active_Child(View_ID) );
+}
+
+//---------------------------------------------------------
+CVIEW_Base *	MDI_Get_Active_Map(void)
+{
+	return( g_pSAGA_Frame->Get_Active_Child(ID_VIEW_MAP) );
+}
+
+//---------------------------------------------------------
+wxPoint			MDI_Get_Def_Position(void)
 {
 	static int	n	= 0;
 
@@ -371,13 +384,13 @@ wxPoint		MDI_Get_Def_Position(void)
 }
 
 //---------------------------------------------------------
-wxSize		MDI_Get_Def_Size(void)
+wxSize			MDI_Get_Def_Size(void)
 {
 	return( wxSize(400, 300) );
 }
 
 //---------------------------------------------------------
-void		MDI_Top_Window_Push(wxWindow *pWindow)
+void			MDI_Top_Window_Push(wxWindow *pWindow)
 {
 	if( g_pSAGA_Frame )
 	{
@@ -386,7 +399,7 @@ void		MDI_Top_Window_Push(wxWindow *pWindow)
 }
 
 //---------------------------------------------------------
-void		MDI_Top_Window_Pop(wxWindow *pWindow)
+void			MDI_Top_Window_Pop(wxWindow *pWindow)
 {
 	if( g_pSAGA_Frame )
 	{
@@ -395,17 +408,39 @@ void		MDI_Top_Window_Pop(wxWindow *pWindow)
 }
 
 //---------------------------------------------------------
-wxWindow *	MDI_Get_Top_Window(void)
+wxWindow *		MDI_Get_Top_Window(void)
 {
 	return( g_pSAGA_Frame ? g_pSAGA_Frame->Top_Window_Get() : NULL );
 }
 
 //---------------------------------------------------------
-bool		MDI_Window_Arrange(int Arrange)
+bool			MDI_Window_Arrange(int Arrange)
 {
 	return( g_pSAGA_Frame ? g_pSAGA_Frame->Arrange_Children(Arrange) : false );
 }
 
+//---------------------------------------------------------
+bool			MDI_Freeze(void)
+{
+	if( g_pSAGA_Frame )
+	{
+		g_pSAGA_Frame->Freeze();
+	}
+
+	return( g_pSAGA_Frame != NULL );
+}
+
+//---------------------------------------------------------
+bool			MDI_Thaw(void)
+{
+	if( g_pSAGA_Frame )
+	{
+		g_pSAGA_Frame->Thaw();
+	}
+
+	return( g_pSAGA_Frame != NULL );
+}
+
 
 ///////////////////////////////////////////////////////////
 //														 //
@@ -866,11 +901,11 @@ bool		PROCESS_Set_Busy(bool bOn, const CSG_String &Message)
 }
 
 //---------------------------------------------------------
-bool		PROGRESSBAR_Set_Position(int Position)
+bool		PROGRESSBAR_Set_Ready(void)
 {
 	if( g_pSAGA_Frame )
 	{
-		return( g_pSAGA_Frame->ProgressBar_Set_Position(Position) );
+		return( g_pSAGA_Frame->Process_Set_Okay() );
 	}
 
 	return( true );
