@@ -132,7 +132,7 @@ wxString DLG_Get_FILE_Caption(int ID_DLG)
 {
 	switch( ID_DLG )
 	{
-	case ID_DLG_FILE_OPEN      :	return( _TL("Load") );
+	case ID_DLG_FILE_OPEN      :	return( _TL("Open") );
 
 	case ID_DLG_TOOL_OPEN      :	return( _TL("Load Tool Library") );
 
@@ -254,7 +254,7 @@ wxString DLG_Get_FILE_Filter(int ID_DLG)
 			"%s (*.sgrd, *.sg-grd-z)|*.sgrd;*.sg-grd;*.sg-grd-z;*.dgm;*.grd|"
 			"%s (*.sg-gds, *.sg-gds-z)|*.sg-gds;*.sg-gds-z|"
 			"%s (*.shp)|*.shp|"
-			"%s (*.spc, *.sg-pts, *.sg-pts-z)|*.spc;*.sg-pts;*.sg-pts-z|"
+			"%s (*.sg-pts, *.sg-pts-z)|*.sg-pts;*.sg-pts-z;*.spc|"
 			"%s (*.txt, *.csv, *.dbf)|*.txt;*.csv;*.dbf|"
 			"%s|*.*",
 			_TL("Recognized Files"), Recognized.c_str(),
@@ -483,7 +483,7 @@ wxString DLG_Get_FILE_Filter(int ID_DLG)
 	//-----------------------------------------------------
 	case ID_DLG_POINTCLOUD_OPEN:
 		return( wxString::Format(
-			"%s (*.spc, *.sg-pts, *.sg-pts-z)|*.spc;*.sg-pts;*.sg-pts-z|"
+			"%s (*.sg-pts, *.sg-pts-z)|*.sg-pts;*.sg-pts-z;*.spc|"
 			"%s|*.*",
 			_TL("SAGA Point Clouds"),
 			_TL("All Files")
@@ -492,7 +492,7 @@ wxString DLG_Get_FILE_Filter(int ID_DLG)
 	case ID_DLG_POINTCLOUD_SAVE:
 		return( wxString::Format(
 			"%s (*.sg-pts-z)|*.sg-pts-z|"
-			"%s (*.sg-pts, *.spc)|*.sg-pts;*.spc|"
+			"%s (*.sg-pts)|*.sg-pts|"
 			"%s|*.*",
 			_TL("SAGA Compressed Point Clouds"),
 			_TL("SAGA Uncompressed Point Clouds"),
@@ -1107,11 +1107,18 @@ bool		DLG_Open(wxArrayString &File_Paths, const wxString &Caption, const wxStrin
 	return( false );
 }
 
-bool		DLG_Open(wxArrayString &File_Paths, int ID_DLG)
+bool		DLG_Open(wxArrayString &File_Paths, int ID_DLG, const wxString &Directory)
 {
-	wxString	def_Dir;
+	wxString def_Dir;
 
-	CONFIG_Read(CONFIG_GROUP_FILE_DLG, DLG_Get_FILE_Config(ID_DLG), def_Dir);
+	if( Directory.IsEmpty() || !wxDirExists(Directory) )
+	{
+		CONFIG_Read(CONFIG_GROUP_FILE_DLG, DLG_Get_FILE_Config(ID_DLG), def_Dir);
+	}
+	else
+	{
+		def_Dir = Directory;
+	}
 
 	if( DLG_Open(File_Paths, DLG_Get_FILE_Caption(ID_DLG), def_Dir, DLG_Get_FILE_Filter(ID_DLG)) )
 	{
