@@ -53,6 +53,7 @@
 #endif
 
 #include <wx/filename.h>
+#include <wx/clipbrd.h>
 
 #include <saga_api/saga_api.h>
 
@@ -108,16 +109,16 @@ CWKSP_Data_Manager	*g_pData	= NULL;
 //---------------------------------------------------------
 CWKSP_Data_Manager::CWKSP_Data_Manager(void)
 {
-	g_pData			= this;
+	g_pData        = this;
 
-	m_pTables		= NULL;
-	m_pShapes		= NULL;
-	m_pTINs			= NULL;
-	m_pPointClouds	= NULL;
-	m_pGrids		= NULL;
+	m_pTables      = NULL;
+	m_pShapes      = NULL;
+	m_pTINs        = NULL;
+	m_pPointClouds = NULL;
+	m_pGrids       = NULL;
 
-	m_pProject		= new CWKSP_Project;
-	m_pMenu_Files	= new CWKSP_Data_Menu_Files;
+	m_pProject     = new CWKSP_Project;
+	m_pMenu_Files  = new CWKSP_Data_Menu_Files;
 
 	//-----------------------------------------------------
 	m_Parameters.Add_Bool (""          , "THUMBNAILS"        , _TL("Thumbnails"     ), _TL(""), true);
@@ -140,7 +141,7 @@ CWKSP_Data_Manager::CWKSP_Data_Manager(void)
 		CSG_String::Format("%s|%s|%s",
 			_TL("empty"),
 			_TL("last state"),
-			_TL("always ask what to do")
+			_TL("ask what to do")
 		), 2
 	);
 
@@ -302,6 +303,20 @@ CWKSP_Data_Manager::CWKSP_Data_Manager(void)
 		6, 0, true
 	);
 
+	m_Parameters.Add_Choice("NODE_TABLE",
+		"TABLE_ENCODING"		, _TL("Default Encoding"),
+		_TL("Default encoding used when loading a table."),
+		CSG_String::Format("%s|%s|%s|%s|%s|%s|%s",
+			SG_T("ANSI"),
+			SG_T("UTF-7"),
+			SG_T("UTF-8"),
+			SG_T("UTF-16 (Little Endian)"),
+			SG_T("UTF-16 (Big Endian)"),
+			SG_T("UTF-32 (Little Endian)"),
+			SG_T("UTF-32 (Big Endian)")
+		), 2
+	);
+
 	//-----------------------------------------------------
 	m_Parameters.Add_Node("", "NODE_SHAPES", _TL("Shapes"), _TL(""));
 
@@ -394,13 +409,11 @@ bool CWKSP_Data_Manager::Initialise(void)
 
 	switch( m_Parameters("PROJECT_START")->asInt() )
 	{
-	case 0:	// empty
-		return( true );
-
 	case 1:	// last state
-		return( m_pProject->Load(fLastState.GetFullPath(), false, false) );
+		fProject = fLastState;
+		break;
 
-	case 2:	// always ask what to do
+	case 2:	// ask what to do
 		{
 			wxArrayString Projects;
 
@@ -411,28 +424,35 @@ bool CWKSP_Data_Manager::Initialise(void)
 				Projects.Add(wxString::Format("[%s]", _TL("last state")));
 			}
 
-			m_pMenu_Files->Recent_Get(SG_DATAOBJECT_TYPE_Undefined, Projects, true);
+			m_pMenu_Files->Recent_Get(CWKSP_Data_Menu_File::Recent_Type::Project, Projects, true);
 
-			wxSingleChoiceDialog dlg(MDI_Get_Top_Window(), _TL("Startup Project"), _TL("Select Startup Project"), Projects);
+			if( Projects.Count() > 1 )
+			{
+				wxSingleChoiceDialog dlg(MDI_Get_Top_Window(), _TL("Startup Project"), _TL("Select Startup Project"), Projects);
 
-			if( Projects.Count() <= 1 || dlg.ShowModal() != wxID_OK || dlg.GetSelection() == 0 )
-			{	// empty
-				return( true );
-			}
-
-			if( fLastState.FileExists() && dlg.GetSelection() == 1 )
-			{	// last state
-				return( m_pProject->Load(fLastState.GetFullPath(), false, false) );
-			}
-			else
-			{	// recently opened project
-				return( m_pProject->Load(dlg.GetStringSelection(), false, true) );
+				if( dlg.ShowModal() == wxID_OK && dlg.GetSelection() > 0 )
+				{
+					if( fLastState.FileExists() && dlg.GetSelection() == 1 )
+					{	// last state
+						fProject = fLastState;
+					}
+					else
+					{	// recently opened project
+						fProject = dlg.GetStringSelection();
+					}
+				}
 			}
 		}
+		break;
 	}
 
 	//-----------------------------------------------------
-	return( false );
+	if( fProject.FileExists() )
+	{
+		return( m_pProject->Load(fProject.GetFullPath(), false, fProject != fLastState) );
+	}
+
+	return( true );	// empty
 }
 
 //---------------------------------------------------------
@@ -500,9 +520,10 @@ wxString CWKSP_Data_Manager::Get_Description(void)
 //---------------------------------------------------------
 wxMenu * CWKSP_Data_Manager::Get_Menu(void)
 {
-	if( m_Sel_Items.Count() > 0 )
+//	if( m_Sel_Items.Count() > 1 )
+	if( Get_Control()->Get_Selection_Count() > 1 )
 	{
-		wxMenu	*pMenu	= new wxMenu;
+		wxMenu *pMenu = new wxMenu;
 
 		CMD_Menu_Add_Item(pMenu, false, ID_CMD_WKSP_ITEM_SHOW);
 		CMD_Menu_Add_Item(pMenu, false, ID_CMD_WKSP_ITEM_CLOSE);
@@ -515,7 +536,7 @@ wxMenu * CWKSP_Data_Manager::Get_Menu(void)
 	}
 
 	//-----------------------------------------------------
-	wxMenu	*pMenu	= new wxMenu(_TL("Data"));
+	wxMenu *pMenu = new wxMenu(_TL("Data"));
 
 	if( wxGetKeyState(WXK_CONTROL) ) // add advanced/hidden commands
 	{
@@ -542,6 +563,26 @@ wxMenu * CWKSP_Data_Manager::Get_Menu(void)
 		CMD_Menu_Add_Item(pMenu, false, ID_CMD_WKSP_ITEM_SEARCH);
 	}
 
+	//-----------------------------------------------------
+	if( wxTheClipboard->Open() )
+	{
+		bool bSeparator = false;
+
+		if( wxTheClipboard->IsSupported(wxDF_TEXT) )
+		{
+			if( !bSeparator ) { bSeparator = true; pMenu->AppendSeparator(); }
+			CMD_Menu_Add_Item(pMenu, false, ID_CMD_DATA_CLIPBOARD_PASTE_TABLE);
+		}
+
+		if( wxTheClipboard->IsSupported(wxDF_BITMAP) )
+		{
+			if( !bSeparator ) { bSeparator = true; pMenu->AppendSeparator(); }
+			CMD_Menu_Add_Item(pMenu, false, ID_CMD_DATA_CLIPBOARD_PASTE_IMAGE);
+		}
+
+		wxTheClipboard->Close();
+	}
+
 	//-----------------------------------------------------
 	return( pMenu );
 }
@@ -559,41 +600,10 @@ bool CWKSP_Data_Manager::On_Command(int Cmd_ID)
 		return( true );
 	}
 
-	if( m_pTables && Cmd_ID >= ID_CMD_TABLE_FIRST  && Cmd_ID <= ID_CMD_TABLE_LAST  && m_pTables->On_Command(Cmd_ID) )
-	{
-		return( true );
-	}
-
-	if( m_pShapes && Cmd_ID >= ID_CMD_SHAPES_FIRST && Cmd_ID <= ID_CMD_SHAPES_LAST && m_pShapes->On_Command(Cmd_ID) )
-	{
-		return( true );
-	}
-
-	if( m_pTINs   && Cmd_ID >= ID_CMD_TIN_FIRST    && Cmd_ID <= ID_CMD_TIN_LAST    && m_pTINs  ->On_Command(Cmd_ID) )
-	{
-		return( true );
-	}
-
-	if( m_pPointClouds && Cmd_ID >= ID_CMD_POINTCLOUD_FIRST && Cmd_ID <= ID_CMD_POINTCLOUD_LAST && m_pPointClouds->On_Command(Cmd_ID) )
-	{
-		return( true );
-	}
-
-	if( m_pGrids  && Cmd_ID >= ID_CMD_GRID_FIRST   && Cmd_ID <= ID_CMD_GRID_LAST   && m_pGrids ->On_Command(Cmd_ID) )
-	{
-		return( true );
-	}
-
-	if( m_pGrids  && Cmd_ID >= ID_CMD_GRIDS_FIRST  && Cmd_ID <= ID_CMD_GRIDS_LAST  && m_pGrids ->On_Command(Cmd_ID) )
-	{
-		return( true );
-	}
-
 	//-----------------------------------------------------
 	switch( Cmd_ID )
 	{
-	default:
-		return( CWKSP_Base_Manager::On_Command(Cmd_ID) );
+	default: return( CWKSP_Base_Manager::On_Command(Cmd_ID) );
 
 	//-----------------------------------------------------
 	case ID_CMD_WKSP_ITEM_RETURN     :                                      break;
@@ -617,6 +627,10 @@ bool CWKSP_Data_Manager::On_Command(int Cmd_ID)
 	case ID_CMD_GRID_OPEN            : Open(SG_DATAOBJECT_TYPE_Grid      ); break;
 	case ID_CMD_GRIDS_OPEN           : Open(SG_DATAOBJECT_TYPE_Grids     ); break;
 
+	//-----------------------------------------------------
+	case ID_CMD_DATA_CLIPBOARD_PASTE_TABLE: Clipboard_Paste_Table(); break;
+	case ID_CMD_DATA_CLIPBOARD_PASTE_IMAGE: Clipboard_Paste_Image(); break;
+
 	//-----------------------------------------------------
 	case ID_CMD_DATA_MANAGER_LIST    : {
 		CSG_String s(SG_Get_Data_Manager().Get_Summary());
@@ -669,19 +683,24 @@ bool CWKSP_Data_Manager::On_Command_UI(wxUpdateUIEvent &event)
 {
 	switch( event.GetId() )
 	{
-	default:
-		return( CWKSP_Base_Manager::On_Command_UI(event) );
+	default: return( CWKSP_Base_Manager::On_Command_UI(event) );
 
-	case ID_CMD_WKSP_ITEM_CLOSE:
-		event.Enable(Get_Count() > 0 && g_pTool == NULL);
+	case ID_CMD_WKSP_ITEM_CLOSE     : event.Enable(Get_Count() > 0 && g_pTool == NULL); break;
+
+	case ID_CMD_DATA_PROJECT_SAVE   : event.Enable(Get_Count() > 0 && m_pProject->Has_File_Name() ); break;
+	case ID_CMD_DATA_PROJECT_SAVE_AS: event.Enable(Get_Count() > 0); break;
+	case ID_CMD_DATA_PROJECT_COPY   : event.Enable(g_pData->Get_Count() > 0); break;
+	case ID_CMD_DATA_PROJECT_COPY_DB: event.Enable(g_pData->Get_Count() > 0); break;
+
+	case ID_CMD_DATA_FILE_RECENT    : event.Enable(m_pMenu_Files->Recent_Count(CWKSP_Data_Menu_File::Recent_Type::Data  ) > 0); break;
+	case ID_CMD_DATA_FOLDER_RECENT  : event.Enable(m_pMenu_Files->Recent_Count(CWKSP_Data_Menu_File::Recent_Type::Folder) > 0); break;
+
+	case ID_CMD_DATA_CLIPBOARD_PASTE_TABLE:
+		if( wxTheClipboard->Open() ) { event.Enable(wxTheClipboard->IsSupported(wxDF_TEXT  )); wxTheClipboard->Close(); } else { event.Enable(false); }
 		break;
 
-	case ID_CMD_DATA_PROJECT_SAVE:
-		event.Enable(Get_Count() > 0 && m_pProject->Has_File_Name() );
-		break;
-
-	case ID_CMD_DATA_PROJECT_SAVE_AS:
-		event.Enable(Get_Count() > 0);
+	case ID_CMD_DATA_CLIPBOARD_PASTE_IMAGE:
+		if( wxTheClipboard->Open() ) { event.Enable(wxTheClipboard->IsSupported(wxDF_BITMAP)); wxTheClipboard->Close(); } else { event.Enable(false); }
 		break;
 	}
 
@@ -806,7 +825,24 @@ CWKSP_Data_Item * CWKSP_Data_Manager::Open(const wxString &File, int DataType)
 
 	switch( DataType )
 	{
-	case SG_DATAOBJECT_TYPE_Table     : pObject = SG_Create_Table     (&File); break;
+	case SG_DATAOBJECT_TYPE_Table     : {
+		int Encoding;
+
+		switch( m_Parameters("TABLE_ENCODING")->asInt() )
+		{
+		case  0: Encoding = SG_FILE_ENCODING_ANSI     ; break;
+		case  1: Encoding = SG_FILE_ENCODING_UTF7     ; break;
+		case  2: Encoding = SG_FILE_ENCODING_UTF8     ; break;
+		case  3: Encoding = SG_FILE_ENCODING_UTF16LE  ; break;
+		case  4: Encoding = SG_FILE_ENCODING_UTF16BE  ; break;
+		case  5: Encoding = SG_FILE_ENCODING_UTF32LE  ; break;
+		case  6: Encoding = SG_FILE_ENCODING_UTF32BE  ; break;
+		default: Encoding = SG_FILE_ENCODING_UNDEFINED; break;
+		}
+
+		pObject = SG_Create_Table(&File, TABLE_FILETYPE_Undefined, Encoding);
+		break; }
+
 	case SG_DATAOBJECT_TYPE_Shapes    : pObject = SG_Create_Shapes    (&File); break;
 	case SG_DATAOBJECT_TYPE_TIN       : pObject = SG_Create_TIN       (&File); break;
 	case SG_DATAOBJECT_TYPE_PointCloud: pObject = SG_Create_PointCloud(&File); break;
@@ -820,7 +856,7 @@ CWKSP_Data_Item * CWKSP_Data_Manager::Open(const wxString &File, int DataType)
 
 		if( pItem )
 		{
-			m_pMenu_Files->Recent_Add(pObject->Get_ObjectType(), File);
+			m_pMenu_Files->Recent_Add(CWKSP_Data_Menu_File::Recent_Type::Data, File);
 
 			SG_Get_Data_Manager().Add(pObject);
 
@@ -830,7 +866,7 @@ CWKSP_Data_Item * CWKSP_Data_Manager::Open(const wxString &File, int DataType)
 		delete(pObject);
 	}
 
-	m_pMenu_Files->Recent_Del(DataType, File);
+	m_pMenu_Files->Recent_Del(CWKSP_Data_Menu_File::Recent_Type::Data, File);
 
 	return( NULL );
 }
@@ -900,7 +936,14 @@ bool CWKSP_Data_Manager::Open(const wxString &File)
 		return( Open(File, SG_DATAOBJECT_TYPE_Grids     ) != NULL );
 	}
 
-	return( SG_Get_Data_Manager().Add(&File) != NULL );
+	if( SG_Get_Data_Manager().Add(&File) != NULL )
+	{
+		m_pMenu_Files->Recent_Add(CWKSP_Data_Menu_File::Recent_Type::Data, File);
+
+		return( true );
+	}
+
+	return( false );
 }
 
 //---------------------------------------------------------
@@ -944,6 +987,26 @@ bool CWKSP_Data_Manager::Open_CMD(int Cmd_ID)
 	return( m_pMenu_Files->Recent_Open(Cmd_ID) );
 }
 
+//---------------------------------------------------------
+bool CWKSP_Data_Manager::Open_Directory(const wxString &Directory)
+{
+	wxArrayString Files;
+
+	if( DLG_Open(Files, ID_DLG_FILE_OPEN, Directory) )
+	{
+		MSG_General_Add_Line();
+
+		for(size_t i=0; i<Files.GetCount(); i++)
+		{
+			Open(Files[i]);
+		}
+
+		return( true );
+	}
+
+	return( false );
+}
+
 
 ///////////////////////////////////////////////////////////
 //                                                       //
@@ -1273,11 +1336,11 @@ bool CWKSP_Data_Manager::Close(bool bSilent)
 		{
 			if( bSilent )
 			{
-				MSG_General_Add(_TL("Stop running tool or wait until its exection has been finished!"), true, false);
+				MSG_General_Add(_TL("Stop running tool or wait until its execution has been finished!"), true, false);
 			}
 			else
 			{
-				DLG_Message_Show(_TL("Stop running tool or wait until its exection has been finished!"), g_pTool->Get_Name());
+				DLG_Message_Show(_TL("Stop running tool or wait until its execution has been finished!"), g_pTool->Get_Name());
 			}
 
 			return( false );
@@ -1467,6 +1530,101 @@ bool CWKSP_Data_Manager::Del(CSG_Data_Object *pObject, bool bConfirm)
 }
 
 
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool CWKSP_Data_Manager::Clipboard_Paste_Table(void)
+{
+	if( wxTheClipboard->Open() )
+	{
+		if( wxTheClipboard->IsSupported(wxDF_TEXT) )
+		{
+			wxTextDataObject Data;
+
+			if( wxTheClipboard->GetData(Data) )
+			{
+				wxString Text(Data.GetText()); CSG_Table *pTable = SG_Create_Table();
+
+				if( pTable->from_Text(&Text) )
+				{
+					CWKSP_Data_Item *pItem = Add(pTable);
+					
+					if( pItem )
+					{
+						pItem->Show();
+
+						wxTheClipboard->Close();
+
+						return( true );
+					}
+				}
+
+				delete(pTable);
+			}
+		}
+
+		wxTheClipboard->Close();
+	}
+
+	DLG_Message_Show_Error(_TL("Failed to paste clipboard content as table!"), _TL("Paste from Clipboard"));
+
+	return( false );
+}
+
+//---------------------------------------------------------
+bool CWKSP_Data_Manager::Clipboard_Paste_Image(void)
+{
+	if( wxTheClipboard->Open() )
+	{
+		if( wxTheClipboard->IsSupported(wxDF_BITMAP) )
+		{
+			wxBitmapDataObject Data;
+
+			if( wxTheClipboard->GetData(Data) && Data.GetBitmap().IsOk() )
+			{
+				wxImage Image(Data.GetBitmap().ConvertToImage());
+
+				CSG_Grid *pGrid = SG_Create_Grid(SG_DATATYPE_DWord, Image.GetWidth(), Image.GetHeight());
+
+				if( pGrid )
+				{
+					pGrid->Set_Name(_TL("New Image"));
+					pGrid->Set_NoData_Value(-1.);
+
+					for(int y=0, yy=pGrid->Get_NY()-1; y<pGrid->Get_NY(); y++, yy--) for(int x=0; x<pGrid->Get_NX(); x++)
+					{
+						pGrid->Set_Value(x, yy, SG_GET_RGB(Image.GetRed(x, y), Image.GetGreen(x, y), Image.GetBlue(x, y)));
+					}
+
+					CWKSP_Data_Item *pItem = Add(pGrid);
+
+					if( pItem )
+					{
+						pItem->Get_Parameters()->Set_Parameter("COLORS_TYPE", 5); // RGB Coded Values
+						pItem->Parameters_Changed();
+						pItem->Show(SG_UI_DATAOBJECT_SHOW_MAP);
+
+						wxTheClipboard->Close();
+
+						return( true );
+					}
+
+					delete(pGrid);
+				}
+			}
+		}
+
+		wxTheClipboard->Close();
+	}
+
+	DLG_Message_Show_Error(_TL("Failed to paste clipboard content as image!"), _TL("Paste from Clipboard"));
+
+	return( false );
+}
+
+
 ///////////////////////////////////////////////////////////
 //                                                       //
 ///////////////////////////////////////////////////////////
