@@ -198,10 +198,15 @@ wxString CWKSP_Grid::Get_Description(void)
 //---------------------------------------------------------
 wxMenu * CWKSP_Grid::Get_Menu(void)
 {
-	wxMenu *pMenu = new wxMenu(m_pObject->Get_Name());
+	wxMenu *pSubMenu, *pMenu = new wxMenu(m_pObject->Get_Name());
 
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_WKSP_ITEM_CLOSE);
-	CMD_Menu_Add_Item(pMenu, false, ID_CMD_GRID_SHOW);
+	CMD_Menu_Add_Item(pMenu, false, ID_CMD_DATA_SHOW_MAP);
+	if( MDI_Get_Active_Map() )
+	{
+		CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAP_ZOOM_ACTIVE);
+		CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAP_PAN_ACTIVE);
+	}
 
 	pMenu->AppendSeparator();
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_DATA_SAVE);
@@ -210,8 +215,8 @@ wxMenu * CWKSP_Grid::Get_Menu(void)
 	if( PGSQL_has_Connections() )
 		CMD_Menu_Add_Item(pMenu, false, ID_CMD_DATA_SAVETODB);
 
-	CMD_Menu_Add_Item(pMenu, false, ID_CMD_GRID_SAVEAS_IMAGE);
-	CMD_Menu_Add_Item(pMenu, false, ID_CMD_GRID_CLIPBOARD_IMAGE);
+	CMD_Menu_Add_Item(pMenu, false, ID_CMD_DATA_SAVEAS_IMAGE);
+	CMD_Menu_Add_Item(pMenu, false, ID_CMD_DATA_CLIPBOARD_COPY);
 
 	if( m_pObject->is_Modified() && SG_File_Exists(m_pObject->Get_File_Name(false)) )
 		CMD_Menu_Add_Item(pMenu, false, ID_CMD_DATA_RELOAD);
@@ -226,14 +231,25 @@ wxMenu * CWKSP_Grid::Get_Menu(void)
 		CMD_Menu_Add_Item(pMenu, false, ID_CMD_DATA_METADATA);
 
 	pMenu->AppendSeparator();
-	CMD_Menu_Add_Item(pMenu, true , ID_CMD_GRID_HISTOGRAM);
-	CMD_Menu_Add_Item(pMenu, false, ID_CMD_GRID_SCATTERPLOT);
-
-	pMenu->AppendSeparator();
-	CMD_Menu_Add_Item(pMenu, false, ID_CMD_GRID_SET_LUT);
+	CMD_Menu_Add_Item(pMenu, false, ID_CMD_DATA_CLASSIFY);
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_DATA_SETTINGS_COPY);
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_DATA_FORCE_UPDATE);
 
+	pMenu->AppendSeparator();
+
+	pMenu->Append(ID_CMD_WKSP_FIRST, _TL("Charts"   ), pSubMenu = new wxMenu());
+	CMD_Menu_Add_Item(pSubMenu, true , ID_CMD_DATA_HISTOGRAM);
+	CMD_Menu_Add_Item(pSubMenu, false, ID_CMD_DATA_SCATTERPLOT);
+	CMD_Menu_Add_Item(pSubMenu, false, ID_CMD_DATA_SCATTERPLOT_3D);
+
+	if( MDI_Get_Active_Map() && m_Edit_Attributes.Get_Count() > 0 )
+	{
+		pMenu->Append(ID_CMD_WKSP_FIRST, _TL("Selection"), pSubMenu = new wxMenu());
+		CMD_Menu_Add_Item(pSubMenu, false, ID_CMD_MAP_ZOOM_SELECTION);
+		CMD_Menu_Add_Item(pSubMenu, false, ID_CMD_MAP_PAN_SELECTION);
+		CMD_Menu_Add_Item(pSubMenu,  true, ID_CMD_DATA_SELECTION_CLEAR);
+	}
+
 	return( pMenu );
 }
 
@@ -250,33 +266,40 @@ bool CWKSP_Grid::On_Command(int Cmd_ID)
 	default:
 		return( CWKSP_Layer::On_Command(Cmd_ID) );
 
-	case ID_CMD_GRID_SAVEAS_IMAGE:
+	case ID_CMD_DATA_SAVEAS_IMAGE:
 		_Save_Image();
 		break;
 
-	case ID_CMD_GRID_CLIPBOARD_IMAGE:
+	case ID_CMD_DATA_CLIPBOARD_COPY:
 		_Save_Image_Clipboard();
 		break;
 
-	case ID_CMD_GRID_HISTOGRAM:
+	case ID_CMD_DATA_HISTOGRAM:
 		Histogram_Toggle();
 		break;
 
-	case ID_CMD_GRID_SCATTERPLOT:
+	case ID_CMD_DATA_SCATTERPLOT:
 		Add_ScatterPlot();
 		break;
 
-	case ID_CMD_GRID_SET_LUT:
+	case ID_CMD_DATA_CLASSIFY:
 		_LUT_Create();
 		break;
 
-	case ID_CMD_GRID_SEL_CLEAR:
+	case ID_CMD_DATA_SELECTION_CLEAR:
 		_Edit_Clr_Selection();
 		break;
 
-	case ID_CMD_GRID_SEL_DELETE:
+	case ID_CMD_DATA_SELECTION_DELETE:
 		_Edit_Del_Selection();
 		break;
+
+	case ID_CMD_DATA_SCATTERPLOT_3D: { CSG_Tool *pTool = SG_Get_Tool_Library_Manager().Get_Tool("vis_3d_viewer", 6);
+		if(	pTool && pTool->On_Before_Execution() && pTool->Set_Parameter("TYPE", 0) && pTool->Set_Parameter("GRID_X", m_pObject->asGrid()) && DLG_Parameters(pTool->Get_Parameters()) )
+		{
+			pTool->Execute();
+		}
+		break; }
 	}
 
 	return( true );
@@ -290,15 +313,15 @@ bool CWKSP_Grid::On_Command_UI(wxUpdateUIEvent &event)
 	default:
 		return( CWKSP_Layer::On_Command_UI(event) );
 
-	case ID_CMD_GRID_SEL_CLEAR:
+	case ID_CMD_DATA_SELECTION_CLEAR:
 		event.Enable(m_Edit_Attributes.Get_Count() > 0);
 		break;
 
-	case ID_CMD_GRID_SEL_DELETE:
+	case ID_CMD_DATA_SELECTION_DELETE:
 		event.Enable(m_Edit_Attributes.Get_Count() > 0);
 		break;
 
-	case ID_CMD_GRID_HISTOGRAM:
+	case ID_CMD_DATA_HISTOGRAM:
 		event.Check(m_pHistogram != NULL);
 		break;
 	}
@@ -859,7 +882,7 @@ void CWKSP_Grid::_LUT_Create(void)
 	}
 
 	//-----------------------------------------------------
-	PROGRESSBAR_Set_Position(0);
+	PROGRESSBAR_Set_Ready();
 
 	if( Classes.Get_Count() > 0 )
 	{
@@ -932,10 +955,10 @@ wxMenu * CWKSP_Grid::Edit_Get_Menu(void)
 		return( NULL );
 	}
 
-	wxMenu	*pMenu	= new wxMenu;
+	wxMenu *pMenu = new wxMenu;
 
-	CMD_Menu_Add_Item(pMenu, true , ID_CMD_GRID_SEL_CLEAR);
-	CMD_Menu_Add_Item(pMenu, true , ID_CMD_GRID_SEL_DELETE);
+	CMD_Menu_Add_Item(pMenu, true , ID_CMD_DATA_SELECTION_CLEAR);
+	CMD_Menu_Add_Item(pMenu, true , ID_CMD_DATA_SELECTION_DELETE);
 
 	return( pMenu );
 }
@@ -1161,13 +1184,13 @@ bool CWKSP_Grid::asImage(CSG_Grid *pImage)
 		#pragma omp parallel for
 		for(int y=0; y<pImage->Get_NY(); y++) for(int x=0; x<pImage->Get_NX(); x++)
 		{
-			if( Image.HasAlpha() )
+			if( Image.HasAlpha() && !Image.GetAlpha(x, y) )
 			{
-				pImage->Set_Value(x, y, SG_GET_RGBA(Image.GetRed(x, y), Image.GetGreen(x, y), Image.GetBlue(x, y), Image.GetAlpha(x, y)));
+				pImage->Set_NoData(x, y);
 			}
 			else
 			{
-				pImage->Set_Value(x, y, SG_GET_RGB (Image.GetRed(x, y), Image.GetGreen(x, y), Image.GetBlue(x, y)));
+				pImage->Set_Value(x, y, SG_GET_RGB(Image.GetRed(x, y), Image.GetGreen(x, y), Image.GetBlue(x, y)));
 			}
 		}
 
