@@ -402,10 +402,17 @@ void CWKSP_Map::On_Create_Parameters(void)
 		&m_Name
 	);
 
-	m_Parameters.Add_Color("NODE_GENERAL",
-		"BACKGROUND"    , _TL("Background Color"),
+	m_Parameters.Add_Choice("NODE_GENERAL",
+		"BG_COLOR"      , _TL("Background Color"),
 		_TL(""),
-		g_pMaps->Get_Parameter("BACKGROUND")->asColor()
+		CSG_String::Format("%s|%s", _TL("system"), _TL("user defined")),
+		g_pMaps->Get_Parameter("BG_COLOR")->asInt()
+	);
+
+	m_Parameters.Add_Color("BG_COLOR",
+		"BG_USER"       , _TL("User Defined"),
+		_TL(""),
+		g_pMaps->Get_Parameter("BG_USER")->asColor()
 	);
 
 	m_Parameters.Add_Bool("NODE_GENERAL",
@@ -585,6 +592,11 @@ int CWKSP_Map::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *
 {
 	if( Flags & PARAMETER_CHECK_ENABLE )
 	{
+		if(	pParameter->Cmp_Identifier("BG_COLOR") )
+		{
+			pParameter->Set_Children_Enabled(pParameter->asInt ());
+		}
+
 		if(	pParameter->Cmp_Identifier("SEL_EXTENT") )
 		{
 			pParameter->Set_Children_Enabled(pParameter->asBool());
@@ -1380,7 +1392,8 @@ void CWKSP_Map::Set_Projection(void)
 	{
 		CSG_Parameters P(*pTool->Get_Parameters());
 
-		P.Set_Parameter("CRS_STRING"   , m_Projection.Get_WKT());
+		P.Set_Parameter("CRS_WKT" , m_Projection.Get_WKT2());
+		P.Set_Parameter("CRS_PROJ", m_Projection.Get_PROJ());
 
 		P.Add_Bool("", "ONTHEFLY", _TL("On-The-Fly Projection"),
 			_TL("Turn on the on-the-fly projection for all layers in the map."),
@@ -1392,7 +1405,7 @@ void CWKSP_Map::Set_Projection(void)
 		{
 			CSG_Projection Projection; CSG_Parameters &_P = *pTool->Get_Parameters();
 
-			Projection.Create(_P["CRS_WKT"].asString());
+			Projection.Create(_P["CRS_WKT"].asString(), _P["CRS_PROJ"].asString());
 
 			if( P("ONTHEFLY")->asBool() )
 			{
@@ -2120,14 +2133,13 @@ bool CWKSP_Map::_Set_Thumbnail(void)
 {
 	if( m_Thumbnail.IsOk() && m_Thumbnail.GetWidth() > 0 && m_Thumbnail.GetHeight() > 0 )
 	{
-		wxMemoryDC		dc;
-		wxRect			r(0, 0, m_Thumbnail.GetWidth(), m_Thumbnail.GetHeight());
+		wxMemoryDC dc; wxRect r(0, 0, m_Thumbnail.GetWidth(), m_Thumbnail.GetHeight());
 
 		dc.SelectObject(m_Thumbnail);
 		dc.SetBackground(*wxWHITE_BRUSH);
 		dc.Clear();
 
-		Draw_Map(dc, Get_Extent(), 1., r, LAYER_DRAW_FLAG_NOEDITS|LAYER_DRAW_FLAG_NOLABELS);
+		Draw_Map(dc, Get_Extent(), 1., r, LAYER_DRAW_FLAG_NOEDITS|LAYER_DRAW_FLAG_NOLABELS|LAYER_DRAW_FLAG_THUMBNAIL);
 
 		dc.SelectObject(wxNullBitmap);
 
@@ -2138,6 +2150,17 @@ bool CWKSP_Map::_Set_Thumbnail(void)
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+wxColour CWKSP_Map::Get_Background(void)
+{
+	return( m_Parameters["BG_COLOR"].asInt() ? Get_Color_asWX(m_Parameters["BG_USER"].asInt()) : SYS_Get_Color_Background() );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 ///////////////////////////////////////////////////////////
@@ -2151,7 +2174,7 @@ void CWKSP_Map::Draw_Map(wxDC &dc, double Zoom, const wxRect &rClient, int Flags
 //---------------------------------------------------------
 void CWKSP_Map::Draw_Map(wxDC &dc, const CSG_Rect &rWorld, double Zoom, const wxRect &rClient, int Flags, int Background)
 {
-	CSG_Map_DC dc_Map(rWorld, rClient, Zoom, Background >= 0 ? Background : m_Parameters("BACKGROUND")->asInt());
+	CSG_Map_DC dc_Map(rWorld, rClient, Zoom, Background >= 0 ? Background : Get_Background().GetRGB());
 
 	Draw_Map(dc_Map, Flags);
 
@@ -2167,7 +2190,7 @@ void CWKSP_Map::Draw_Map(CSG_Map_DC &dc, int Flags)
 	{
 		switch( Get_Item(i)->Get_Type() )
 		{
-		case WKSP_ITEM_Map_Layer:
+		case WKSP_ITEM_Map_Layer    :
 		{
 			CWKSP_Map_Layer     *pLayer	= (CWKSP_Map_Layer     *)Get_Item(i);
 
@@ -2178,7 +2201,7 @@ void CWKSP_Map::Draw_Map(CSG_Map_DC &dc, int Flags)
 		}
 		break;
 
-		case WKSP_ITEM_Map_Graticule:
+		case WKSP_ITEM_Map_Graticule: if( (Flags & LAYER_DRAW_FLAG_THUMBNAIL) == 0 )
 		{
 			CWKSP_Map_Graticule *pLayer	= (CWKSP_Map_Graticule *)Get_Item(i);
 
@@ -2189,7 +2212,7 @@ void CWKSP_Map::Draw_Map(CSG_Map_DC &dc, int Flags)
 		}
 		break;
 
-		case WKSP_ITEM_Map_BaseMap:
+		case WKSP_ITEM_Map_BaseMap  : if( (Flags & LAYER_DRAW_FLAG_THUMBNAIL) == 0 )
 		{
 			CWKSP_Map_BaseMap   *pLayer	= (CWKSP_Map_BaseMap   *)Get_Item(i);
 
