@@ -318,7 +318,7 @@ bool CWKSP_Shapes_Line::Get_Style_Size(int &min_Size, int &max_Size, double &min
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-void CWKSP_Shapes_Line::Draw_Initialize(CWKSP_Map_DC &dc_Map, int Flags)
+void CWKSP_Shapes_Line::Draw_Initialize(CSG_Map_DC &dc_Map, int Flags)
 {
 	m_Label_Style	= m_Parameters("LABEL_STYLE"    )->asInt();
 	m_Label_Freq	= m_Parameters("LABEL_FREQUENCY")->asInt();
@@ -333,11 +333,11 @@ void CWKSP_Shapes_Line::Draw_Initialize(CWKSP_Map_DC &dc_Map, int Flags)
 
 	m_Pen.SetStyle((wxPenStyle)(m_Line_Style = PenList_Get_Style("LINE_STYLE")));
 
-	dc_Map.dc.SetPen(m_Pen);
+	dc_Map.SetPen(m_Pen);
 }
 
 //---------------------------------------------------------
-void CWKSP_Shapes_Line::Draw_Shape(CWKSP_Map_DC &dc_Map, CSG_Shape *pShape, int Selection)
+void CWKSP_Shapes_Line::Draw_Shape(CSG_Map_DC &dc_Map, CSG_Shape *pShape, int Selection)
 {
 	wxPen	Pen(m_Pen);
 
@@ -380,8 +380,8 @@ void CWKSP_Shapes_Line::Draw_Shape(CWKSP_Map_DC &dc_Map, CSG_Shape *pShape, int
 
 		switch( m_Size_Type )
 		{
-		default: Size *= dc_Map.m_Scale   ; break;
-		case  1: Size *= dc_Map.m_World2DC; break;
+		default: Size *= dc_Map.Scale()   ; break;
+		case  1: Size *= dc_Map.World2DC(); break;
 		}
 
 		Pen.SetWidth(Size < 0 ? 0 : (int)(0.5 + Size));
@@ -390,7 +390,7 @@ void CWKSP_Shapes_Line::Draw_Shape(CWKSP_Map_DC &dc_Map, CSG_Shape *pShape, int
 	//-----------------------------------------------------
 	if( m_Effect )
 	{
-		wxColour	Color	= Pen.GetColour();	Pen.SetColour(m_Effect_Color);	dc_Map.dc.SetPen(Pen);
+		wxColour	Color	= Pen.GetColour();	Pen.SetColour(m_Effect_Color);	dc_Map.SetPen(Pen);
 
 		if( m_Effect & TEXTEFFECT_TOP         )	_Draw_Shape(dc_Map, pShape,  0, -1);
 		if( m_Effect & TEXTEFFECT_TOPLEFT     )	_Draw_Shape(dc_Map, pShape, -1, -1);
@@ -405,15 +405,15 @@ void CWKSP_Shapes_Line::Draw_Shape(CWKSP_Map_DC &dc_Map, CSG_Shape *pShape, int
 	}
 
 	//-----------------------------------------------------
-	dc_Map.dc.SetPen(Pen);
+	dc_Map.SetPen(Pen);
 
 	_Draw_Shape(dc_Map, pShape);
 
-	dc_Map.dc.SetPen(m_Pen);
+	dc_Map.SetPen(m_Pen);
 }
 
 //---------------------------------------------------------
-void CWKSP_Shapes_Line::_Draw_Shape(CWKSP_Map_DC &dc_Map, CSG_Shape *pShape, int xOffset, int yOffset)
+void CWKSP_Shapes_Line::_Draw_Shape(CSG_Map_DC &dc_Map, CSG_Shape *pShape, int xOffset, int yOffset)
 {
 	for(int iPart=0; iPart<pShape->Get_Part_Count(); iPart++)
 	{
@@ -425,7 +425,7 @@ void CWKSP_Shapes_Line::_Draw_Shape(CWKSP_Map_DC &dc_Map, CSG_Shape *pShape, int
 			{
 				TSG_Point_Int B = A; A = dc_Map.World2DC(pShape->Get_Point(iPoint, iPart)); A.x += xOffset; A.y += yOffset;
 
-				dc_Map.dc.DrawLine(A.x, A.y, B.x, B.y);
+				dc_Map.DrawLine(A.x, A.y, B.x, B.y);
 			}
 		}
 	}
@@ -435,18 +435,18 @@ void CWKSP_Shapes_Line::_Draw_Shape(CWKSP_Map_DC &dc_Map, CSG_Shape *pShape, int
 #define GET_ANGLE(a, b)	M_RAD_TO_DEG * (b.x != a.x ? M_PI_180 - atan2((double)(b.y - a.y), (double)(b.x - a.x)) : (b.y > a.y ? M_PI_270 : (b.y < a.y ? M_PI_090 : 0.0)))
 
 //---------------------------------------------------------
-void CWKSP_Shapes_Line::Draw_Label(CWKSP_Map_DC &dc_Map, CSG_Shape *pShape, const wxString &Label)
+void CWKSP_Shapes_Line::Draw_Label(CSG_Map_DC &dc_Map, CSG_Shape *pShape, const wxString &Label)
 {
-	CSG_Shape_Line	*pLine	= (CSG_Shape_Line *)pShape;
+	CSG_Shape_Line *pLine = (CSG_Shape_Line *)pShape;
 
 	switch( m_Label_Style )
 	{
 	//-----------------------------------------------------
 	case  0:	// one label at the polyline centroid
 	{
-		TSG_Point_Int	C	= dc_Map.World2DC(pLine->Get_Centroid());
+		TSG_Point_Int C = dc_Map.World2DC(pLine->Get_Centroid());
 
-		Draw_Text(dc_Map.dc, TEXTALIGN_CENTER, C.x, C.y, Label, m_Label_Eff, m_Label_Eff_Color, m_Label_Eff_Size);
+		dc_Map.DrawText(TEXTALIGN_CENTER, C.x, C.y, Label, m_Label_Eff, m_Label_Eff_Color, m_Label_Eff_Size);
 	} break;
 
 	//-----------------------------------------------------
@@ -455,40 +455,38 @@ void CWKSP_Shapes_Line::Draw_Label(CWKSP_Map_DC &dc_Map, CSG_Shape *pShape, cons
 	{
 		for(int iPart=0; iPart<pLine->Get_Part_Count(); iPart++)
 		{
-			double	d = 0.0, c = 0.5 * pLine->Get_Length(iPart);
-
-			TSG_Point	A = pLine->Get_Point(0, iPart);
+			double d = 0., c = 0.5 * pLine->Get_Length(iPart);
 
 			for(int i=1, j=0; d<c && i<pLine->Get_Point_Count(iPart); i++, j++)
 			{
-				d	+= SG_Get_Distance(pLine->Get_Point(i, iPart), pLine->Get_Point(j, iPart));
+				d += SG_Get_Distance(pLine->Get_Point(i, iPart), pLine->Get_Point(j, iPart));
 
 				if( d >= c )
 				{
 					if( m_Label_Style == 1 )
 					{
-						TSG_Point	A	= pLine->Get_Point(i, iPart);
-						TSG_Point	B	= pLine->Get_Point(j, iPart);
+						TSG_Point A = pLine->Get_Point(i, iPart);
+						TSG_Point B = pLine->Get_Point(j, iPart);
 
-						A.x	+= 0.5 * (B.x - A.x);
-						A.y	+= 0.5 * (B.y - A.y);
+						A.x += 0.5 * (B.x - A.x);
+						A.y += 0.5 * (B.y - A.y);
 
-						TSG_Point_Int	C	= dc_Map.World2DC(A);
+						TSG_Point_Int C = dc_Map.World2DC(A);
 
-						Draw_Text(dc_Map.dc, TEXTALIGN_CENTER, C.x, C.y, Label, m_Label_Eff, m_Label_Eff_Color, m_Label_Eff_Size);
+						dc_Map.DrawText(TEXTALIGN_CENTER, C.x, C.y, Label, m_Label_Eff, m_Label_Eff_Color, m_Label_Eff_Size);
 					}
 					else
 					{
-						TSG_Point_Int	A	= dc_Map.World2DC(pLine->Get_Point(i, iPart));
-						TSG_Point_Int	B	= dc_Map.World2DC(pLine->Get_Point(j, iPart));
+						TSG_Point_Int A = dc_Map.World2DC(pLine->Get_Point(i, iPart));
+						TSG_Point_Int B = dc_Map.World2DC(pLine->Get_Point(j, iPart));
 
 						if( m_Label_Orient == 0 )
 						{
-							Draw_Text(dc_Map.dc, m_Label_Align, A.x, A.y, GET_ANGLE(B, A), Label, m_Label_Eff, m_Label_Eff_Color, m_Label_Eff_Size);
+							dc_Map.DrawText(m_Label_Align, A.x, A.y, GET_ANGLE(B, A), Label, m_Label_Eff, m_Label_Eff_Color, m_Label_Eff_Size);
 						}
 						else
 						{
-							Draw_Text(dc_Map.dc, m_Label_Align, B.x, B.y, GET_ANGLE(A, B), Label, m_Label_Eff, m_Label_Eff_Color, m_Label_Eff_Size);
+							dc_Map.DrawText(m_Label_Align, B.x, B.y, GET_ANGLE(A, B), Label, m_Label_Eff, m_Label_Eff_Color, m_Label_Eff_Size);
 						}
 					}
 				}
@@ -499,48 +497,46 @@ void CWKSP_Shapes_Line::Draw_Label(CWKSP_Map_DC &dc_Map, CSG_Shape *pShape, cons
 	//-----------------------------------------------------
 	case  3:	// along line labeling
 	{
-		wxCoord	Width, Height;	dc_Map.dc.GetTextExtent(Label, &Width, &Height);
+		wxCoord Width, Height; dc_Map.Get_DC().GetTextExtent(Label, &Width, &Height);
 
 		for(int iPart=0; iPart<pLine->Get_Part_Count(); iPart++)
 		{
-			if( pLine->Get_Point_Count(iPart) < 2 || Width > dc_Map.m_World2DC * pLine->Get_Length(iPart) )
+			if( pLine->Get_Point_Count(iPart) < 2 || Width > dc_Map.World2DC() * pLine->Get_Length(iPart) )
 			{
 				continue;
 			}
 
-			bool			bLabel	= false;
-			double			d		= 0.0;
-			TSG_Point_Int	B, A	= dc_Map.World2DC(pLine->Get_Point(0, iPart));
+			bool bLabel = false; double d = 0.; TSG_Point_Int B, A = dc_Map.World2DC(pLine->Get_Point(0, iPart));
 
 			for(int iPoint=1; iPoint<pLine->Get_Point_Count(iPart); iPoint++)
 			{
 				//-----------------------------------------
 				if( !bLabel )
 				{
-					B	= A; A	= dc_Map.World2DC(pLine->Get_Point(iPoint, iPart));
+					B = A; A = dc_Map.World2DC(pLine->Get_Point(iPoint, iPart));
 
 					if( (d += SG_Get_Distance(A.x, A.y, B.x, B.y)) > m_Label_Freq * Width )
 					{
-						B	= A; bLabel	= true;
+						B = A; bLabel = true;
 					}
 				}
 
 				//-----------------------------------------
 				else
 				{
-					A	= dc_Map.World2DC(pLine->Get_Point(iPoint, iPart));
+					A = dc_Map.World2DC(pLine->Get_Point(iPoint, iPart));
 
 					if( SG_Get_Distance(A.x, A.y, B.x, B.y) > Width )
 					{
-						d	= 0.0;	bLabel	= false;
+						d = 0.; bLabel = false;
 
 						if( m_Label_Orient == 0 )
 						{
-							Draw_Text(dc_Map.dc, m_Label_Align, A.x, A.y, GET_ANGLE(B, A), Label, m_Label_Eff, m_Label_Eff_Color, m_Label_Eff_Size);
+							dc_Map.DrawText(m_Label_Align, A.x, A.y, GET_ANGLE(B, A), Label, m_Label_Eff, m_Label_Eff_Color, m_Label_Eff_Size);
 						}
 						else
 						{
-							Draw_Text(dc_Map.dc, m_Label_Align, B.x, B.y, GET_ANGLE(A, B), Label, m_Label_Eff, m_Label_Eff_Color, m_Label_Eff_Size);
+							dc_Map.DrawText(m_Label_Align, B.x, B.y, GET_ANGLE(A, B), Label, m_Label_Eff, m_Label_Eff_Color, m_Label_Eff_Size);
 						}
 					}
 				}
@@ -602,21 +598,21 @@ void CWKSP_Shapes_Line::Edit_Shape_Draw_Move(wxDC &dc, const CSG_Rect &rWorld, c
 }
 
 //---------------------------------------------------------
-void CWKSP_Shapes_Line::Edit_Shape_Draw(CWKSP_Map_DC &dc_Map)
+void CWKSP_Shapes_Line::Edit_Shape_Draw(CSG_Map_DC &dc_Map)
 {
 	if( m_Edit_pShape )
 	{
 		if( m_Edit_bGleam )
 		{
-			dc_Map.dc.SetPen(wxPen(m_Edit_Color, 3));
-			dc_Map.dc.SetLogicalFunction(wxINVERT);
+			dc_Map.SetPen(wxPen(m_Edit_Color, 3));
+			dc_Map.Get_DC().SetLogicalFunction(wxINVERT);
 
 			_Draw_Shape(dc_Map, m_Edit_pShape);
 
-			dc_Map.dc.SetLogicalFunction(wxCOPY);
+			dc_Map.Get_DC().SetLogicalFunction(wxCOPY);
 		}
 
-		dc_Map.dc.SetPen(wxPen(m_Edit_Color));
+		dc_Map.SetPen(wxPen(m_Edit_Color));
 
 		_Draw_Shape(dc_Map, m_Edit_pShape);
 
