@@ -335,7 +335,7 @@ const CSG_String & CPhenIps::Get_Description(void)
 //---------------------------------------------------------
 #define ADD_REFERENCES	{\
 	Add_Reference("Baier P., Pennerstorfer J. and Schopf A.", "2007",\
-		"PHENIPS  A comprehensive phenology model of Ips typographus (L.) (Col., Scolytinae) as a tool for hazard rating of bark beetle infestation",\
+		"PHENIPS — A comprehensive phenology model of Ips typographus (L.) (Col., Scolytinae) as a tool for hazard rating of bark beetle infestation",\
 		"Forest Ecology and Management, 249(3): 171-186.",\
 		SG_T("https://www.sciencedirect.com/science/article/pii/S0378112707004057"), SG_T("ScienceDirect")\
 	);\
@@ -535,9 +535,9 @@ CPhenIps_Table::CPhenIps_Table(void)
 	//-----------------------------------------------------
 	Parameters.Add_Table("",   "WEATHER", _TL("Weather Data"), _TL(""), PARAMETER_INPUT);
 
-	Parameters.Add_Table_Field("WEATHER", "ATmean", _TL("Mean Temperature"   ), _TL("Degree Celsius"));
-	Parameters.Add_Table_Field("WEATHER", "ATmax" , _TL("Maximum Temperature"), _TL("Degree Celsius"));
-	Parameters.Add_Table_Field("WEATHER", "SIrel" , _TL("Solar Irradiation"  ), _TL("Wh/m^2"        ));
+	Parameters.Add_Table_Field("WEATHER", "ATmean", _TL("Mean Temperature"   ), "°C"   );
+	Parameters.Add_Table_Field("WEATHER", "ATmax" , _TL("Maximum Temperature"), "°C"   );
+	Parameters.Add_Table_Field("WEATHER", "SIrel" , _TL("Solar Irradiation"  ), "Wh/m²");
 
 	Parameters.Add_Table("", "PHENOLOGY", _TL("Phenology"), _TL(""), PARAMETER_OUTPUT);
 	Parameters.Add_Table("", "SUMMARY"  , _TL("Summary"  ), _TL(""), PARAMETER_OUTPUT);
@@ -604,9 +604,11 @@ bool CPhenIps_Table::On_Execute(void)
 	CPhenIps	PhenIps;	PhenIps.Set_Parameters(Parameters);
 
 	//-----------------------------------------------------
-	for(int iDay=0, Day=1; iDay<Weather.Get_Count() && Set_Progress(iDay, Weather.Get_Count()); iDay++, Day++)
+	int Day = 1;
+
+	for(sLong iDay=0; iDay<Weather.Get_Count() && Set_Progress(iDay, Weather.Get_Count()); iDay++, Day++)
 	{
-		double	DayLength	= SG_Get_Day_Length(Day, Latitude);
+		double DayLength = SG_Get_Day_Length(Day, Latitude);
 
 		PhenIps.Add_Day(Day,
 			Weather[iDay].asDouble(ATmean),
@@ -614,7 +616,7 @@ bool CPhenIps_Table::On_Execute(void)
 			Weather[iDay].asDouble(SIrel ), DayLength
 		);
 
-		CSG_Table_Record	*pRecord	= pPhenology->Add_Record();
+		CSG_Table_Record *pRecord = pPhenology->Add_Record();
 
 		pRecord->Set_Value(0, Day);
 		pRecord->Set_Value(1, DayLength);
@@ -673,9 +675,9 @@ CPhenIps_Grids::CPhenIps_Grids(void)
 	ADD_REFERENCES;
 
 	//-----------------------------------------------------
-	Parameters.Add_Grid_List("", "ATmean", _TL("Mean Temperature"   ), _TL("Degree Celsius"), PARAMETER_INPUT);
-	Parameters.Add_Grid_List("", "ATmax" , _TL("Maximum Temperature"), _TL("Degree Celsius"), PARAMETER_INPUT);
-	Parameters.Add_Grid_List("", "SIrel" , _TL("Solar Irradiation"  ), _TL("Wh/m^2"        ), PARAMETER_INPUT);
+	Parameters.Add_Grid_List("", "ATmean", _TL("Mean Temperature"   ), "°C"   , PARAMETER_INPUT);
+	Parameters.Add_Grid_List("", "ATmax" , _TL("Maximum Temperature"), "°C"   , PARAMETER_INPUT);
+	Parameters.Add_Grid_List("", "SIrel" , _TL("Solar Irradiation"  ), "Wh/m²", PARAMETER_INPUT);
 
 	Parameters.Add_Grid("", "GENERATIONS", _TL("Potential Number of Generations"), _TL(""), PARAMETER_OUTPUT, true, SG_DATATYPE_Short);
 	Parameters.Add_Grid("", "ONSET"      , _TL("Onset Day of Infestation"       ), _TL(""), PARAMETER_OUTPUT, true, SG_DATATYPE_Short);
@@ -766,7 +768,7 @@ bool CPhenIps_Grids::Initialize(bool bReset)
 
 		CSG_Colors	Colors(2 * MAX_GENERATIONS, SG_COLORS_YELLOW_RED);
 
-		ADD_LUT_CLASS(0, SG_GET_RGB(000, 127, 000), _TL("no generation"));
+		ADD_LUT_CLASS((double)0, SG_GET_RGB(000, 127, 000), _TL("no generation"));
 
 		for(int i=1, j=1; i<=MAX_GENERATIONS; i++, j+=2)
 		{
@@ -908,7 +910,7 @@ bool CPhenIps_Grids_Annual::On_Execute(void)
 	_PhenIps.Set_Parameters(Parameters);
 
 	//-----------------------------------------------------
-	for(int y=0; y<Get_NY() && Set_Progress(y); y++)
+	for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 	{
 		#ifndef _DEBUG
 		#pragma omp parallel for
@@ -1087,7 +1089,7 @@ bool CPhenIps_Grids_Days::On_Execute(void)
 	_PhenIps.Set_Parameters(Parameters);
 
 	//-----------------------------------------------------
-	for(int y=0; y<Get_NY() && Set_Progress(y); y++)
+	for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 	{
 		#ifndef _DEBUG
 		#pragma omp parallel for
