@@ -189,7 +189,7 @@ CGrid_Classify_Supervised::CGrid_Classify_Supervised(void)
 
 	Parameters.Add_Double("METHOD",
 		"THRESHOLD_DIST", _TL("Distance Threshold"),
-		_TL("Let pixel stay unclassified, if minimum euclidian or mahalanobis distance is greater than threshold."),
+		_TL("Let pixel stay unclassified, if minimum euclidean or mahalanobis distance is greater than threshold."),
 		0., 0., true
 	);
 
