@@ -455,7 +455,7 @@ bool CTiles_Provider::Provide_Tiles(const CSG_String &Directory, CSG_Rect Extent
 //---------------------------------------------------------
 int CTiles_Provider::Provide_Tile(const CSG_String &Directory, int Col, int Row, bool DeleteArchive)
 {
-	CSG_String File = Get_Tile_Name(Col, Row) + "." + m_Grid_Extension;
+	CSG_String File = Get_Tile_File(Col, Row);
 
 	CSG_String Local_File = SG_File_Make_Path(Directory, File);
 
@@ -468,6 +468,8 @@ int CTiles_Provider::Provide_Tile(const CSG_String &Directory, int Col, int Row,
 	CSG_String Archive_Name = Get_Tile_Archive(Col, Row);
 	CSG_String Archive_File = SG_File_Make_Path(Directory, Archive_Name);
 
+	Message_Fmt("\n%s: %s%s...", _TL("requesting file"), m_ServerPath.c_str(), Archive_Name.c_str());
+
 	if( !SG_File_Exists(Archive_File) )
 	{
 		Process_Set_Text("%s: %s...", File.c_str(), _TL("downloading"));
@@ -477,14 +479,14 @@ int CTiles_Provider::Provide_Tile(const CSG_String &Directory, int Col, int Row,
 
 		CSG_CURL Connection(m_ServerPath, Username, Password);
 
-		Message_Fmt("\n%s: %s%s", _TL("requesting file"), m_ServerPath.c_str(), Archive_Name.c_str());
-
-		SG_UI_Process_Set_Busy(true, CSG_String::Format("%s: %s%s...", _TL("Downloading"), m_ServerPath.c_str(), Archive_Name.c_str()));
+		SG_UI_Process_Set_Busy(true, CSG_String::Format("%s: %s%s...", _TL("downloading"), m_ServerPath.c_str(), Archive_Name.c_str()));
 
 		if( !Connection.Request(Archive_Name, Archive_File.c_str()) )
 		{
 			SG_UI_Process_Set_Busy(false);
 
+			Message_Fmt(_TL("failed"));
+
 			Error_Fmt("%s:\n\n%s%s", _TL("failed to request file from server"), m_ServerPath.c_str(), Archive_Name.c_str());
 
 			return( -1 );
@@ -498,9 +500,9 @@ int CTiles_Provider::Provide_Tile(const CSG_String &Directory, int Col, int Row,
 
 	CSG_Archive Archive(Archive_File);
 
-	if( !Archive.is_Open() || !Archive.Extract(Get_Tile_Archive_File(Col, Row)) )
+	if( !Archive.Extract(Get_Tile_Archive_File(Col, Row)) )
 	{
-		Error_Fmt("%s: %s", _TL("failed to extract file"), Get_Tile_Archive_File(Col, Row).c_str());
+		Message_Fmt("\n%s: %s", _TL("failed to extract file"), Get_Tile_Archive_File(Col, Row).c_str());
 
 		if( DeleteArchive )
 		{
@@ -510,12 +512,16 @@ int CTiles_Provider::Provide_Tile(const CSG_String &Directory, int Col, int Row,
 		return( -1 );
 	}
 
+	On_Provide_Tile(Col, Row, Archive);
+
 	if( DeleteArchive )
 	{
 		Archive.Close(); SG_File_Delete(Archive_File);
 	}
 
 	//-----------------------------------------------------
+	Message_Fmt(_TL("okay"));
+
 	return( 1 );
 }
 
@@ -625,21 +631,21 @@ CSG_Rect_Int CSRTM_CGIAR::Get_Tiles(const CSG_Rect &_Extent) const
 }
 
 //---------------------------------------------------------
-CSG_String CSRTM_CGIAR::Get_Tile_Name(int Col, int Row) const
+CSG_String CSRTM_CGIAR::Get_Tile_File(int Col, int Row) const
 {
-	return( CSG_String::Format("srtm_%02d_%02d", 1 + Col, 1 + Row) );
+	return( CSG_String::Format("srtm_%02d_%02d.tif", 1 + Col, 1 + Row) );
 }
 
 //---------------------------------------------------------
 CSG_String CSRTM_CGIAR::Get_Tile_Archive(int Col, int Row) const
 {
-	return( Get_Tile_Name(Col, Row) + ".zip" );
+	return( CSG_String::Format("srtm_%02d_%02d.zip", 1 + Col, 1 + Row) );
 }
 
 //---------------------------------------------------------
 CSG_String CSRTM_CGIAR::Get_Tile_Archive_File(int Col, int Row) const
 {
-	return( Get_Tile_Name(Col, Row) + ".tif" );
+	return( CSG_String::Format("srtm_%02d_%02d.tif", 1 + Col, 1 + Row) );
 }
 
 
@@ -716,11 +722,15 @@ CSG_String CSRTM_USGS::Get_Tile_Name(int Col, int Row) const
 	));
 }
 
+//---------------------------------------------------------
+CSG_String CSRTM_USGS::Get_Tile_File(int Col, int Row) const
+{
+	return( Get_Tile_Name(Col, Row) + ".tif" );
+}
+
 //---------------------------------------------------------
 CSG_String CSRTM_USGS::Get_Tile_Archive(int Col, int Row) const
 {
-	// http://e4ftl01.cr.usgs.gov/MEASURES/SRTMGL1.003/2000.02.11/S56W180.SRTMGL1.hgt.zip
-
 	return( Get_Tile_Name(Col, Row) + ".hgt.zip" );
 }
 
@@ -758,8 +768,9 @@ CCopernicus_DEM::CCopernicus_DEM(void)
 	);
 
 	//-----------------------------------------------------
-	// https://e4ftl01.cr.usgs.gov/MEASURES/SRTMGL1.003/2000.02.11/N51E009.SRTMGL1.hgt.zip
+	Parameters.Add_Bool("TILES", "MASK", _TL("Water Mask"), _TL("Applies ocean water mask."), true);
 
+	//-----------------------------------------------------
 	m_ServerPath     = "https://prism-dem-open.copernicus.eu/pd-desk-open-access/prismDownload/COP-DEM_GLO-30-DGED__2022_1/";
 
 	m_Grid_Name      = "Copernicus DEM";
@@ -797,6 +808,12 @@ CSG_String CCopernicus_DEM::Get_Tile_Name(int Col, int Row) const
 	));
 }
 
+//---------------------------------------------------------
+CSG_String CCopernicus_DEM::Get_Tile_File(int Col, int Row) const
+{
+	return( Get_Tile_Name(Col, Row) + "_DEM.tif" );
+}
+
 //---------------------------------------------------------
 CSG_String CCopernicus_DEM::Get_Tile_Archive(int Col, int Row) const
 {
@@ -806,13 +823,68 @@ CSG_String CCopernicus_DEM::Get_Tile_Archive(int Col, int Row) const
 //---------------------------------------------------------
 CSG_String CCopernicus_DEM::Get_Tile_Archive_File(int Col, int Row) const
 {
-	#ifdef _SAGA_MSW
-		return( Get_Tile_Name(Col, Row) + "\\DEM\\" + Get_Tile_Name(Col, Row) + "_DEM.tif" );
-	#else
-		return( Get_Tile_Name(Col, Row) + "/DEM/" + Get_Tile_Name(Col, Row) + "_DEM.tif" );
-	#endif
+#ifdef _SAGA_MSW
+	return( Get_Tile_Name(Col, Row) + "\\DEM\\" + Get_Tile_File(Col, Row) );
+#else
+	return( Get_Tile_Name(Col, Row) +  "/DEM/"  + Get_Tile_File(Col, Row) );
+#endif
 }
 
+//---------------------------------------------------------
+bool CCopernicus_DEM::On_Provide_Tile(int Col, int Row, CSG_Archive &Archive)
+{
+	if( !Parameters["MASK"].asBool() )
+	{
+		return( true );
+	}
+
+	CSG_Grid DEM, Mask; CSG_String Name(Get_Tile_Name(Col, Row)), Directory(SG_File_Get_Path(Archive.Get_Archive()));
+
+	Process_Set_Text("%s: %s...", Name.c_str(), _TL("masking"));
+
+	SG_UI_ProgressAndMsg_Lock(true);
+
+	if( DEM.Create(SG_File_Make_Path(Directory, Name + "_DEM.tif")) )
+	{
+		#ifdef _SAGA_MSW
+		CSG_String File(Name + "\\AUXFILES\\" + Name + "_WBM.tif" );
+		#else
+		CSG_String File(Name +  "/AUXFILES/"  + Name + "_WBM.tif" );
+		#endif
+
+		if( Archive.Extract(File) )
+		{
+			File = SG_File_Make_Path(Directory, Name + "_WBM.tif");
+
+			if( Mask.Create(File) && Mask.Get_System() == DEM.Get_System() )
+			{
+				for(sLong i=0; i<DEM.Get_NCells(); i++)
+				{
+					if( Mask.asInt(i) == 1 )
+					{
+						DEM.Set_NoData(i);
+					}
+				}
+
+				DEM.Save("");
+
+				SG_File_Delete(File);
+
+				SG_UI_ProgressAndMsg_Lock(false);
+
+				return( true );
+			}
+
+			SG_File_Delete(File);
+		}
+	}
+
+	SG_UI_ProgressAndMsg_Lock(false);
+
+	return( false );
+}
+
+
 
 ///////////////////////////////////////////////////////////
 //														 //
