@@ -238,7 +238,7 @@ bool CLine_Smoothing::Calc_SIA(CSG_Shapes *pLines, CSG_Shapes *pSmooth, int iMet
 
 
 	//--------------------------------------------------------
-	for(int iLine=0; iLine<pLines->Get_Count() && Set_Progress(iLine, pLines->Get_Count()); iLine++)
+	for(sLong iLine=0; iLine<pLines->Get_Count() && Set_Progress(iLine, pLines->Get_Count()); iLine++)
 	{
 		CSG_Shape *pLine = pLines->Get_Shape(iLine);
 		
@@ -406,7 +406,7 @@ bool CLine_Smoothing::Calc_Gaussian(CSG_Shapes *pLines, CSG_Shapes *pSmooth, dou
 
 
 	//--------------------------------------------------------
-	for(int iLine=0; iLine<pLines->Get_Count() && Set_Progress (iLine, pLines->Get_Count ()); iLine++)
+	for(sLong iLine=0; iLine<pLines->Get_Count() && Set_Progress (iLine, pLines->Get_Count ()); iLine++)
 	{
 		CSG_Shape *pLine = pLines->Get_Shape(iLine);
 		
@@ -640,7 +640,7 @@ bool CLine_Smoothing::Calc_Gaussian(CSG_Shapes *pLines, CSG_Shapes *pSmooth, dou
 
 				if( abs(denom) < EPSILON )
 				{
-					Error_Set(_TL("First Derivative is singular! Probably the shape containes consecutive identical points.\n\n"));
+					Error_Set(_TL("First Derivative is singular! Probably the shape contains consecutive identical points.\n\n"));
 
 					return( false );
 				}
