@@ -47,7 +47,7 @@
 
 //---------------------------------------------------------
 #include "polygon_generalization.h"
-
+#include <vector>
 
 ///////////////////////////////////////////////////////////
 //														 //
@@ -65,27 +65,50 @@ CPolygon_Generalization::CPolygon_Generalization(void)
 	Set_Description	(_TW(
 		"A simple generalization tool for polygons. "
 		"The tool joins polygons with an area size smaller than "
-		"the specified threshold to their largest neighbouring polygon. "
+		"the specified threshold to a neighbouring polygon. "
+		"Either the neighbouring polygon with the largest area or "
+		"the one with which the largest edge length is shared wins."
 	));
 
 	//-----------------------------------------------------
 	Parameters.Add_Shapes("",
 		"POLYGONS", _TL("Shapes"),
-		_TL(""),
+		_TL("The input polygons."),
 		PARAMETER_INPUT, SHAPE_TYPE_Polygon
 	);
 
 	Parameters.Add_Shapes("",
-		"GENERALIZED"	, _TL("Shape Indices"),
-		_TL(""),
+		"GENERALIZED"	, _TL("Generalized Shapes"),
+		_TL("The generalized output polygons."),
 		PARAMETER_OUTPUT_OPTIONAL, SHAPE_TYPE_Polygon
 	);
 
 	Parameters.Add_Double("",
-		"THRESHOLD"	, _TL("Threshold"),
-		_TL(""),
+		"THRESHOLD"	, _TL("Area Threshold"),
+		_TL("The maximum area of a polygon to get joined [map units squared]."),
 		100., 0., true
 	);
+
+	Parameters.Add_Choice("",
+		"JOIN_TO"	, _TL("Join to Neighbour with ..."),
+		_TL("Choose the method to determine the winner polygon."),
+		CSG_String::Format("%s|%s",
+			_TL("largest area"),
+			_TL("largest shared edge length")
+		), 0
+	);
+
+	Parameters.Add_Bool("",
+		"VERTICES"	, _TL("Check Vertices"),
+		_TL(""),
+		false
+	);
+
+	Parameters.Add_Double("VERTICES",
+		"EPSILON"	, _TL("Tolerance"),
+		_TL(""),
+		0.00001, 0., true
+	);
 }
 
 
@@ -96,6 +119,16 @@ CPolygon_Generalization::CPolygon_Generalization(void)
 //---------------------------------------------------------
 int CPolygon_Generalization::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
+	if( pParameter->Cmp_Identifier("JOIN_TO") )
+	{
+		pParameters->Set_Enabled("VERTICES", pParameter->asInt() == 1);
+	}
+
+	if( pParameter->Cmp_Identifier("VERTICES") )
+	{
+		pParameters->Set_Enabled("EPSILON", pParameter->asBool());
+	}
+
 	return( CSG_Tool::On_Parameters_Enable(pParameters, pParameter) );
 }
 
@@ -107,8 +140,7 @@ int CPolygon_Generalization::On_Parameters_Enable(CSG_Parameters *pParameters, C
 //---------------------------------------------------------
 bool CPolygon_Generalization::On_Execute(void)
 {
-	//-----------------------------------------------------
-	CSG_Shapes	*pPolygons = Parameters("POLYGONS")->asShapes();
+	CSG_Shapes *pPolygons = Parameters("POLYGONS")->asShapes();
 
 	if( !pPolygons->is_Valid() )
 	{
@@ -120,17 +152,17 @@ bool CPolygon_Generalization::On_Execute(void)
 	//-----------------------------------------------------
 	if( Parameters("GENERALIZED")->asShapes() && Parameters("GENERALIZED")->asShapes() != pPolygons )
 	{
-		CSG_Shapes	*pTarget   = Parameters("GENERALIZED")->asShapes();
+		CSG_Shapes *pTarget = Parameters("GENERALIZED")->asShapes();
 
 		pTarget->Create(*pPolygons);
 
 		pTarget->Fmt_Name("%s [%s]", pPolygons->Get_Name(), _TL("generalized"));
 
-		pPolygons	= pTarget;
+		pPolygons = pTarget;
 	}
 
 	//-----------------------------------------------------
-	sLong	i = 0, n = pPolygons->Get_Count();
+	sLong i = 0, n = pPolygons->Get_Count();
 
 	do
 	{
@@ -144,7 +176,7 @@ bool CPolygon_Generalization::On_Execute(void)
 		DataObject_Update(pPolygons);
 	}
 
-	n	-= pPolygons->Get_Count();
+	n -= pPolygons->Get_Count();
 
 	Message_Fmt("\n%s: %lld", _TL("total number of removed polygons"), n);
 
@@ -159,20 +191,20 @@ bool CPolygon_Generalization::On_Execute(void)
 //---------------------------------------------------------
 bool CPolygon_Generalization::Set_JoinTos(CSG_Shapes *pPolygons)
 {
-	CSG_Array_Int JoinTo;
+	CSG_Array_sLong JoinTo;
 
 	if( !Get_JoinTos(pPolygons, JoinTo) )
 	{
 		return( false );
 	}
 
-	sLong nDropped = 0, nRemoved = 0;
+	sLong nCandidate = 0, nRemoved = 0;
 
 	for(sLong i=0; i<pPolygons->Get_Count() && Set_Progress(i, pPolygons->Get_Count()); i++)
 	{
 		if( JoinTo[i] < 0 )
 		{
-			nDropped++;
+			nCandidate++;
 		}
 		else if( JoinTo[i] != i )
 		{
@@ -181,9 +213,17 @@ bool CPolygon_Generalization::Set_JoinTos(CSG_Shapes *pPolygons)
 			CSG_Shape_Polygon *pJoinTo = (CSG_Shape_Polygon *)pPolygons->Get_Shape(JoinTo[i]);
 			CSG_Shape_Polygon *pRemove = (CSG_Shape_Polygon *)pPolygons->Get_Shape(       i );
 
+			for(int iPart=0; iPart<pJoinTo->Get_Part_Count(); iPart++)
+			{
+				if( pJoinTo->is_Lake(iPart) == pJoinTo->is_Clockwise(iPart) )
+				{
+					pJoinTo->Revert_Points(iPart);
+				}
+			}
+
 			for(int iPart=0; iPart<pRemove->Get_Part_Count(); iPart++)
 			{
-				pJoinTo->Add_Part(pRemove->Get_Part(iPart));
+				pJoinTo->Add_Part(pRemove->Get_Part(iPart), pRemove->is_Lake(iPart) == pRemove->is_Clockwise(iPart));
 			}
 
 			SG_Shape_Get_Dissolve(pJoinTo);
@@ -198,9 +238,9 @@ bool CPolygon_Generalization::Set_JoinTos(CSG_Shapes *pPolygons)
 		}
 	}
 
-	Message_Fmt("\n%s: %lld; %s: %lld", _TL("candidates"), nRemoved + nDropped, _TL("eliminated"), nRemoved);
+	Message_Fmt("\n%s: %lld; %s: %lld", _TL("candidates"), nRemoved + nCandidate, _TL("eliminated"), nRemoved);
 
-	return( nDropped > 0 && nRemoved > 0 );
+	return( nRemoved > 0 );
 }
 
 
@@ -209,9 +249,12 @@ bool CPolygon_Generalization::Set_JoinTos(CSG_Shapes *pPolygons)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-bool CPolygon_Generalization::Get_JoinTos(CSG_Shapes *pPolygons, CSG_Array_Int &JoinTo)
+bool CPolygon_Generalization::Get_JoinTos(CSG_Shapes *pPolygons, CSG_Array_sLong &JoinTo)
 {
 	double Threshold = Parameters("THRESHOLD")->asDouble();
+	int       Method = Parameters("JOIN_TO")->asInt();
+	bool   bVertices = Parameters("VERTICES")->asBool();
+	double   Epsilon = Parameters("EPSILON")->asDouble();
 
 	if( Threshold <= 0. || !JoinTo.Create(pPolygons->Get_Count()) )
 	{
@@ -219,12 +262,13 @@ bool CPolygon_Generalization::Get_JoinTos(CSG_Shapes *pPolygons, CSG_Array_Int &
 	}
 
 	sLong n = 0;
+	std::vector<bool> Has_Join(pPolygons->Get_Count(), false);
 
 	for(sLong i=0; i<pPolygons->Get_Count() && Set_Progress(i, pPolygons->Get_Count()); i++)
 	{
 		CSG_Shape_Polygon *pPolygon = (CSG_Shape_Polygon *)pPolygons->Get_Shape(i);
 
-		if( Threshold <= pPolygon->Get_Area() )
+		if( Has_Join[i] || Threshold <= pPolygon->Get_Area() )
 		{
 			JoinTo[i] = i;
 		}
@@ -232,19 +276,35 @@ bool CPolygon_Generalization::Get_JoinTos(CSG_Shapes *pPolygons, CSG_Array_Int &
 		{
 			JoinTo[i] = -1;
 
-			double maxArea = Threshold;
+			double maxValue = 0.;
 
 			for(sLong j=0; j<pPolygons->Get_Count(); j++)
 			{
 				if( j != i )
 				{
-					CSG_Shape_Polygon	*pNeighbour	= (CSG_Shape_Polygon *)pPolygons->Get_Shape(j);
+					CSG_Shape_Polygon *pNeighbour = (CSG_Shape_Polygon *)pPolygons->Get_Shape(j);
 
-					if( maxArea <= pNeighbour->Get_Area() && pPolygon->is_Neighbour(pNeighbour) )
+					if( Method == 0 ) // largest area
 					{
-						maxArea   = pNeighbour->Get_Area();
+						if( maxValue <= pNeighbour->Get_Area() && pPolygon->is_Neighbour(pNeighbour) )
+						{
+							maxValue   = pNeighbour->Get_Area();
 
-						JoinTo[i] = j;
+							JoinTo[i]   = j;
+							Has_Join[j] = true;
+						}
+					}
+					else if( pPolygon->is_Neighbour(pNeighbour) ) // largest shared edge length
+					{
+						double sharedLength = pPolygon->Get_Shared_Length(pNeighbour, bVertices, Epsilon);
+						
+						if( sharedLength > maxValue )
+						{
+							maxValue  = sharedLength;
+
+							JoinTo[i]   = j;
+							Has_Join[j] = true;
+						}
 					}
 				}
 			}
