@@ -316,7 +316,7 @@ bool CErosion_LS_Fields::Get_Flow(void)
 	int	Method_Area	= Parameters("METHOD_AREA")->asInt();
 
 	//-----------------------------------------------------
-	for(sLong n=0; n<Get_NCells() && Set_Progress_NCells(n); n++)
+	for(sLong n=0; n<Get_NCells() && Set_Progress_Cells(n); n++)
 	{
 		int	x, y;	double	dzSum, dz[8], Slope, Aspect;
 
@@ -365,7 +365,7 @@ bool CErosion_LS_Fields::Get_Flow(void)
 
 			m_pUp_Area  ->Set_Value(x, y, Up_Area);
 			m_pUp_Length->Set_Value(x, y, Up_Length);
-			m_pUp_Slope ->Set_Value(x, y, Up_Slope / (Up_Length < M_ALMOST_ZERO ? M_ALMOST_ZERO : Up_Length));
+			m_pUp_Slope ->Set_Value(x, y, Up_Slope / (Up_Length < M_FLT_EPSILON ? M_FLT_EPSILON : Up_Length));
 		}
 	}
 
@@ -419,7 +419,7 @@ bool CErosion_LS_Fields::Get_LS(void)
 
 	Process_Set_Text(_TL("LS Factor"));
 
-	for(int y=0; y<Get_NY() && Set_Progress(y); y++)
+	for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 	{
 		#pragma omp parallel for
 		for(int x=0; x<Get_NX(); x++)
@@ -464,7 +464,7 @@ inline double CErosion_LS_Fields::Get_LS(int x, int y, bool bFeet)
 		Slope	= m_pUp_Slope->asDouble(x, y);
 	}
 
-	if( Slope  < M_ALMOST_ZERO ) Slope  = M_ALMOST_ZERO;
+	if( Slope  < M_FLT_EPSILON ) Slope  = M_FLT_EPSILON;
 	if( Aspect < 0.            ) Aspect = 0.           ;
 
 	sin_Slope	= sin(Slope);
@@ -515,12 +515,12 @@ inline double CErosion_LS_Fields::Get_LS(int x, int y, bool bFeet)
 
 	//-----------------------------------------------------
 	case  2: {	// Wischmeier and Smith
-		if( Slope > 0.0505 )	// >  ca. 3
+		if( Slope > 0.0505 )	// >  ca. 3°
 		{
 			LS	= sqrt(SCA / 22.13)
 				* (65.41 * sin_Slope * sin_Slope + 4.56 * sin_Slope + 0.065);
 		}
-		else					// <= ca. 3
+		else					// <= ca. 3°
 		{
 			LS	= pow (SCA / 22.13, 3. * pow(Slope, 0.6))
 				* (65.41 * sin_Slope * sin_Slope + 4.56 * sin_Slope + 0.065);
@@ -553,7 +553,7 @@ bool CErosion_LS_Fields::Get_Balance(void)
 	//-----------------------------------------------------
 	Process_Set_Text("%s: %s 1", _TL("Sediment Balance"), _TL("Pass"));
 
-	for(int y=0; y<Get_NY() && Set_Progress(y); y++)
+	for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 	{
 		#pragma omp parallel for
 		for(int x=0; x<Get_NX(); x++)
@@ -584,7 +584,7 @@ bool CErosion_LS_Fields::Get_Balance(void)
 	//-----------------------------------------------------
 	Process_Set_Text("%s: %s 2", _TL("Sediment Balance"), _TL("Pass"));
 
-	for(int y=0; y<Get_NY() && Set_Progress(y); y++)
+	for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 	{
 		#pragma omp parallel for
 		for(int x=0; x<Get_NX(); x++)
@@ -654,7 +654,7 @@ bool CErosion_LS_Fields::Get_Statistics(void)
 	CSG_Simple_Statistics	*Statistics	= new CSG_Simple_Statistics[m_nFields];
 
 	//-----------------------------------------------------
-	for(int y=0; y<Get_NY() && Set_Progress(y); y++)
+	for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 	{
 		for(int x=0; x<Get_NX(); x++)
 		{
@@ -676,7 +676,7 @@ bool CErosion_LS_Fields::Get_Statistics(void)
 	pStatistics->Add_Field("MAX"   , SG_DATATYPE_Double);
 	pStatistics->Add_Field("STDDEV", SG_DATATYPE_Double);
 
-	for(int i=0; i<pFields->Get_Count() && Set_Progress(i, pFields->Get_Count()); i++)
+	for(sLong i=0; i<pFields->Get_Count() && Set_Progress(i, pFields->Get_Count()); i++)
 	{
 		CSG_Shape	*pField	= pStatistics->Add_Shape(pFields->Get_Shape(i));
 
@@ -735,14 +735,14 @@ bool CErosion_LS_Fields::Set_Fields(void)
 	//-----------------------------------------------------
 	Process_Set_Text(_TL("Initializing Fields"));
 
-	m_nFields	= pFields->Get_Count();
+	m_nFields = (int)pFields->Get_Count();
 
 	m_Fields.Create(Get_System(), m_nFields < pow(2., 16.) - 1. ? SG_DATATYPE_Word : SG_DATATYPE_DWord);
 	m_Fields.Set_NoData_Value(m_nFields);
 	m_Fields.Assign_NoData();
 
 	//-----------------------------------------------------
-	for(int iField=0; iField<pFields->Get_Count() && Set_Progress(iField, pFields->Get_Count()); iField++)
+	for(sLong iField=0; iField<pFields->Get_Count() && Set_Progress(iField, pFields->Get_Count()); iField++)
 	{
 		CSG_Shape_Polygon	*pField	= (CSG_Shape_Polygon *)pFields->Get_Shape(iField);
 
@@ -757,7 +757,7 @@ bool CErosion_LS_Fields::Set_Fields(void)
 			{
 				if( m_pDEM->is_InGrid(x, y) && pField->Contains(Get_System().Get_Grid_to_World(x, y)) )
 				{
-					m_Fields.Set_Value(x, y, iField);
+					m_Fields.Set_Value(x, y, (int)iField);
 				}
 			}
 		}
