@@ -94,8 +94,8 @@ CSG_String CFlow_AreaUpslope::Get_Methods(void)
 		_TL("Deterministic 8"),
 		_TL("Deterministic Infinity"),
 		_TL("Multiple Flow Direction"),
-		_TL("Multiple Triangular Flow Directon"),
-		_TL("Multiple Maximum Downslope Gradient Based Flow Directon")
+		_TL("Multiple Triangular Flow Direction"),
+		_TL("Multiple Maximum Downslope Gradient Based Flow Direction")
 	));
 }
 
@@ -639,7 +639,7 @@ CFlow_AreaUpslope_Interactive::CFlow_AreaUpslope_Interactive(void)
 
 	Parameters.Add_Double("",
 		"CONVERGE"	, _TL("Convergence"),
-		_TL("Convergence factor for Multiple Flow Direction Algorithm (Freeman 1991).\nApplies also to the Multiple Triangular Flow Directon Algorithm."),
+		_TL("Convergence factor for Multiple Flow Direction Algorithm (Freeman 1991).\nApplies also to the Multiple Triangular Flow Direction Algorithm."),
 		1.1, 0.001, true
 	);
 
@@ -686,7 +686,7 @@ bool CFlow_AreaUpslope_Interactive::On_Execute(void)
 		Parameters("MFD_CONTOUR")->asBool  ()) )
 	{
 		DataObject_Set_Colors(Parameters("AREA")->asGrid(), 11, SG_COLORS_WHITE_BLUE);
-		DataObject_Update    (Parameters("AREA")->asGrid(), SG_UI_DATAOBJECT_SHOW);
+		DataObject_Update    (Parameters("AREA")->asGrid(), SG_UI_DATAOBJECT_SHOW_MAP);
 
 		return( true );
 	}
@@ -842,7 +842,7 @@ bool CFlow_AreaUpslope_Area::On_Execute(void)
 
 		if( pTarget != NULL )
 		{
-			for(int y=0; y<Get_NY() && Set_Progress(y); y++)
+			for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 			{
 				for(int x=0; x<Get_NX(); x++)
 				{
