@@ -109,7 +109,7 @@ CSolarRadiation::CSolarRadiation(void)
 	Parameters.Add_Double("",
 		"SOLARCONST"	, _TL("Solar Constant [W/m²]"),
 		_TL(""),
-		1367., 0., true
+		1361., 0., true
 	);
 
 	Parameters.Add_Bool("",
@@ -276,9 +276,10 @@ int CSolarRadiation::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Param
 		bool bResult;
 
 		SG_RUN_TOOL(bResult, "pj_proj4", 2,	// Coordinate Transformation (Shapes)
-			   SG_TOOL_PARAMETER_SET("SOURCE"    , &srcCenter)
-			&& SG_TOOL_PARAMETER_SET("TARGET"    , &dstCenter)
-			&& SG_TOOL_PARAMETER_SET("CRS_STRING", CSG_Projection::Get_GCS_WGS84().Get_WKT())
+			   SG_TOOL_PARAMETER_SET("SOURCE"  , &srcCenter)
+			&& SG_TOOL_PARAMETER_SET("TARGET"  , &dstCenter)
+			&& SG_TOOL_PARAMETER_SET("CRS_WKT" , CSG_Projection::Get_GCS_WGS84().Get_WKT2())
+			&& SG_TOOL_PARAMETER_SET("CRS_PROJ", CSG_Projection::Get_GCS_WGS84().Get_PROJ())
 		)
 
 		if( bResult )
@@ -666,7 +667,8 @@ bool CSolarRadiation::Get_Insolation(CSG_DateTime Date, double Hour)
 
 	Process_Set_Text(Date.Format("%A, %d. %B %Y, %X"));
 
-	double JDN = floor(Date.Get_JDN()) - 0.5 + Hour / 24.; // relate to UTC, avoid problems with daylight saving time
+//	double JDN = Date.Get_JDN(); // relate to UTC, avoid problems with daylight saving time
+	double JDN = SG_Date_To_JulianDayNumber(Date.Get_Year(), 1 + Date.Get_Month(), Date.Get_Day()) + Hour / 24.; // relate to UTC, avoid problems with daylight saving time
 
 	//-----------------------------------------------------
 	m_Solar_Const = Parameters("SOLARCONST")->asDouble() / 1000.; // >> [kW/m²]
@@ -708,6 +710,17 @@ bool CSolarRadiation::Get_Insolation(CSG_DateTime Date, double Hour)
 
 		if( SG_Get_Sun_Position(JDN, 0., m_Latitude, Sun_Height, Sun_Azimuth) )
 		{
+			if( Parameters("PERIOD")->asInt() == 0 ) // moment
+			{
+				Message_Fmt("\n____\n%s\n%s: %f\n%s: %02d:%02.2f\n%s: %f\n%s: %f\n",
+					_TL("Solar Position"   ),
+					_TL("Julian Day Number"), JDN,
+					_TL("Local Time"       ), (int)Hour, (Hour - (int)Hour) * 60.,
+					_TL("Height"           ), M_RAD_TO_DEG * Sun_Height,
+					_TL("Azimuth"          ), M_RAD_TO_DEG * fmod(Sun_Azimuth + M_PI_360, M_PI_360)
+				);
+			}
+
 			return( Get_Insolation(Sun_Height, Sun_Azimuth, Hour) );
 		}
 	}
