@@ -524,6 +524,18 @@ protected:
 	virtual void				On_Update_Choices		(wxCommandEvent &event);
 	virtual void				On_Update_Control		(wxCommandEvent &event);
 
+	#ifdef __WXMAC__
+	virtual void				On_Menu					(wxCommandEvent &event)
+	{
+		switch( event.GetId() )
+		{
+		default: CSG_3DView_Dialog::On_Menu(event); return;
+
+		case MENU_PROPERTIES: if( SG_UI_Dlg_Parameters(&m_pPanel->Get_Parameters(), "") ) { m_pPanel->Set_Parameters(); } return;
+		}
+	}
+	#endif
+
 
 private:
 
